@@ -6,8 +6,8 @@
 mod context;
 
 pub mod args;
-pub mod internal_wsl;
 pub mod tunnels;
 pub mod update;
 pub mod version;
+pub mod serve_web;
 pub use context::CommandContext;
