@@ -14,7 +14,7 @@ use crate::tunnels::paths::{get_server_folder_name, SERVER_FOLDER_NAME};
 use crate::update_service::{
 	unzip_downloaded_release, Platform, Release, TargetKind, UpdateService,
 };
-use crate::util::command::{capture_command, kill_tree};
+use crate::util::command::{capture_command, capture_command_and_check_status, kill_tree};
 use crate::util::errors::{wrap, AnyError, CodeError, ExtensionInstallFailed, WrappedError};
 use crate::util::http::{self, BoxedHttp};
 use crate::util::io::SilentCopyProgress;
@@ -416,11 +416,23 @@ impl<'a> ServerBuilder<'a> {
 				)
 				.await?;
 
-				unzip_downloaded_release(
-					&archive_path,
-					&target_dir.join(SERVER_FOLDER_NAME),
-					SilentCopyProgress(),
-				)?;
+				let server_dir = target_dir.join(SERVER_FOLDER_NAME);
+				unzip_downloaded_release(&archive_path, &server_dir, SilentCopyProgress())?;
+
+				let output = capture_command_and_check_status(
+					server_dir
+						.join("bin")
+						.join(self.server_params.release.quality.server_entrypoint()),
+					&["--version"],
+				)
+				.await
+				.map_err(|e| wrap(e, "error checking server integrity"))?;
+
+				trace!(
+					self.logger,
+					"Server integrity verified, version: {}",
+					String::from_utf8_lossy(&output.stdout).replace('\n', " / ")
+				);
 
 				Ok(())
 			})
@@ -541,6 +553,15 @@ impl<'a> ServerBuilder<'a> {
 
 		debug!(self.logger, "Starting server with command... {:?}", cmd);
 
+		// On Windows spawning a code-server binary will run cmd.exe /c C:\path\to\code-server.cmd...
+		// This spawns a cmd.exe window for the user, which if they close will kill the code-server process
+		// and disconnect the tunnel. To prevent this, pass the CREATE_NO_WINDOW flag to the Command
+		// only on Windows.
+		// Original issue: https://github.com/microsoft/vscode/issues/184058
+		// Partial fix: https://github.com/microsoft/vscode/pull/184621
+		#[cfg(target_os = "windows")]
+		let cmd = cmd.creation_flags(winapi::um::winbase::CREATE_NO_WINDOW);
+
 		let child = cmd
 			.stderr(std::process::Stdio::piped())
 			.stdout(std::process::Stdio::piped())
