@@ -7,13 +7,12 @@ use std::cmp::Ordering;
 use super::command::capture_command;
 use crate::constants::QUALITYLESS_SERVER_NAME;
 use crate::update_service::Platform;
-use crate::util::errors::SetupError;
 use lazy_static::lazy_static;
 use regex::bytes::Regex as BinRegex;
 use regex::Regex;
 use tokio::fs;
 
-use super::errors::AnyError;
+use super::errors::CodeError;
 
 lazy_static! {
 	static ref LDCONFIG_STDC_RE: Regex = Regex::new(r"libstdc\+\+.* => (.+)").unwrap();
@@ -41,19 +40,18 @@ impl PreReqChecker {
 	}
 
 	#[cfg(not(target_os = "linux"))]
-	pub async fn verify(&self) -> Result<Platform, AnyError> {
-		use crate::constants::QUALITYLESS_PRODUCT_NAME;
+	pub async fn verify(&self) -> Result<Platform, CodeError> {
 		Platform::env_default().ok_or_else(|| {
-			SetupError(format!(
-				"{} is not supported on this platform",
-				QUALITYLESS_PRODUCT_NAME
+			CodeError::UnsupportedPlatform(format!(
+				"{} {}",
+				std::env::consts::OS,
+				std::env::consts::ARCH
 			))
-			.into()
 		})
 	}
 
 	#[cfg(target_os = "linux")]
-	pub async fn verify(&self) -> Result<Platform, AnyError> {
+	pub async fn verify(&self) -> Result<Platform, CodeError> {
 		let (is_nixos, gnu_a, gnu_b, or_musl) = tokio::join!(
 			check_is_nixos(),
 			check_glibc_version(),
@@ -64,7 +62,7 @@ impl PreReqChecker {
 		if (gnu_a.is_ok() && gnu_b.is_ok()) || is_nixos {
 			return Ok(if cfg!(target_arch = "x86_64") {
 				Platform::LinuxX64
-			} else if cfg!(target_arch = "armhf") {
+			} else if cfg!(target_arch = "arm") {
 				Platform::LinuxARM32
 			} else {
 				Platform::LinuxARM64
@@ -96,16 +94,16 @@ impl PreReqChecker {
 			.collect::<Vec<String>>()
 			.join("\n");
 
-		Err(AnyError::from(SetupError(format!(
-			"This machine not meet {}'s prerequisites, expected either...\n{}",
-			QUALITYLESS_SERVER_NAME, bullets,
-		))))
+		Err(CodeError::PrerequisitesFailed {
+			bullets,
+			name: QUALITYLESS_SERVER_NAME,
+		})
 	}
 }
 
 #[allow(dead_code)]
 async fn check_musl_interpreter() -> Result<(), String> {
-	const MUSL_PATH: &str = if cfg!(target_platform = "aarch64") {
+	const MUSL_PATH: &str = if cfg!(target_arch = "aarch64") {
 		"/lib/ld-musl-aarch64.so.1"
 	} else {
 		"/lib/ld-musl-x86_64.so.1"
