@@ -3,7 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { LsConfiguration } from 'vscode-markdown-languageservice/out/config';
+import { LsConfiguration } from 'vscode-markdown-languageservice';
 
 export { LsConfiguration };
 
