@@ -5,7 +5,6 @@
 
 import { RGBA, Color } from './color';
 import { ansiColorIdentifiers } from './colorMap';
-import { ttPolicy } from './htmlHelper';
 import { linkify } from './linkify';
 
 
@@ -396,14 +395,9 @@ function appendStylizedStringToContainer(
 
 	let container = document.createElement('span');
 
-	if (trustHtml) {
-		const trustedHtml = ttPolicy?.createHTML(stringContent) ?? stringContent;
-		container.innerHTML = trustedHtml as string;
-	}
-
 	if (container.childElementCount === 0) {
 		// plain text
-		container = linkify(stringContent, true, workspaceFolder);
+		container = linkify(stringContent, true, workspaceFolder, trustHtml);
 	}
 
 	container.className = cssClasses.join(' ');
