@@ -20,11 +20,48 @@ import { applyCodeActionCommands, getEditForCodeAction } from './util/codeAction
 import { conditionalRegistration, requireSomeCapability } from './util/dependentRegistration';
 
 type ApplyCodeActionCommand_args = {
-	readonly resource: vscode.Uri;
+	readonly document: vscode.TextDocument;
 	readonly diagnostic: vscode.Diagnostic;
 	readonly action: Proto.CodeFixAction;
+	readonly followupAction?: Command;
 };
 
+class EditorChatFollowUp implements Command {
+
+	id: string = '_typescript.quickFix.editorChatFollowUp';
+
+	constructor(private readonly prompt: string, private readonly document: vscode.TextDocument, private readonly range: vscode.Range, private readonly client: ITypeScriptServiceClient) {
+	}
+
+	async execute() {
+		const findScopeEndLineFromNavTree = (startLine: number, navigationTree: Proto.NavigationTree[]): vscode.Range | undefined => {
+			for (const node of navigationTree) {
+				const range = typeConverters.Range.fromTextSpan(node.spans[0]);
+				if (startLine === range.start.line) {
+					return range;
+				} else if (startLine > range.start.line && startLine <= range.end.line && node.childItems) {
+					return findScopeEndLineFromNavTree(startLine, node.childItems);
+				}
+			}
+			return undefined;
+		};
+		const filepath = this.client.toOpenTsFilePath(this.document);
+		if (!filepath) {
+			return;
+		}
+		const response = await this.client.execute('navtree', { file: filepath }, nulToken);
+		if (response.type !== 'response' || !response.body?.childItems) {
+			return;
+		}
+		const startLine = this.range.start.line;
+		const enclosingRange = findScopeEndLineFromNavTree(startLine, response.body.childItems);
+		if (!enclosingRange) {
+			return;
+		}
+		await vscode.commands.executeCommand('vscode.editorChat.start', { initialRange: enclosingRange, message: this.prompt, autoSend: true });
+	}
+}
+
 class ApplyCodeActionCommand implements Command {
 	public static readonly ID = '_typescript.applyCodeActionCommand';
 	public readonly id = ApplyCodeActionCommand.ID;
@@ -35,7 +72,7 @@ class ApplyCodeActionCommand implements Command {
 		private readonly telemetryReporter: TelemetryReporter,
 	) { }
 
-	public async execute({ resource, action, diagnostic }: ApplyCodeActionCommand_args): Promise<boolean> {
+	public async execute({ document, action, diagnostic, followupAction }: ApplyCodeActionCommand_args): Promise<boolean> {
 		/* __GDPR__
 			"quickFix.execute" : {
 				"owner": "mjbvz",
@@ -49,8 +86,10 @@ class ApplyCodeActionCommand implements Command {
 			fixName: action.fixName
 		});
 
-		this.diagnosticManager.deleteDiagnostic(resource, diagnostic);
-		return applyCodeActionCommands(this.client, action.commands, nulToken);
+		this.diagnosticManager.deleteDiagnostic(document.uri, diagnostic);
+		const codeActionResult = await applyCodeActionCommands(this.client, action.commands, nulToken);
+		await followupAction?.execute();
+		return codeActionResult;
 	}
 }
 
@@ -313,22 +352,27 @@ class TypeScriptQuickFixProvider implements vscode.CodeActionProvider<VsCodeCode
 		diagnostic: vscode.Diagnostic,
 		tsAction: Proto.CodeFixAction
 	): CodeActionSet {
-		results.addAction(this.getSingleFixForTsCodeAction(document.uri, diagnostic, tsAction));
+		results.addAction(this.getSingleFixForTsCodeAction(document, diagnostic, tsAction));
 		this.addFixAllForTsCodeAction(results, document.uri, file, diagnostic, tsAction as Proto.CodeFixAction);
 		return results;
 	}
 
 	private getSingleFixForTsCodeAction(
-		resource: vscode.Uri,
+		document: vscode.TextDocument,
 		diagnostic: vscode.Diagnostic,
 		tsAction: Proto.CodeFixAction
 	): VsCodeCodeAction {
+		const aiQuickFixEnabled = vscode.workspace.getConfiguration('typescript').get('experimental.aiQuickFix');
+		let followupAction: Command | undefined;
+		if (aiQuickFixEnabled && tsAction.fixName === fixNames.classIncorrectlyImplementsInterface) {
+			followupAction = new EditorChatFollowUp('Implement the class using the interface', document, diagnostic.range, this.client);
+		}
 		const codeAction = new VsCodeCodeAction(tsAction, tsAction.description, vscode.CodeActionKind.QuickFix);
 		codeAction.edit = getEditForCodeAction(this.client, tsAction);
 		codeAction.diagnostics = [diagnostic];
 		codeAction.command = {
 			command: ApplyCodeActionCommand.ID,
-			arguments: [<ApplyCodeActionCommand_args>{ action: tsAction, diagnostic, resource }],
+			arguments: [<ApplyCodeActionCommand_args>{ action: tsAction, diagnostic, document, followupAction }],
 			title: ''
 		};
 		return codeAction;
