@@ -4,10 +4,11 @@
  *--------------------------------------------------------------------------------------------*/
 
 import * as vscode from 'vscode';
-import { vscodeNotebookCell } from '../configuration/fileSchemes';
+import { officeScript, vscodeNotebookCell } from '../configuration/fileSchemes';
 import * as languageModeIds from '../configuration/languageIds';
 import * as typeConverters from '../typeConverters';
 import { ClientCapability, ITypeScriptServiceClient } from '../typescriptService';
+import { inMemoryResourcePrefix } from '../typescriptServiceClient';
 import { coalesce } from '../utils/arrays';
 import { Delayer, setImmediate } from '../utils/async';
 import { nulToken } from '../utils/cancellation';
@@ -16,17 +17,6 @@ import { ResourceMap } from '../utils/resourceMap';
 import { API } from './api';
 import type * as Proto from './protocol/protocol';
 
-const enum BufferLanguage {
-	TypeScript = 1,
-	JavaScript = 2,
-}
-
-const enum BufferState {
-	Initial = 1,
-	Open = 2,
-	Closed = 2,
-}
-
 type ScriptKind = 'TS' | 'TSX' | 'JS' | 'JSX';
 
 function mode2ScriptKind(mode: string): ScriptKind | undefined {
@@ -39,6 +29,8 @@ function mode2ScriptKind(mode: string): ScriptKind | undefined {
 	return undefined;
 }
 
+const enum BufferState { Initial, Open, Closed }
+
 const enum BufferOperationType { Close, Open, Change }
 
 class CloseOperation {
@@ -154,7 +146,7 @@ class BufferSynchronizer {
 			const closedFiles: string[] = [];
 			const openFiles: Proto.OpenRequestArgs[] = [];
 			const changedFiles: Proto.FileCodeEdits[] = [];
-			for (const change of this._pending.values) {
+			for (const change of this._pending.values()) {
 				switch (change.type) {
 					case BufferOperationType.Change: changedFiles.push(change.args); break;
 					case BufferOperationType.Open: openFiles.push(change.args); break;
@@ -209,7 +201,7 @@ class SyncedBuffer {
 		const args: Proto.OpenRequestArgs = {
 			file: this.filepath,
 			fileContent: this.document.getText(),
-			projectRootPath: this.client.getWorkspaceRootForResource(this.document.uri),
+			projectRootPath: this.getProjectRootPath(this.document.uri),
 		};
 
 		const scriptKind = mode2ScriptKind(this.document.languageId);
@@ -228,6 +220,16 @@ class SyncedBuffer {
 		this.state = BufferState.Open;
 	}
 
+	private getProjectRootPath(resource: vscode.Uri): string | undefined {
+		const workspaceRoot = this.client.getWorkspaceRootForResource(resource);
+		if (workspaceRoot) {
+			const tsRoot = this.client.toTsFilePath(workspaceRoot);
+			return tsRoot?.startsWith(inMemoryResourcePrefix) ? undefined : tsRoot;
+		}
+
+		return resource.scheme === officeScript ? '/' : undefined;
+	}
+
 	public get resource(): vscode.Uri {
 		return this.document.uri;
 	}
@@ -236,17 +238,8 @@ class SyncedBuffer {
 		return this.document.lineCount;
 	}
 
-	public get language(): BufferLanguage {
-		switch (this.document.languageId) {
-			case languageModeIds.javascript:
-			case languageModeIds.javascriptreact:
-				return BufferLanguage.JavaScript;
-
-			case languageModeIds.typescript:
-			case languageModeIds.typescriptreact:
-			default:
-				return BufferLanguage.TypeScript;
-		}
+	public get languageId(): string {
+		return this.document.languageId;
 	}
 
 	/**
@@ -277,13 +270,13 @@ class SyncedBufferMap extends ResourceMap<SyncedBuffer> {
 	}
 
 	public get allBuffers(): Iterable<SyncedBuffer> {
-		return this.values;
+		return this.values();
 	}
 }
 
 class PendingDiagnostics extends ResourceMap<number> {
 	public getOrderedFileSet(): ResourceMap<void> {
-		const orderedResources = Array.from(this.entries)
+		const orderedResources = Array.from(this.entries())
 			.sort((a, b) => a.value - b.value)
 			.map(entry => entry.resource);
 
@@ -320,7 +313,7 @@ class GetErrRequest {
 		}
 
 		const supportsSyntaxGetErr = this.client.apiVersion.gte(API.v440);
-		const allFiles = coalesce(Array.from(files.entries)
+		const allFiles = coalesce(Array.from(files.entries())
 			.filter(entry => supportsSyntaxGetErr || client.hasCapabilityForResource(entry.resource, ClientCapability.Semantic))
 			.map(entry => client.toTsFilePath(entry.resource)));
 
@@ -462,8 +455,9 @@ export default class BufferSyncSupport extends Disposable {
 
 	private readonly client: ITypeScriptServiceClient;
 
-	private _validateJavaScript: boolean = true;
-	private _validateTypeScript: boolean = true;
+	private _validateJavaScript = true;
+	private _validateTypeScript = true;
+
 	private readonly modeIds: Set<string>;
 	private readonly syncedBuffers: SyncedBufferMap;
 	private readonly pendingDiagnostics: PendingDiagnostics;
@@ -717,7 +711,7 @@ export default class BufferSyncSupport extends Disposable {
 		if (this.pendingGetErr) {
 			this.pendingGetErr.cancel();
 
-			for (const { resource } of this.pendingGetErr.files.entries) {
+			for (const { resource } of this.pendingGetErr.files.entries()) {
 				if (this.syncedBuffers.get(resource)) {
 					orderedFileSet.set(resource, undefined);
 				}
@@ -727,7 +721,7 @@ export default class BufferSyncSupport extends Disposable {
 		}
 
 		// Add all open TS buffers to the geterr request. They might be visible
-		for (const buffer of this.syncedBuffers.values) {
+		for (const buffer of this.syncedBuffers.values()) {
 			orderedFileSet.set(buffer.resource, undefined);
 		}
 
@@ -755,11 +749,13 @@ export default class BufferSyncSupport extends Disposable {
 			return false;
 		}
 
-		switch (buffer.language) {
-			case BufferLanguage.JavaScript:
+		switch (buffer.languageId) {
+			case languageModeIds.javascript:
+			case languageModeIds.javascriptreact:
 				return this._validateJavaScript;
 
-			case BufferLanguage.TypeScript:
+			case languageModeIds.typescript:
+			case languageModeIds.typescriptreact:
 			default:
 				return this._validateTypeScript;
 		}
