@@ -3,24 +3,31 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { $ } from 'vs/base/browser/dom';
+import { $, IDomNodePagePosition } from 'vs/base/browser/dom';
 import { IView, IViewSize } from 'vs/base/browser/ui/grid/grid';
-import { IBoundarySashes } from 'vs/base/browser/ui/grid/gridview';
-import { ISplitViewStyles, IView as ISplitViewView, Orientation, SplitView } from 'vs/base/browser/ui/splitview/splitview';
+import { IBoundarySashes } from 'vs/base/browser/ui/sash/sash';
+import { DistributeSizing, ISplitViewStyles, IView as ISplitViewView, Orientation, SplitView } from 'vs/base/browser/ui/splitview/splitview';
 import { Color } from 'vs/base/common/color';
 import { Event } from 'vs/base/common/event';
 import { DisposableStore, IDisposable } from 'vs/base/common/lifecycle';
 
 export interface CenteredViewState {
+	// width of the fixed centered layout
+	targetWidth: number;
+	// proportional size of left margin
 	leftMarginRatio: number;
+	// proportional size of right margin
 	rightMarginRatio: number;
 }
 
-const GOLDEN_RATIO = {
+const defaultState: CenteredViewState = {
+	targetWidth: 900,
 	leftMarginRatio: 0.1909,
-	rightMarginRatio: 0.1909
+	rightMarginRatio: 0.1909,
 };
 
+const distributeSizing: DistributeSizing = { type: 'distribute' };
+
 function createEmptyView(background: Color | undefined): ISplitViewView<{ top: number; left: number }> {
 	const element = $('.centered-layout-margin');
 	element.style.height = '100%';
@@ -54,14 +61,18 @@ export interface ICenteredViewStyles extends ISplitViewStyles {
 export class CenteredViewLayout implements IDisposable {
 
 	private splitView?: SplitView<{ top: number; left: number }>;
-	private width: number = 0;
-	private height: number = 0;
+	private lastLayoutPosition: IDomNodePagePosition = { width: 0, height: 0, left: 0, top: 0 };
 	private style!: ICenteredViewStyles;
 	private didLayout = false;
 	private emptyViews: ISplitViewView<{ top: number; left: number }>[] | undefined;
 	private readonly splitViewDisposables = new DisposableStore();
+	private centeredLayoutFixedWidth = true;
 
-	constructor(private container: HTMLElement, private view: IView, public readonly state: CenteredViewState = { leftMarginRatio: GOLDEN_RATIO.leftMarginRatio, rightMarginRatio: GOLDEN_RATIO.rightMarginRatio }) {
+	constructor(
+		private container: HTMLElement,
+		private view: IView,
+		public state: CenteredViewState = { ...defaultState }
+	) {
 		this.container.appendChild(this.view.element);
 		// Make sure to hide the split view overflow like sashes #52892
 		this.container.style.overflow = 'hidden';
@@ -87,25 +98,53 @@ export class CenteredViewLayout implements IDisposable {
 	}
 
 	layout(width: number, height: number, top: number, left: number): void {
-		this.width = width;
-		this.height = height;
+		this.lastLayoutPosition = { width, height, top, left };
 		if (this.splitView) {
-			this.splitView.layout(width);
-			if (!this.didLayout) {
-				this.resizeMargins();
+			this.splitView.layout(width, this.lastLayoutPosition);
+			if (!this.didLayout || this.centeredLayoutFixedWidth) {
+				this.resizeSplitViews();
 			}
 		} else {
 			this.view.layout(width, height, top, left);
 		}
+
 		this.didLayout = true;
 	}
 
-	private resizeMargins(): void {
+	private resizeSplitViews(): void {
 		if (!this.splitView) {
 			return;
 		}
-		this.splitView.resizeView(0, this.state.leftMarginRatio * this.width);
-		this.splitView.resizeView(2, this.state.rightMarginRatio * this.width);
+		if (this.centeredLayoutFixedWidth) {
+			const centerViewWidth = Math.min(this.lastLayoutPosition.width, this.state.targetWidth);
+			const marginWidthFloat = (this.lastLayoutPosition.width - centerViewWidth) / 2;
+			this.splitView.resizeView(0, Math.floor(marginWidthFloat));
+			this.splitView.resizeView(1, centerViewWidth);
+			this.splitView.resizeView(2, Math.ceil(marginWidthFloat));
+		} else {
+			const leftMargin = this.state.leftMarginRatio * this.lastLayoutPosition.width;
+			const rightMargin = this.state.rightMarginRatio * this.lastLayoutPosition.width;
+			const center = this.lastLayoutPosition.width - leftMargin - rightMargin;
+			this.splitView.resizeView(0, leftMargin);
+			this.splitView.resizeView(1, center);
+			this.splitView.resizeView(2, rightMargin);
+		}
+	}
+
+	setFixedWidth(option: boolean) {
+		this.centeredLayoutFixedWidth = option;
+		if (!!this.splitView) {
+			this.updateState();
+			this.resizeSplitViews();
+		}
+	}
+
+	private updateState() {
+		if (!!this.splitView) {
+			this.state.targetWidth = this.splitView.getViewSize(1);
+			this.state.leftMarginRatio = this.splitView.getViewSize(0) / this.lastLayoutPosition.width;
+			this.state.rightMarginRatio = this.splitView.getViewSize(2) / this.lastLayoutPosition.width;
+		}
 	}
 
 	isActive(): boolean {
@@ -137,23 +176,24 @@ export class CenteredViewLayout implements IDisposable {
 			this.splitView.orthogonalEndSash = this.boundarySashes.bottom;
 
 			this.splitViewDisposables.add(this.splitView.onDidSashChange(() => {
-				if (this.splitView) {
-					this.state.leftMarginRatio = this.splitView.getViewSize(0) / this.width;
-					this.state.rightMarginRatio = this.splitView.getViewSize(2) / this.width;
+				if (!!this.splitView) {
+					this.updateState();
 				}
 			}));
 			this.splitViewDisposables.add(this.splitView.onDidSashReset(() => {
-				this.state.leftMarginRatio = GOLDEN_RATIO.leftMarginRatio;
-				this.state.rightMarginRatio = GOLDEN_RATIO.rightMarginRatio;
-				this.resizeMargins();
+				this.state = { ...defaultState };
+				this.resizeSplitViews();
 			}));
 
-			this.splitView.layout(this.width);
-			this.splitView.addView(toSplitViewView(this.view, () => this.height), 0);
+			this.splitView.layout(this.lastLayoutPosition.width, this.lastLayoutPosition);
 			const backgroundColor = this.style ? this.style.background : undefined;
 			this.emptyViews = [createEmptyView(backgroundColor), createEmptyView(backgroundColor)];
-			this.splitView.addView(this.emptyViews[0], this.state.leftMarginRatio * this.width, 0);
-			this.splitView.addView(this.emptyViews[1], this.state.rightMarginRatio * this.width, 2);
+
+			this.splitView.addView(this.emptyViews[0], distributeSizing, 0);
+			this.splitView.addView(toSplitViewView(this.view, () => this.lastLayoutPosition.height), distributeSizing, 1);
+			this.splitView.addView(this.emptyViews[1], distributeSizing, 2);
+
+			this.resizeSplitViews();
 		} else {
 			if (this.splitView) {
 				this.container.removeChild(this.splitView.el);
@@ -163,12 +203,17 @@ export class CenteredViewLayout implements IDisposable {
 			this.splitView = undefined;
 			this.emptyViews = undefined;
 			this.container.appendChild(this.view.element);
-			this.view.layout(this.width, this.height, 0, 0);
+			this.view.layout(this.lastLayoutPosition.width, this.lastLayoutPosition.height, this.lastLayoutPosition.top, this.lastLayoutPosition.left);
 		}
 	}
 
 	isDefault(state: CenteredViewState): boolean {
-		return state.leftMarginRatio === GOLDEN_RATIO.leftMarginRatio && state.rightMarginRatio === GOLDEN_RATIO.rightMarginRatio;
+		if (this.centeredLayoutFixedWidth) {
+			return state.targetWidth === defaultState.targetWidth;
+		} else {
+			return state.leftMarginRatio === defaultState.leftMarginRatio
+				&& state.rightMarginRatio === defaultState.rightMarginRatio;
+		}
 	}
 
 	dispose(): void {
