@@ -12,6 +12,7 @@ export const enum MarshalledId {
 	ScmProvider,
 	CommentController,
 	CommentThread,
+	CommentThreadInstance,
 	CommentThreadReply,
 	CommentNode,
 	CommentThreadNode,
@@ -19,5 +20,6 @@ export const enum MarshalledId {
 	NotebookCellActionContext,
 	NotebookActionContext,
 	TestItemContext,
-	Date
+	Date,
+	TestMessageMenuArgs,
 }
