@@ -150,7 +150,7 @@ export abstract class AbstractCodeEditorService extends Disposable implements IC
 		this._editorStyleSheets.delete(editorId);
 	}
 
-	public registerDecorationType(description: string, key: string, options: IDecorationRenderOptions, parentTypeKey?: string, editor?: ICodeEditor): void {
+	public registerDecorationType(description: string, key: string, options: IDecorationRenderOptions, parentTypeKey?: string, editor?: ICodeEditor): IDisposable {
 		let provider = this._decorationOptionProviders.get(key);
 		if (!provider) {
 			const styleSheet = this._getOrCreateStyleSheet(editor);
@@ -169,6 +169,11 @@ export abstract class AbstractCodeEditorService extends Disposable implements IC
 			this._onDecorationTypeRegistered.fire(key);
 		}
 		provider.refCount++;
+		return {
+			dispose: () => {
+				this.removeDecorationType(key);
+			}
+		};
 	}
 
 	public listDecorationTypes(): string[] {
