@@ -18,6 +18,7 @@ export class BlockDecorations extends ViewPart {
 	private readonly blocks: FastDomNode<HTMLElement>[] = [];
 
 	private contentWidth: number = -1;
+	private contentLeft: number = 0;
 
 	constructor(context: ViewContext) {
 		super(context);
@@ -41,6 +42,12 @@ export class BlockDecorations extends ViewPart {
 			didChange = true;
 		}
 
+		const newContentLeft = layoutInfo.contentLeft;
+		if (this.contentLeft !== newContentLeft) {
+			this.contentLeft = newContentLeft;
+			didChange = true;
+		}
+
 		return didChange;
 	}
 
@@ -82,14 +89,28 @@ export class BlockDecorations extends ViewPart {
 				block = this.blocks[count] = createFastDomNode(document.createElement('div'));
 				this.domNode.appendChild(block);
 			}
-			const top = ctx.getVerticalOffsetForLineNumber(decoration.range.startLineNumber, true);
-			const bottom = ctx.getVerticalOffsetAfterLineNumber(decoration.range.endLineNumber, true);
+
+			let top: number;
+			let bottom: number;
+
+			if (decoration.options.blockIsAfterEnd) {
+				// range must be empty
+				top = ctx.getVerticalOffsetAfterLineNumber(decoration.range.endLineNumber, false);
+				bottom = ctx.getVerticalOffsetAfterLineNumber(decoration.range.endLineNumber, true);
+			} else {
+				top = ctx.getVerticalOffsetForLineNumber(decoration.range.startLineNumber, true);
+				bottom = decoration.range.isEmpty() && !decoration.options.blockDoesNotCollapse
+					? ctx.getVerticalOffsetForLineNumber(decoration.range.startLineNumber, false)
+					: ctx.getVerticalOffsetAfterLineNumber(decoration.range.endLineNumber, true);
+			}
+
+			const [paddingTop, paddingRight, paddingBottom, paddingLeft] = decoration.options.blockPadding ?? [0, 0, 0, 0];
 
 			block.setClassName('blockDecorations-block ' + decoration.options.blockClassName);
-			block.setLeft(ctx.scrollLeft);
-			block.setWidth(this.contentWidth);
-			block.setTop(top);
-			block.setHeight(bottom - top);
+			block.setLeft(this.contentLeft - paddingLeft);
+			block.setWidth(this.contentWidth + paddingLeft + paddingRight);
+			block.setTop(top - ctx.scrollTop - paddingTop);
+			block.setHeight(bottom - top + paddingTop + paddingBottom);
 
 			count++;
 		}
