@@ -4,7 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { IdleDeadline, runWhenIdle } from 'vs/base/common/async';
-import { onUnexpectedError } from 'vs/base/common/errors';
+import { BugIndicatingError, onUnexpectedError } from 'vs/base/common/errors';
 import { setTimeout0 } from 'vs/base/common/platform';
 import { StopWatch } from 'vs/base/common/stopwatch';
 import { countEOL } from 'vs/editor/common/core/eolCounter';
@@ -25,7 +25,7 @@ const enum Constants {
 }
 
 export class TokenizerWithStateStore<TState extends IState = IState> {
-	private readonly initialState = this.tokenizationSupport.getInitialState();
+	private readonly initialState = this.tokenizationSupport.getInitialState() as TState;
 
 	public readonly store: TrackingTokenizationStateStore<TState>;
 
@@ -37,10 +37,11 @@ export class TokenizerWithStateStore<TState extends IState = IState> {
 	}
 
 	public getStartState(lineNumber: number): TState | null {
-		if (lineNumber === 1) {
-			return this.initialState as TState;
-		}
-		return this.store.getEndState(lineNumber - 1);
+		return this.store.getStartState(lineNumber, this.initialState);
+	}
+
+	public getFirstInvalidLine(): { lineNumber: number; startState: TState } | null {
+		return this.store.getFirstInvalidLine(this.initialState);
 	}
 }
 
@@ -58,17 +59,16 @@ export class TokenizerWithStateStoreAndTextModel<TState extends IState = IState>
 		const languageId = this._textModel.getLanguageId();
 
 		while (true) {
-			const nextLineNumber = this.store.getFirstInvalidEndStateLineNumber();
-			if (!nextLineNumber || nextLineNumber > lineNumber) {
+			const lineToTokenize = this.getFirstInvalidLine();
+			if (!lineToTokenize || lineToTokenize.lineNumber > lineNumber) {
 				break;
 			}
 
-			const text = this._textModel.getLineContent(nextLineNumber);
-			const lineStartState = this.getStartState(nextLineNumber);
+			const text = this._textModel.getLineContent(lineToTokenize.lineNumber);
 
-			const r = safeTokenize(this._languageIdCodec, languageId, this.tokenizationSupport, text, true, lineStartState!);
-			builder.add(nextLineNumber, r.tokens);
-			this!.store.setEndState(nextLineNumber, r.endState as TState);
+			const r = safeTokenize(this._languageIdCodec, languageId, this.tokenizationSupport, text, true, lineToTokenize.startState);
+			builder.add(lineToTokenize.lineNumber, r.tokens);
+			this.store.setEndState(lineToTokenize.lineNumber, r.endState as TState);
 		}
 	}
 
@@ -204,8 +204,13 @@ export class TokenizerWithStateStoreAndTextModel<TState extends IState = IState>
 	}
 }
 
+/**
+ * **Invariant:**
+ * If the text model is retokenized from line 1 to {@link getFirstInvalidEndStateLineNumber}() - 1,
+ * then the recomputed end state for line l will be equal to {@link getEndState}(l).
+ */
 export class TrackingTokenizationStateStore<TState extends IState> {
-	private readonly tokenizationStateStore = new TokenizationStateStore<TState>();
+	private readonly _tokenizationStateStore = new TokenizationStateStore<TState>();
 	private readonly _invalidEndStatesLineNumbers = new RangePriorityQueueImpl();
 
 	constructor(private lineCount: number) {
@@ -213,20 +218,19 @@ export class TrackingTokenizationStateStore<TState extends IState> {
 	}
 
 	public getEndState(lineNumber: number): TState | null {
-		return this.tokenizationStateStore.getEndState(lineNumber);
+		return this._tokenizationStateStore.getEndState(lineNumber);
 	}
 
+	/**
+	 * @returns if the end state has changed.
+	 */
 	public setEndState(lineNumber: number, state: TState): boolean {
-		while (true) {
-			const min = this._invalidEndStatesLineNumbers.min;
-			if (min !== null && min <= lineNumber) {
-				this._invalidEndStatesLineNumbers.removeMin();
-			} else {
-				break;
-			}
+		if (!state) {
+			throw new BugIndicatingError('Cannot set null/undefined state');
 		}
 
-		const r = this.tokenizationStateStore.setEndState(lineNumber, state);
+		this._invalidEndStatesLineNumbers.delete(lineNumber);
+		const r = this._tokenizationStateStore.setEndState(lineNumber, state);
 		if (r && lineNumber < this.lineCount) {
 			// because the state changed, we cannot trust the next state anymore and have to invalidate it.
 			this._invalidEndStatesLineNumbers.addRange(new OffsetRange(lineNumber + 1, lineNumber + 2));
@@ -237,7 +241,7 @@ export class TrackingTokenizationStateStore<TState extends IState> {
 
 	public acceptChange(range: LineRange, newLineCount: number): void {
 		this.lineCount += newLineCount - range.length;
-		this.tokenizationStateStore.acceptChange(range, newLineCount);
+		this._tokenizationStateStore.acceptChange(range, newLineCount);
 		this._invalidEndStatesLineNumbers.addRangeAndResize(new OffsetRange(range.startLineNumber, range.endLineNumberExclusive), newLineCount);
 	}
 
@@ -252,16 +256,30 @@ export class TrackingTokenizationStateStore<TState extends IState> {
 		this._invalidEndStatesLineNumbers.addRange(new OffsetRange(range.startLineNumber, range.endLineNumberExclusive));
 	}
 
-	public getFirstInvalidEndStateLineNumber(): number | null {
-		return this._invalidEndStatesLineNumbers.min;
-	}
+	public getFirstInvalidEndStateLineNumber(): number | null { return this._invalidEndStatesLineNumbers.min; }
 
 	public getFirstInvalidEndStateLineNumberOrMax(): number {
-		return this._invalidEndStatesLineNumbers.min || Number.MAX_SAFE_INTEGER;
+		return this.getFirstInvalidEndStateLineNumber() || Number.MAX_SAFE_INTEGER;
 	}
 
-	public isTokenizationComplete(): boolean {
-		return this._invalidEndStatesLineNumbers.min === null;
+	public allStatesValid(): boolean { return this._invalidEndStatesLineNumbers.min === null; }
+
+	public getStartState(lineNumber: number, initialState: TState): TState | null {
+		if (lineNumber === 1) { return initialState; }
+		return this.getEndState(lineNumber - 1);
+	}
+
+	public getFirstInvalidLine(initialState: TState): { lineNumber: number; startState: TState } | null {
+		const lineNumber = this.getFirstInvalidEndStateLineNumber();
+		if (lineNumber === null) {
+			return null;
+		}
+		const startState = this.getStartState(lineNumber, initialState);
+		if (!startState) {
+			throw new BugIndicatingError('Start state must be defined');
+		}
+
+		return { lineNumber, startState };
 	}
 }
 
@@ -338,6 +356,26 @@ export class RangePriorityQueueImpl implements RangePriorityQueue {
 		return range.start;
 	}
 
+	public delete(value: number): void {
+		const idx = this._ranges.findIndex(r => r.contains(value));
+		if (idx !== -1) {
+			const range = this._ranges[idx];
+			if (range.start === value) {
+				if (range.endExclusive === value + 1) {
+					this._ranges.splice(idx, 1);
+				} else {
+					this._ranges[idx] = new OffsetRange(value + 1, range.endExclusive);
+				}
+			} else {
+				if (range.endExclusive === value + 1) {
+					this._ranges[idx] = new OffsetRange(range.start, value);
+				} else {
+					this._ranges.splice(idx, 1, new OffsetRange(range.start, value), new OffsetRange(value + 1, range.endExclusive));
+				}
+			}
+		}
+	}
+
 	public addRange(range: OffsetRange): void {
 		OffsetRange.addRange(range, this._ranges);
 	}
@@ -490,23 +528,23 @@ export class DefaultBackgroundTokenizer implements IBackgroundTokenizer {
 		if (!this._tokenizerWithStateStore) {
 			return false;
 		}
-		return !this._tokenizerWithStateStore.store.isTokenizationComplete();
+		return !this._tokenizerWithStateStore.store.allStatesValid();
 	}
 
 	private _tokenizeOneInvalidLine(builder: ContiguousMultilineTokensBuilder): number {
-		if (!this._tokenizerWithStateStore || !this._hasLinesToTokenize()) {
+		const firstInvalidLine = this._tokenizerWithStateStore?.getFirstInvalidLine();
+		if (!firstInvalidLine) {
 			return this._tokenizerWithStateStore._textModel.getLineCount() + 1;
 		}
-		const lineNumber = this._tokenizerWithStateStore.store.getFirstInvalidEndStateLineNumber()!;
-		this._tokenizerWithStateStore.updateTokensUntilLine(builder, lineNumber);
-		return lineNumber;
+		this._tokenizerWithStateStore.updateTokensUntilLine(builder, firstInvalidLine.lineNumber);
+		return firstInvalidLine.lineNumber;
 	}
 
 	public checkFinished(): void {
 		if (this._isDisposed) {
 			return;
 		}
-		if (this._tokenizerWithStateStore.store.isTokenizationComplete()) {
+		if (this._tokenizerWithStateStore.store.allStatesValid()) {
 			this._backgroundTokenStore.backgroundTokenizationFinished();
 		}
 	}
