@@ -54,7 +54,7 @@ export class CodeActionController extends Disposable implements IEditorContribut
 
 	private readonly _resolver: CodeActionKeybindingResolver;
 
-	#disposed = false;
+	private _disposed = false;
 
 	constructor(
 		editor: ICodeEditor,
@@ -89,7 +89,7 @@ export class CodeActionController extends Disposable implements IEditorContribut
 	}
 
 	override dispose() {
-		this.#disposed = true;
+		this._disposed = true;
 		super.dispose();
 	}
 
@@ -97,6 +97,10 @@ export class CodeActionController extends Disposable implements IEditorContribut
 		return this.showCodeActionList(actions, at, { includeDisabledActions: false, fromLightbulb: false });
 	}
 
+	public hideCodeActions(): void {
+		this._actionWidgetService.hide();
+	}
+
 	public manualTriggerAtCurrentPosition(
 		notAvailableMessage: string,
 		triggerAction: CodeActionTriggerSource,
@@ -126,6 +130,10 @@ export class CodeActionController extends Disposable implements IEditorContribut
 		}
 	}
 
+	public hideLightBulbWidget(): void {
+		this._lightBulbWidget.rawValue?.hide();
+	}
+
 	private async update(newState: CodeActionsState.State): Promise<void> {
 		if (newState.type !== CodeActionsState.Type.Triggered) {
 			this._lightBulbWidget.rawValue?.hide();
@@ -140,7 +148,7 @@ export class CodeActionController extends Disposable implements IEditorContribut
 			return;
 		}
 
-		if (this.#disposed) {
+		if (this._disposed) {
 			return;
 		}
 
