@@ -6,8 +6,7 @@
 import { alert } from 'vs/base/browser/ui/aria/aria';
 import { Event } from 'vs/base/common/event';
 import { Disposable, toDisposable } from 'vs/base/common/lifecycle';
-import { autorun, constObservable, observableFromEvent, observableValue } from 'vs/base/common/observable';
-import { ITransaction, disposableObservableValue, transaction } from 'vs/base/common/observableImpl/base';
+import { ITransaction, autorun, constObservable, disposableObservableValue, observableFromEvent, observableValue, transaction } from 'vs/base/common/observable';
 import { CoreEditingCommands } from 'vs/editor/browser/coreCommands';
 import { ICodeEditor } from 'vs/editor/browser/editorBrowser';
 import { EditorOption } from 'vs/editor/common/config/editorOptions';
@@ -23,11 +22,13 @@ import { InlineCompletionContextKeys } from 'vs/editor/contrib/inlineCompletions
 import { InlineCompletionsHintsWidget, InlineSuggestionHintsContentWidget } from 'vs/editor/contrib/inlineCompletions/browser/inlineCompletionsHintsWidget';
 import { InlineCompletionsModel, VersionIdChangeReason } from 'vs/editor/contrib/inlineCompletions/browser/inlineCompletionsModel';
 import { SuggestWidgetAdaptor } from 'vs/editor/contrib/inlineCompletions/browser/suggestWidgetInlineCompletionProvider';
+import { localize } from 'vs/nls';
 import { AudioCue, IAudioCueService } from 'vs/platform/audioCues/browser/audioCueService';
 import { ICommandService } from 'vs/platform/commands/common/commands';
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
+import { IKeybindingService } from 'vs/platform/keybinding/common/keybinding';
 
 export class InlineCompletionsController extends Disposable {
 	static ID = 'editor.contrib.inlineCompletionsController';
@@ -37,12 +38,19 @@ export class InlineCompletionsController extends Disposable {
 	}
 
 	public readonly model = disposableObservableValue<InlineCompletionsModel | undefined>('inlineCompletionModel', undefined);
-	private readonly textModelVersionId = observableValue<number, VersionIdChangeReason>('textModelVersionId', -1);
-	private readonly cursorPosition = observableValue<Position>('cursorPosition', new Position(1, 1));
+	private readonly textModelVersionId = observableValue<number, VersionIdChangeReason>(this, -1);
+	private readonly cursorPosition = observableValue<Position>(this, new Position(1, 1));
 	private readonly suggestWidgetAdaptor = this._register(new SuggestWidgetAdaptor(
 		this.editor,
 		() => this.model.get()?.selectedInlineCompletion.get()?.toSingleTextEdit(undefined),
-		(tx) => this.updateObservables(tx, VersionIdChangeReason.Other)
+		(tx) => this.updateObservables(tx, VersionIdChangeReason.Other),
+		(item) => {
+			transaction(tx => {
+				/** @description handleSuggestAccepted */
+				this.updateObservables(tx, VersionIdChangeReason.Other);
+				this.model.get()?.handleSuggestAccepted(item);
+			});
+		}
 	));
 	private readonly _enabled = observableFromEvent(this.editor.onDidChangeConfiguration, () => this.editor.getOption(EditorOption.inlineSuggest).enabled);
 
@@ -67,11 +75,11 @@ export class InlineCompletionsController extends Disposable {
 		@ILanguageFeatureDebounceService private readonly debounceService: ILanguageFeatureDebounceService,
 		@ILanguageFeaturesService private readonly languageFeaturesService: ILanguageFeaturesService,
 		@IAudioCueService private readonly audioCueService: IAudioCueService,
+		@IKeybindingService private readonly _keybindingService: IKeybindingService
 	) {
 		super();
 
 		this._register(new InlineCompletionContextKeys(this.contextKeyService, this.model));
-
 		this._register(Event.runAndSubscribe(editor.onDidChangeModel, () => transaction(tx => {
 			/** @description onDidChangeModel */
 			this.model.set(undefined, tx);
@@ -109,7 +117,7 @@ export class InlineCompletionsController extends Disposable {
 		this._register(editor.onDidChangeCursorPosition(e => transaction(tx => {
 			/** @description onDidChangeCursorPosition */
 			this.updateObservables(tx, VersionIdChangeReason.Other);
-			if (e.reason === CursorChangeReason.Explicit) {
+			if (e.reason === CursorChangeReason.Explicit || e.source === 'api') {
 				this.model.get()?.stop(tx);
 			}
 		})));
@@ -141,7 +149,7 @@ export class InlineCompletionsController extends Disposable {
 
 		this._register(this.editor.onDidBlurEditorWidget(() => {
 			// This is a hidden setting very useful for debugging
-			if (this.configurationService.getValue('editor.inlineSuggest.keepOnBlur') ||
+			if (this.contextKeyService.getContextKeyValue<boolean>('accessibleViewIsShown') || this.configurationService.getValue('editor.inlineSuggest.keepOnBlur') ||
 				editor.getOption(EditorOption.inlineSuggest).keepOnBlur) {
 				return;
 			}
@@ -154,7 +162,8 @@ export class InlineCompletionsController extends Disposable {
 			});
 		}));
 
-		this._register(autorun('forceRenderingAbove', reader => {
+		this._register(autorun(reader => {
+			/** @description forceRenderingAbove */
 			const state = this.model.read(reader)?.state.read(reader);
 			if (state?.suggestItem) {
 				if (state.ghostText.lineCount >= 2) {
@@ -169,7 +178,8 @@ export class InlineCompletionsController extends Disposable {
 		}));
 
 		let lastInlineCompletionId: string | undefined = undefined;
-		this._register(autorun('play audio cue & read suggestion', reader => {
+		this._register(autorun(reader => {
+			/** @description play audio cue & read suggestion */
 			const model = this.model.read(reader);
 			const state = model?.state.read(reader);
 			if (!model || !state || !state.inlineCompletion) {
@@ -182,13 +192,29 @@ export class InlineCompletionsController extends Disposable {
 				const lineText = model.textModel.getLineContent(state.ghostText.lineNumber);
 				this.audioCueService.playAudioCue(AudioCue.inlineSuggestion).then(() => {
 					if (this.editor.getOption(EditorOption.screenReaderAnnounceInlineSuggestion)) {
-						alert(state.ghostText.renderForScreenReader(lineText));
+						this.provideScreenReaderUpdate(state.ghostText.renderForScreenReader(lineText));
 					}
 				});
 			}
 		}));
 
 		this._register(new InlineCompletionsHintsWidget(this.editor, this.model, this.instantiationService));
+		this._register(this.configurationService.onDidChangeConfiguration(e => {
+			if (e.affectsConfiguration('accessibility.verbosity.inlineCompletions')) {
+				this.editor.updateOptions({ inlineCompletionsAccessibilityVerbose: this.configurationService.getValue('accessibility.verbosity.inlineCompletions') });
+			}
+		}));
+		this.editor.updateOptions({ inlineCompletionsAccessibilityVerbose: this.configurationService.getValue('accessibility.verbosity.inlineCompletions') });
+	}
+
+	private provideScreenReaderUpdate(content: string): void {
+		const accessibleViewShowing = this.contextKeyService.getContextKeyValue<boolean>('accessibleViewIsShown');
+		const accessibleViewKeybinding = this._keybindingService.lookupKeybinding('editor.action.accessibleView');
+		let hint: string | undefined;
+		if (!accessibleViewShowing && accessibleViewKeybinding && this.editor.getOption(EditorOption.inlineCompletionsAccessibilityVerbose)) {
+			hint = localize('showAccessibleViewHint', "Inspect this in the accessible view ({0})", accessibleViewKeybinding.getAriaLabel());
+		}
+		hint ? alert(content + ', ' + hint) : alert(content);
 	}
 
 	/**
