@@ -3,9 +3,9 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { Disposable, DisposableStore, IDisposable, toDisposable } from 'vs/base/common/lifecycle';
-import { IActiveCodeEditor, ICodeEditor } from 'vs/editor/browser/editorBrowser';
-import { IEditorContribution } from 'vs/editor/common/editorCommon';
+import { Disposable, DisposableStore, toDisposable } from 'vs/base/common/lifecycle';
+import { IActiveCodeEditor, ICodeEditor, MouseTargetType } from 'vs/editor/browser/editorBrowser';
+import { IEditorContribution, ScrollType } from 'vs/editor/common/editorCommon';
 import { ILanguageFeaturesService } from 'vs/editor/common/services/languageFeatures';
 import { EditorOption, RenderLineNumbersType } from 'vs/editor/common/config/editorOptions';
 import { StickyScrollWidget, StickyScrollWidgetState } from './stickyScrollWidget';
@@ -16,7 +16,7 @@ import { IContextMenuService } from 'vs/platform/contextview/browser/contextView
 import { MenuId } from 'vs/platform/actions/common/actions';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { EditorContextKeys } from 'vs/editor/common/editorContextKeys';
-import { ClickLinkGesture } from 'vs/editor/contrib/gotoSymbol/browser/link/clickLinkGesture';
+import { ClickLinkGesture, ClickLinkMouseEvent } from 'vs/editor/contrib/gotoSymbol/browser/link/clickLinkGesture';
 import { IRange, Range } from 'vs/editor/common/core/range';
 import { getDefinitionsAtPosition } from 'vs/editor/contrib/gotoSymbol/browser/goToSymbol';
 import { goToDefinitionWithLocation } from 'vs/editor/contrib/inlayHints/browser/inlayHintsLocations';
@@ -26,12 +26,7 @@ import { ILanguageConfigurationService } from 'vs/editor/common/languages/langua
 import { ILanguageFeatureDebounceService } from 'vs/editor/common/services/languageFeatureDebounce';
 import * as dom from 'vs/base/browser/dom';
 import { StickyRange } from 'vs/editor/contrib/stickyScroll/browser/stickyScrollElement';
-import { StandardMouseEvent } from 'vs/base/browser/mouseEvent';
-
-interface CustomMouseEvent {
-	detail: string;
-	element: HTMLElement;
-}
+import { IMouseEvent, StandardMouseEvent } from 'vs/base/browser/mouseEvent';
 
 export interface IStickyScrollController {
 	get stickyScrollCandidateProvider(): IStickyLineCandidateProvider;
@@ -62,13 +57,14 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 	private _stickyScrollFocusedContextKey: IContextKey<boolean>;
 	private _stickyScrollVisibleContextKey: IContextKey<boolean>;
 
-	private _stickyElements: HTMLCollection | undefined;
 	private _focusDisposableStore: DisposableStore | undefined;
 	private _focusedStickyElementIndex: number = -1;
 	private _enabled = false;
 	private _focused = false;
 	private _positionRevealed = false;
 	private _onMouseDown = false;
+	private _endLineNumbers: number[] = [];
+	private _showEndForLine: number | null = null;
 
 	constructor(
 		private readonly _editor: ICodeEditor,
@@ -85,24 +81,29 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 		this._register(this._stickyScrollWidget);
 		this._register(this._stickyLineCandidateProvider);
 
-		this._widgetState = new StickyScrollWidgetState([], 0);
+		this._widgetState = new StickyScrollWidgetState([], [], 0);
 		this._readConfiguration();
+		const stickyScrollDomNode = this._stickyScrollWidget.getDomNode();
 		this._register(this._editor.onDidChangeConfiguration(e => {
-			if (e.hasChanged(EditorOption.stickyScroll)) {
+			if (
+				e.hasChanged(EditorOption.stickyScroll)
+				|| e.hasChanged(EditorOption.minimap)
+				|| e.hasChanged(EditorOption.lineHeight)
+				|| e.hasChanged(EditorOption.showFoldingControls)
+			) {
 				this._readConfiguration();
 			}
 		}));
-		this._register(dom.addDisposableListener(this._stickyScrollWidget.getDomNode(), dom.EventType.CONTEXT_MENU, async (event: MouseEvent) => {
+		this._register(dom.addDisposableListener(stickyScrollDomNode, dom.EventType.CONTEXT_MENU, async (event: MouseEvent) => {
 			this._onContextMenu(event);
 		}));
 		this._stickyScrollFocusedContextKey = EditorContextKeys.stickyScrollFocused.bindTo(this._contextKeyService);
 		this._stickyScrollVisibleContextKey = EditorContextKeys.stickyScrollVisible.bindTo(this._contextKeyService);
-		const focusTracker = this._register(dom.trackFocus(this._stickyScrollWidget.getDomNode()));
+		const focusTracker = this._register(dom.trackFocus(stickyScrollDomNode));
 		this._register(focusTracker.onDidBlur(_ => {
-			const height = this._stickyScrollWidget.getDomNode().clientHeight;
 			// Suppose that the blurring is caused by scrolling, then keep the focus on the sticky scroll
 			// This is determined by the fact that the height of the widget has become zero and there has been no position revealing
-			if (this._positionRevealed === false && height === 0) {
+			if (this._positionRevealed === false && stickyScrollDomNode.clientHeight === 0) {
 				this._focusedStickyElementIndex = -1;
 				this.focus();
 
@@ -115,9 +116,9 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 		this._register(focusTracker.onDidFocus(_ => {
 			this.focus();
 		}));
-		this._register(this._createClickLinkGesture());
+		this._registerMouseListeners();
 		// Suppose that mouse down on the sticky scroll, then do not focus on the sticky scroll because this will be followed by the revealing of a position
-		this._register(dom.addDisposableListener(this._stickyScrollWidget.getDomNode(), dom.EventType.MOUSE_DOWN, (e) => {
+		this._register(dom.addDisposableListener(stickyScrollDomNode, dom.EventType.MOUSE_DOWN, (e) => {
 			this._onMouseDown = true;
 		}));
 	}
@@ -156,14 +157,12 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 		this._focused = true;
 		this._focusDisposableStore = new DisposableStore();
 		this._stickyScrollFocusedContextKey.set(true);
-		const rootNode = this._stickyScrollWidget.getDomNode();
-		(rootNode.lastElementChild! as HTMLDivElement).focus();
-		this._stickyElements = rootNode.children;
 		this._focusedStickyElementIndex = this._stickyScrollWidget.lineNumbers.length - 1;
+		this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex);
 	}
 
 	public focusNext(): void {
-		if (this._focusedStickyElementIndex < this._stickyElements!.length - 1) {
+		if (this._focusedStickyElementIndex < this._stickyScrollWidget.lineNumberCount - 1) {
 			this._focusNav(true);
 		}
 	}
@@ -181,7 +180,7 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 	// True is next, false is previous
 	private _focusNav(direction: boolean): void {
 		this._focusedStickyElementIndex = direction ? this._focusedStickyElementIndex + 1 : this._focusedStickyElementIndex - 1;
-		(this._stickyElements!.item(this._focusedStickyElementIndex) as HTMLDivElement).focus();
+		this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex);
 	}
 
 	public goToFocused(): void {
@@ -191,104 +190,178 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 	}
 
 	private _revealPosition(position: IPosition): void {
+		this._reveaInEditor(position, () => this._editor.revealPosition(position));
+	}
+
+	private _revealLineInCenterIfOutsideViewport(position: IPosition): void {
+		this._reveaInEditor(position, () => this._editor.revealLineInCenterIfOutsideViewport(position.lineNumber, ScrollType.Smooth));
+	}
+
+	private _reveaInEditor(position: IPosition, revealFunction: () => void): void {
+		if (this._focused) {
+			this._disposeFocusStickyScrollStore();
+		}
 		this._positionRevealed = true;
-		this._editor.revealPosition(position);
+		revealFunction();
 		this._editor.setSelection(Range.fromPositions(position));
 		this._editor.focus();
 	}
 
-	private _createClickLinkGesture(): IDisposable {
+	private _registerMouseListeners(): void {
 
-		const linkGestureStore = new DisposableStore();
-		const sessionStore = new DisposableStore();
-		linkGestureStore.add(sessionStore);
-		const gesture = new ClickLinkGesture(this._editor, true);
-		linkGestureStore.add(gesture);
+		const sessionStore = this._register(new DisposableStore());
+		const gesture = this._register(new ClickLinkGesture(this._editor, {
+			extractLineNumberFromMouseEvent: (e) => {
+				const position = this._stickyScrollWidget.getEditorPositionFromNode(e.target.element);
+				return position ? position.lineNumber : 0;
+			}
+		}));
 
-		linkGestureStore.add(gesture.onMouseMoveOrRelevantKeyDown(([mouseEvent, _keyboardEvent]) => {
-			if (!this._editor.hasModel() || !mouseEvent.hasTriggerModifier) {
+		const getMouseEventTarget = (mouseEvent: ClickLinkMouseEvent): { range: Range; textElement: HTMLElement } | null => {
+			if (!this._editor.hasModel()) {
+				return null;
+			}
+			if (mouseEvent.target.type !== MouseTargetType.OVERLAY_WIDGET || mouseEvent.target.detail !== this._stickyScrollWidget.getId()) {
+				// not hovering over our widget
+				return null;
+			}
+			const mouseTargetElement = mouseEvent.target.element;
+			if (!mouseTargetElement || mouseTargetElement.innerText !== mouseTargetElement.innerHTML) {
+				// not on a span element rendering text
+				return null;
+			}
+			const position = this._stickyScrollWidget.getEditorPositionFromNode(mouseTargetElement);
+			if (!position) {
+				// not hovering a sticky scroll line
+				return null;
+			}
+			return {
+				range: new Range(position.lineNumber, position.column, position.lineNumber, position.column + mouseTargetElement.innerText.length),
+				textElement: mouseTargetElement
+			};
+		};
+
+		const stickyScrollWidgetDomNode = this._stickyScrollWidget.getDomNode();
+		this._register(dom.addStandardDisposableListener(stickyScrollWidgetDomNode, dom.EventType.CLICK, (mouseEvent: IMouseEvent) => {
+			if (mouseEvent.ctrlKey || mouseEvent.altKey || mouseEvent.metaKey) {
+				// modifier pressed
+				return;
+			}
+			if (!mouseEvent.leftButton) {
+				// not left click
+				return;
+			}
+			if (mouseEvent.shiftKey) {
+				// shift click
+				const lineIndex = this._stickyScrollWidget.getStickyLineIndexFromChildDomNode(mouseEvent.target);
+				if (lineIndex === null) {
+					return;
+				}
+				const position = new Position(this._endLineNumbers[lineIndex], 1);
+				this._revealLineInCenterIfOutsideViewport(position);
+				return;
+			}
+			// normal click
+			let position = this._stickyScrollWidget.getEditorPositionFromNode(mouseEvent.target);
+			if (!position) {
+				const lineNumber = this._stickyScrollWidget.getLineNumberFromChildDomNode(mouseEvent.target);
+				if (lineNumber === null) {
+					// not hovering a sticky scroll line
+					return;
+				}
+				position = new Position(lineNumber, 1);
+			}
+			this._revealPosition(position);
+		}));
+		this._register(dom.addStandardDisposableListener(stickyScrollWidgetDomNode, dom.EventType.MOUSE_MOVE, (mouseEvent: IMouseEvent) => {
+			if (mouseEvent.shiftKey) {
+				const currentEndForLineIndex = this._stickyScrollWidget.getStickyLineIndexFromChildDomNode(mouseEvent.target);
+				if (currentEndForLineIndex === null || this._showEndForLine !== null && this._showEndForLine === currentEndForLineIndex) {
+					return;
+				}
+				this._showEndForLine = currentEndForLineIndex;
+				this._renderStickyScroll();
+				return;
+			}
+			if (this._showEndForLine !== null) {
+				this._showEndForLine = null;
+				this._renderStickyScroll();
+			}
+		}));
+		this._register(dom.addDisposableListener(stickyScrollWidgetDomNode, dom.EventType.MOUSE_LEAVE, (e) => {
+			if (this._showEndForLine !== null) {
+				this._showEndForLine = null;
+				this._renderStickyScroll();
+			}
+		}));
+
+		this._register(gesture.onMouseMoveOrRelevantKeyDown(([mouseEvent, _keyboardEvent]) => {
+			const mouseTarget = getMouseEventTarget(mouseEvent);
+			if (!mouseTarget || !mouseEvent.hasTriggerModifier || !this._editor.hasModel()) {
 				sessionStore.clear();
 				return;
 			}
-			const targetMouseEvent = mouseEvent.target as unknown as CustomMouseEvent;
-			if (targetMouseEvent.detail === this._stickyScrollWidget.getId()
-				&& targetMouseEvent.element.innerText === targetMouseEvent.element.innerHTML) {
+			const { range, textElement } = mouseTarget;
 
-				const text = targetMouseEvent.element.innerText;
-				if (this._stickyScrollWidget.hoverOnColumn === -1) {
-					return;
-				}
-				const lineNumber = this._stickyScrollWidget.hoverOnLine;
-				const column = this._stickyScrollWidget.hoverOnColumn;
-
-				const stickyPositionProjectedOnEditor = new Range(lineNumber, column, lineNumber, column + text.length);
-				if (!stickyPositionProjectedOnEditor.equalsRange(this._stickyRangeProjectedOnEditor)) {
-					this._stickyRangeProjectedOnEditor = stickyPositionProjectedOnEditor;
-					sessionStore.clear();
-				} else if (targetMouseEvent.element.style.textDecoration === 'underline') {
-					return;
-				}
-
-				const cancellationToken = new CancellationTokenSource();
-				sessionStore.add(toDisposable(() => cancellationToken.dispose(true)));
-
-				let currentHTMLChild: HTMLElement;
-
-				getDefinitionsAtPosition(this._languageFeaturesService.definitionProvider, this._editor.getModel(), new Position(lineNumber, column + 1), cancellationToken.token).then((candidateDefinitions => {
-					if (cancellationToken.token.isCancellationRequested) {
-						return;
-					}
-					if (candidateDefinitions.length !== 0) {
-						this._candidateDefinitionsLength = candidateDefinitions.length;
-						const childHTML: HTMLElement = targetMouseEvent.element;
-						if (currentHTMLChild !== childHTML) {
-							sessionStore.clear();
-							currentHTMLChild = childHTML;
-							currentHTMLChild.style.textDecoration = 'underline';
-							sessionStore.add(toDisposable(() => {
-								currentHTMLChild.style.textDecoration = 'none';
-							}));
-						} else if (!currentHTMLChild) {
-							currentHTMLChild = childHTML;
-							currentHTMLChild.style.textDecoration = 'underline';
-							sessionStore.add(toDisposable(() => {
-								currentHTMLChild.style.textDecoration = 'none';
-							}));
-						}
-					} else {
-						sessionStore.clear();
-					}
-				}));
-			} else {
+			if (!range.equalsRange(this._stickyRangeProjectedOnEditor)) {
+				this._stickyRangeProjectedOnEditor = range;
 				sessionStore.clear();
+			} else if (textElement.style.textDecoration === 'underline') {
+				return;
 			}
+
+			const cancellationToken = new CancellationTokenSource();
+			sessionStore.add(toDisposable(() => cancellationToken.dispose(true)));
+
+			let currentHTMLChild: HTMLElement;
+
+			getDefinitionsAtPosition(this._languageFeaturesService.definitionProvider, this._editor.getModel(), new Position(range.startLineNumber, range.startColumn + 1), cancellationToken.token).then((candidateDefinitions => {
+				if (cancellationToken.token.isCancellationRequested) {
+					return;
+				}
+				if (candidateDefinitions.length !== 0) {
+					this._candidateDefinitionsLength = candidateDefinitions.length;
+					const childHTML: HTMLElement = textElement;
+					if (currentHTMLChild !== childHTML) {
+						sessionStore.clear();
+						currentHTMLChild = childHTML;
+						currentHTMLChild.style.textDecoration = 'underline';
+						sessionStore.add(toDisposable(() => {
+							currentHTMLChild.style.textDecoration = 'none';
+						}));
+					} else if (!currentHTMLChild) {
+						currentHTMLChild = childHTML;
+						currentHTMLChild.style.textDecoration = 'underline';
+						sessionStore.add(toDisposable(() => {
+							currentHTMLChild.style.textDecoration = 'none';
+						}));
+					}
+				} else {
+					sessionStore.clear();
+				}
+			}));
 		}));
-		linkGestureStore.add(gesture.onCancel(() => {
+		this._register(gesture.onCancel(() => {
 			sessionStore.clear();
 		}));
-		linkGestureStore.add(gesture.onExecute(async e => {
-			if ((e.target as unknown as CustomMouseEvent).detail !== this._stickyScrollWidget.getId()) {
+		this._register(gesture.onExecute(async e => {
+			if (e.target.type !== MouseTargetType.OVERLAY_WIDGET || e.target.detail !== this._stickyScrollWidget.getId()) {
+				// not hovering over our widget
 				return;
 			}
-			if (e.hasTriggerModifier) {
-				// Control click
-				if (this._candidateDefinitionsLength > 1) {
-					if (this._focused) {
-						this._disposeFocusStickyScrollStore();
-					}
-					this._revealPosition({ lineNumber: this._stickyScrollWidget.hoverOnLine, column: 1 });
-				}
-				this._instaService.invokeFunction(goToDefinitionWithLocation, e, this._editor as IActiveCodeEditor, { uri: this._editor.getModel()!.uri, range: this._stickyRangeProjectedOnEditor! });
-
-			} else if (!e.isRightClick) {
-				// Normal click
+			const position = this._stickyScrollWidget.getEditorPositionFromNode(e.target.element);
+			if (!position) {
+				// not hovering a sticky scroll line
+				return;
+			}
+			if (this._candidateDefinitionsLength > 1) {
 				if (this._focused) {
 					this._disposeFocusStickyScrollStore();
 				}
-				this._revealPosition({ lineNumber: this._stickyScrollWidget.hoverOnLine, column: this._stickyScrollWidget.hoverOnColumn });
+				this._revealPosition({ lineNumber: position.lineNumber, column: 1 });
 			}
+			this._instaService.invokeFunction(goToDefinitionWithLocation, e, this._editor as IActiveCodeEditor, { uri: this._editor.getModel()!.uri, range: this._stickyRangeProjectedOnEditor! });
 		}));
-		return linkGestureStore;
 	}
 
 	private _onContextMenu(e: MouseEvent) {
@@ -302,7 +375,6 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 
 	private _readConfiguration() {
 		const options = this._editor.getOption(EditorOption.stickyScroll);
-
 		if (options.enabled === false) {
 			this._editor.removeOverlayWidget(this._stickyScrollWidget);
 			this._sessionStore.clear();
@@ -311,16 +383,27 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 		} else if (options.enabled && !this._enabled) {
 			// When sticky scroll was just enabled, add the listeners on the sticky scroll
 			this._editor.addOverlayWidget(this._stickyScrollWidget);
-			this._sessionStore.add(this._editor.onDidScrollChange(() => this._renderStickyScroll()));
+			this._sessionStore.add(this._editor.onDidScrollChange((e) => {
+				if (e.scrollTopChanged) {
+					this._showEndForLine = null;
+					this._renderStickyScroll();
+				}
+			}));
 			this._sessionStore.add(this._editor.onDidLayoutChange(() => this._onDidResize()));
 			this._sessionStore.add(this._editor.onDidChangeModelTokens((e) => this._onTokensChange(e)));
-			this._sessionStore.add(this._stickyLineCandidateProvider.onDidChangeStickyScroll(() => this._renderStickyScroll()));
+			this._sessionStore.add(this._stickyLineCandidateProvider.onDidChangeStickyScroll(() => {
+				this._showEndForLine = null;
+				this._renderStickyScroll();
+			}));
 			this._enabled = true;
 		}
 
 		const lineNumberOption = this._editor.getOption(EditorOption.lineNumbers);
 		if (lineNumberOption.renderType === RenderLineNumbersType.Relative) {
-			this._sessionStore.add(this._editor.onDidChangeCursorPosition(() => this._renderStickyScroll()));
+			this._sessionStore.add(this._editor.onDidChangeCursorPosition(() => {
+				this._showEndForLine = null;
+				this._renderStickyScroll();
+			}));
 		}
 	}
 
@@ -344,39 +427,37 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 
 	private _onDidResize() {
 		const layoutInfo = this._editor.getLayoutInfo();
-		const width = layoutInfo.width - layoutInfo.minimap.minimapCanvasOuterWidth - layoutInfo.verticalScrollbarWidth;
-		this._stickyScrollWidget.getDomNode().style.width = `${width}px`;
 		// Make sure sticky scroll doesn't take up more than 25% of the editor
 		const theoreticalLines = layoutInfo.height / this._editor.getOption(EditorOption.lineHeight);
 		this._maxStickyLines = Math.round(theoreticalLines * .25);
 	}
 
 	private _renderStickyScroll() {
-		if (!(this._editor.hasModel())) {
+		const model = this._editor.getModel();
+		if (!model || model.isTooLargeForTokenization()) {
+			this._stickyScrollWidget.setState(undefined);
 			return;
 		}
-		const model = this._editor.getModel();
 		const stickyLineVersion = this._stickyLineCandidateProvider.getVersionId();
 		if (stickyLineVersion === undefined || stickyLineVersion === model.getVersionId()) {
 			this._widgetState = this.findScrollWidgetState();
-			this._stickyScrollVisibleContextKey.set(!(this._widgetState.lineNumbers.length === 0));
+			this._stickyScrollVisibleContextKey.set(!(this._widgetState.startLineNumbers.length === 0));
 
 			if (!this._focused) {
 				this._stickyScrollWidget.setState(this._widgetState);
 			} else {
-				this._stickyElements = this._stickyScrollWidget.getDomNode().children;
 				// Suppose that previously the sticky scroll widget had height 0, then if there are visible lines, set the last line as focused
 				if (this._focusedStickyElementIndex === -1) {
 					this._stickyScrollWidget.setState(this._widgetState);
-					this._focusedStickyElementIndex = this._stickyElements.length - 1;
+					this._focusedStickyElementIndex = this._stickyScrollWidget.lineNumberCount - 1;
 					if (this._focusedStickyElementIndex !== -1) {
-						(this._stickyElements.item(this._focusedStickyElementIndex) as HTMLDivElement).focus();
+						this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex);
 					}
 				} else {
 					const focusedStickyElementLineNumber = this._stickyScrollWidget.lineNumbers[this._focusedStickyElementIndex];
 					this._stickyScrollWidget.setState(this._widgetState);
 					// Suppose that after setting the state, there are no sticky lines, set the focused index to -1
-					if (this._stickyElements.length === 0) {
+					if (this._stickyScrollWidget.lineNumberCount === 0) {
 						this._focusedStickyElementIndex = -1;
 					} else {
 						const previousFocusedLineNumberExists = this._stickyScrollWidget.lineNumbers.includes(focusedStickyElementLineNumber);
@@ -384,9 +465,9 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 						// If the line number is still there, do not change anything
 						// If the line number is not there, set the new focused line to be the last line
 						if (!previousFocusedLineNumberExists) {
-							this._focusedStickyElementIndex = this._stickyElements.length - 1;
+							this._focusedStickyElementIndex = this._stickyScrollWidget.lineNumberCount - 1;
 						}
-						(this._stickyElements.item(this._focusedStickyElementIndex) as HTMLDivElement).focus();
+						this._stickyScrollWidget.focusLineWithIndex(this._focusedStickyElementIndex);
 					}
 				}
 			}
@@ -398,7 +479,8 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 		const maxNumberStickyLines = Math.min(this._maxStickyLines, this._editor.getOption(EditorOption.stickyScroll).maxLineCount);
 		const scrollTop: number = this._editor.getScrollTop();
 		let lastLineRelativePosition: number = 0;
-		const lineNumbers: number[] = [];
+		const startLineNumbers: number[] = [];
+		const endLineNumbers: number[] = [];
 		const arrayVisibleRanges = this._editor.getVisibleRanges();
 		if (arrayVisibleRanges.length !== 0) {
 			const fullVisibleRange = new StickyRange(arrayVisibleRanges[0].startLineNumber, arrayVisibleRanges[arrayVisibleRanges.length - 1].endLineNumber);
@@ -416,20 +498,23 @@ export class StickyScrollController extends Disposable implements IEditorContrib
 					const bottomOfEndLine = this._editor.getBottomForLineNumber(end) - scrollTop;
 
 					if (topOfElementAtDepth > topOfEndLine && topOfElementAtDepth <= bottomOfEndLine) {
-						lineNumbers.push(start);
+						startLineNumbers.push(start);
+						endLineNumbers.push(end + 1);
 						lastLineRelativePosition = bottomOfEndLine - bottomOfElementAtDepth;
 						break;
 					}
 					else if (bottomOfElementAtDepth > bottomOfBeginningLine && bottomOfElementAtDepth <= bottomOfEndLine) {
-						lineNumbers.push(start);
+						startLineNumbers.push(start);
+						endLineNumbers.push(end + 1);
 					}
-					if (lineNumbers.length === maxNumberStickyLines) {
+					if (startLineNumbers.length === maxNumberStickyLines) {
 						break;
 					}
 				}
 			}
 		}
-		return new StickyScrollWidgetState(lineNumbers, lastLineRelativePosition);
+		this._endLineNumbers = endLineNumbers;
+		return new StickyScrollWidgetState(startLineNumbers, endLineNumbers, lastLineRelativePosition, this._showEndForLine);
 	}
 
 	override dispose(): void {
