@@ -45,6 +45,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 		options._write(EditorOption.lineNumbersMinChars, input.lineNumbersMinChars);
 		options._write(EditorOption.lineDecorationsWidth, input.lineDecorationsWidth);
 		options._write(EditorOption.folding, false);
+		options._write(EditorOption.padding, { top: 0, bottom: 0 });
 		const minimapOptions: EditorMinimapOptions = {
 			enabled: input.minimap,
 			autohide: false,
@@ -95,6 +96,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 			typicalHalfwidthCharacterWidth: input.typicalHalfwidthCharacterWidth,
 			maxDigitWidth: input.maxDigitWidth,
 			pixelRatio: input.pixelRatio,
+			glyphMarginDecorationLaneCount: 1,
 		});
 		assert.deepStrictEqual(actual, expected);
 	}
@@ -126,6 +128,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -194,6 +197,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -262,6 +266,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -330,6 +335,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -398,6 +404,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -466,6 +473,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 50,
@@ -534,6 +542,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 50,
@@ -602,6 +611,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 60,
@@ -670,6 +680,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 30,
@@ -738,6 +749,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 30,
@@ -806,6 +818,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -874,6 +887,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -942,6 +956,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -1010,6 +1025,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 55,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 55,
 			lineNumbersWidth: 0,
@@ -1080,6 +1096,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -1150,6 +1167,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -1220,6 +1238,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -1290,6 +1309,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 0,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 0,
 			lineNumbersWidth: 0,
@@ -1358,6 +1378,7 @@ suite('Editor ViewLayout - EditorLayoutProvider', () => {
 
 			glyphMarginLeft: 0,
 			glyphMarginWidth: 30,
+			glyphMarginDecorationLaneCount: 1,
 
 			lineNumbersLeft: 30,
 			lineNumbersWidth: 36,
