@@ -7,24 +7,29 @@
 
 //*START
 export interface IElement {
-	tagName: string;
-	className: string;
-	textContent: string;
-	attributes: { [name: string]: string };
-	children: IElement[];
-	top: number;
-	left: number;
+	readonly tagName: string;
+	readonly className: string;
+	readonly textContent: string;
+	readonly attributes: { [name: string]: string };
+	readonly children: IElement[];
+	readonly top: number;
+	readonly left: number;
 }
 
 export interface ILocaleInfo {
-	language: string;
-	locale?: string;
+	readonly language: string;
+	readonly locale?: string;
 }
 
 export interface ILocalizedStrings {
-	open: string;
-	close: string;
-	find: string;
+	readonly open: string;
+	readonly close: string;
+	readonly find: string;
+}
+
+export interface ILogFile {
+	readonly relativePath: string;
+	readonly contents: string;
 }
 
 export interface IWindowDriver {
@@ -37,6 +42,7 @@ export interface IWindowDriver {
 	writeInTerminal(selector: string, text: string): Promise<void>;
 	getLocaleInfo(): Promise<ILocaleInfo>;
 	getLocalizedStrings(): Promise<ILocalizedStrings>;
+	getLogs(): Promise<ILogFile[]>;
 	exitApplication(): Promise<void>;
 }
 //*END
