@@ -17,16 +17,17 @@ export interface IExtensionSignatureVerificationService {
 	 * Verifies an extension file (.vsix) against a signature archive file.
 	 * @param { string } vsixFilePath The extension file path.
 	 * @param { string } signatureArchiveFilePath The signature archive file path.
+	 * @param { boolean } verbose A flag indicating whether or not to capture verbose detail in the event of an error.
 	 * @returns { Promise<boolean> } A promise with `true` if the extension is validly signed and trusted;
 	 * otherwise, `false` because verification is not enabled (e.g.:  in the OSS version of VS Code).
 	 * @throws { ExtensionSignatureVerificationError } An error with a code indicating the validity, integrity, or trust issue
 	 * found during verification or a more fundamental issue (e.g.:  a required dependency was not found).
 	 */
-	verify(vsixFilePath: string, signatureArchiveFilePath: string): Promise<boolean>;
+	verify(vsixFilePath: string, signatureArchiveFilePath: string, verbose: boolean): Promise<boolean>;
 }
 
 declare module vsceSign {
-	export function verify(vsixFilePath: string, signatureArchiveFilePath: string): Promise<boolean>;
+	export function verify(vsixFilePath: string, signatureArchiveFilePath: string, verbose: boolean): Promise<boolean>;
 }
 
 /**
@@ -34,6 +35,8 @@ declare module vsceSign {
  */
 export interface ExtensionSignatureVerificationError extends Error {
 	readonly code: string;
+	readonly didExecute: boolean;
+	readonly output?: string;
 }
 
 export class ExtensionSignatureVerificationService implements IExtensionSignatureVerificationService {
@@ -56,7 +59,7 @@ export class ExtensionSignatureVerificationService implements IExtensionSignatur
 		return this.moduleLoadingPromise;
 	}
 
-	public async verify(vsixFilePath: string, signatureArchiveFilePath: string): Promise<boolean> {
+	public async verify(vsixFilePath: string, signatureArchiveFilePath: string, verbose: boolean): Promise<boolean> {
 		let module: typeof vsceSign;
 
 		try {
@@ -65,6 +68,6 @@ export class ExtensionSignatureVerificationService implements IExtensionSignatur
 			return false;
 		}
 
-		return module.verify(vsixFilePath, signatureArchiveFilePath);
+		return module.verify(vsixFilePath, signatureArchiveFilePath, verbose);
 	}
 }
