@@ -3,7 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import * as spdlog from 'spdlog';
+import * as spdlog from '@vscode/spdlog';
 import { ByteSize } from 'vs/platform/files/common/files';
 import { AbstractMessageLogger, ILogger, LogLevel } from 'vs/platform/log/common/log';
 
@@ -20,8 +20,8 @@ enum SpdLogLevel {
 async function createSpdLogLogger(name: string, logfilePath: string, filesize: number, filecount: number, donotUseFormatters: boolean): Promise<spdlog.Logger | null> {
 	// Do not crash if spdlog cannot be loaded
 	try {
-		const _spdlog = await import('spdlog');
-		_spdlog.setFlushOn(LogLevel.Trace);
+		const _spdlog = await import('@vscode/spdlog');
+		_spdlog.setFlushOn(SpdLogLevel.Trace);
 		const logger = await _spdlog.createAsyncRotatingLogger(name, logfilePath, filesize, filecount);
 		if (donotUseFormatters) {
 			logger.clearFormatters();
@@ -47,7 +47,8 @@ function log(logger: spdlog.Logger, level: LogLevel, message: string): void {
 		case LogLevel.Info: logger.info(message); break;
 		case LogLevel.Warning: logger.warn(message); break;
 		case LogLevel.Error: logger.error(message); break;
-		default: throw new Error('Invalid log level');
+		case LogLevel.Off: /* do nothing */ break;
+		default: throw new Error(`Invalid log level ${level}`);
 	}
 }
 
@@ -59,7 +60,7 @@ function setLogLevel(logger: spdlog.Logger, level: LogLevel): void {
 		case LogLevel.Warning: logger.setLevel(SpdLogLevel.Warning); break;
 		case LogLevel.Error: logger.setLevel(SpdLogLevel.Error); break;
 		case LogLevel.Off: logger.setLevel(SpdLogLevel.Off); break;
-		default: throw new Error('Invalid log level');
+		default: throw new Error(`Invalid log level ${level}`);
 	}
 }
 
