@@ -214,7 +214,8 @@ export interface IQuickInput extends IDisposable {
 	description: string | undefined;
 
 	/**
-	 * Should be an HTMLElement (TODO: move this entire file into browser)
+	 * Should be an HTMLElement.
+	 * @deprecated Use an IQuickWidget instead
 	 */
 	widget: any | undefined;
 
@@ -222,6 +223,10 @@ export interface IQuickInput extends IDisposable {
 
 	totalSteps: number | undefined;
 
+	buttons: ReadonlyArray<IQuickInputButton>;
+
+	readonly onDidTriggerButton: Event<IQuickInputButton>;
+
 	enabled: boolean;
 
 	contextKey: string | undefined;
@@ -233,6 +238,15 @@ export interface IQuickInput extends IDisposable {
 	show(): void;
 
 	hide(): void;
+
+	didHide(reason?: QuickInputHideReason): void;
+}
+
+export interface IQuickWidget extends IQuickInput {
+	/**
+	 * Should be an HTMLElement (TODO: move this entire file into browser)
+	 */
+	widget: any | undefined;
 }
 
 export interface IQuickPickWillAcceptEvent {
@@ -297,10 +311,6 @@ export interface IQuickPick<T extends IQuickPickItem> extends IQuickInput {
 
 	customHover: string | undefined;
 
-	buttons: ReadonlyArray<IQuickInputButton>;
-
-	readonly onDidTriggerButton: Event<IQuickInputButton>;
-
 	readonly onDidTriggerItemButton: Event<IQuickPickItemButtonEvent<T>>;
 
 	readonly onDidTriggerSeparatorButton: Event<IQuickPickSeparatorButtonEvent>;
@@ -413,16 +423,6 @@ export interface IInputBox extends IQuickInput {
 	 */
 	readonly onDidAccept: Event<void>;
 
-	/**
-	 * Buttons to show in addition to user input submission.
-	 */
-	buttons: ReadonlyArray<IQuickInputButton>;
-
-	/**
-	 * Event called when a button is selected.
-	 */
-	readonly onDidTriggerButton: Event<IQuickInputButton>;
-
 	/**
 	 * Text show below the input box.
 	 */
@@ -554,10 +554,15 @@ export interface IQuickInputService {
 	createQuickPick<T extends IQuickPickItem>(): IQuickPick<T>;
 
 	/**
-	 * Provides raw access to the quick input controller.
+	 * Provides raw access to the input box controller.
 	 */
 	createInputBox(): IInputBox;
 
+	/**
+	 * Provides raw access to the quick widget controller.
+	 */
+	createQuickWidget(): IQuickWidget;
+
 	/**
 	 * Moves focus into quick input.
 	 */
