@@ -3,7 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { CONFIGURATION_KEY_HOST_NAME, CONFIGURATION_KEY_PREVENT_SLEEP, ConnectionInfo, IRemoteTunnelSession, IRemoteTunnelService, LOGGER_NAME, LOG_ID, TunnelStates, TunnelStatus } from 'vs/platform/remoteTunnel/common/remoteTunnel';
+import { CONFIGURATION_KEY_HOST_NAME, CONFIGURATION_KEY_PREVENT_SLEEP, ConnectionInfo, IRemoteTunnelSession, IRemoteTunnelService, LOGGER_NAME, LOG_ID, TunnelStates, TunnelStatus, TunnelMode, INACTIVE_TUNNEL_MODE, ActiveTunnelMode } from 'vs/platform/remoteTunnel/common/remoteTunnel';
 import { Emitter } from 'vs/base/common/event';
 import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
 import { INativeEnvironmentService } from 'vs/platform/environment/common/environment';
@@ -20,15 +20,18 @@ import { localize } from 'vs/nls';
 import { hostname, homedir } from 'os';
 import { IStorageService, StorageScope, StorageTarget } from 'vs/platform/storage/common/storage';
 import { isString } from 'vs/base/common/types';
+import { StreamSplitter } from 'vs/base/node/nodeStreams';
 
 type RemoteTunnelEnablementClassification = {
 	owner: 'aeschli';
 	comment: 'Reporting when Remote Tunnel access is turned on or off';
 	enabled?: { classification: 'SystemMetaData'; purpose: 'FeatureInsight'; isMeasurement: true; comment: 'Flag indicating if Remote Tunnel Access is enabled or not' };
+	service?: { classification: 'SystemMetaData'; purpose: 'FeatureInsight'; isMeasurement: true; comment: 'Flag indicating if Remote Tunnel Access is installed as a service' };
 };
 
 type RemoteTunnelEnablementEvent = {
 	enabled: boolean;
+	service: boolean;
 };
 
 const restartTunnelOnConfigurationChanges: readonly string[] = [
@@ -40,6 +43,8 @@ const restartTunnelOnConfigurationChanges: readonly string[] = [
 // if set, the remote tunnel access is currently enabled.
 // if not set, the remote tunnel access is currently disabled.
 const TUNNEL_ACCESS_SESSION = 'remoteTunnelSession';
+// Boolean indicating whether the tunnel should be installed as a service.
+const TUNNEL_ACCESS_IS_SERVICE = 'remoteTunnelIsService';
 
 /**
  * This service runs on the shared service. It is running the `code-tunnel` command
@@ -55,12 +60,19 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 	private readonly _onDidChangeTunnelStatusEmitter = new Emitter<TunnelStatus>();
 	public readonly onDidChangeTunnelStatus = this._onDidChangeTunnelStatusEmitter.event;
 
-	private readonly _onDidChangeSessionEmitter = new Emitter<IRemoteTunnelSession | undefined>();
-	public readonly onDidChangeSession = this._onDidChangeSessionEmitter.event;
+	private readonly _onDidChangeModeEmitter = new Emitter<TunnelMode>();
+	public readonly onDidChangeMode = this._onDidChangeModeEmitter.event;
 
 	private readonly _logger: ILogger;
 
-	private _session: IRemoteTunnelSession | undefined;
+	/**
+	 * "Mode" in the terminal state we want to get to -- started, stopped, and
+	 * the attributes associated with each.
+	 *
+	 * At any given time, work may be ongoing to get `_tunnelStatus` into a
+	 * state that reflects the desired `mode`.
+	 */
+	private _mode: TunnelMode = INACTIVE_TUNNEL_MODE;
 
 	private _tunnelProcess: CancelablePromise<any> | undefined;
 
@@ -98,7 +110,7 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 			}
 		}));
 
-		this._session = this._restoreSession();
+		this._mode = this._restoreMode();
 		this._tunnelStatus = TunnelStates.uninitialized;
 	}
 
@@ -111,32 +123,34 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 		this._onDidChangeTunnelStatusEmitter.fire(tunnelStatus);
 	}
 
-	private setSession(session: IRemoteTunnelSession | undefined) {
-		if (!isSameSession(session, this._session)) {
-			this._session = session;
-			this._onDidChangeSessionEmitter.fire(session);
-			this._storeSession(session);
-			if (session) {
-				this._logger.info(`Session updated: ${session.accountLabel} (${session.providerId})`);
-				if (session.token) {
-					this._logger.info(`Session token updated: ${session.accountLabel} (${session.providerId})`);
-				}
-			} else {
-				this._logger.info(`Session reset`);
+	private setMode(mode: TunnelMode) {
+		if (isSameMode(this._mode, mode)) {
+			return;
+		}
+
+		this._mode = mode;
+		this._storeMode(mode);
+		this._onDidChangeModeEmitter.fire(this._mode);
+		if (mode.active) {
+			this._logger.info(`Session updated: ${mode.session.accountLabel} (${mode.session.providerId}) (service=${mode.asService})`);
+			if (mode.session.token) {
+				this._logger.info(`Session token updated: ${mode.session.accountLabel} (${mode.session.providerId})`);
 			}
+		} else {
+			this._logger.info(`Session reset`);
 		}
 	}
 
-	async getSession(): Promise<IRemoteTunnelSession | undefined> {
-		return this._session;
+	getMode(): Promise<TunnelMode> {
+		return Promise.resolve(this._mode);
 	}
 
-	async initialize(session: IRemoteTunnelSession | undefined): Promise<TunnelStatus> {
+	async initialize(mode: TunnelMode): Promise<TunnelStatus> {
 		if (this._initialized) {
 			return this._tunnelStatus;
 		}
 		this._initialized = true;
-		this.setSession(session);
+		this.setMode(mode);
 		try {
 			await this._startTunnelProcessDelayer.trigger(() => this.updateTunnelProcess());
 		} catch (e) {
@@ -145,6 +159,14 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 		return this._tunnelStatus;
 	}
 
+	private readonly defaultOnOutput = (a: string, isErr: boolean) => {
+		if (isErr) {
+			this._logger.error(a);
+		} else {
+			this._logger.info(a);
+		}
+	};
+
 	private getTunnelCommandLocation() {
 		if (!this._tunnelCommand) {
 			let binParentLocation;
@@ -164,11 +186,12 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 		return this._tunnelCommand;
 	}
 
-	async startTunnel(session: IRemoteTunnelSession): Promise<TunnelStatus> {
-		if (isSameSession(session, this._session)) {
+	async startTunnel(mode: ActiveTunnelMode): Promise<TunnelStatus> {
+		if (isSameMode(this._mode, mode) && this._tunnelStatus.type !== 'disconnected') {
 			return this._tunnelStatus;
 		}
-		this.setSession(session);
+
+		this.setMode(mode);
 
 		try {
 			await this._startTunnelProcessDelayer.trigger(() => this.updateTunnelProcess());
@@ -180,74 +203,95 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 
 
 	async stopTunnel(): Promise<void> {
-		this.setSession(undefined);
-
 		if (this._tunnelProcess) {
 			this._tunnelProcess.cancel();
 			this._tunnelProcess = undefined;
 		}
 
-		const onOutput = (a: string, isErr: boolean) => {
-			if (isErr) {
-				this._logger.error(a);
-			} else {
-				this._logger.info(a);
-			}
-		};
+		if (!this._mode.active) {
+			return;
+		}
+
+		// Be careful to only uninstall the service if we're the ones who installed it:
+		const needsServiceUninstall = this._mode.asService;
+		this.setMode(INACTIVE_TUNNEL_MODE);
+
 		try {
-			await this.runCodeTunneCommand('stop', ['kill'], onOutput);
+			if (needsServiceUninstall) {
+				this.runCodeTunnelCommand('uninstallService', ['service', 'uninstall']);
+			}
 		} catch (e) {
 			this._logger.error(e);
 		}
-		this.setTunnelStatus(TunnelStates.disconnected());
 
+		try {
+			await this.runCodeTunnelCommand('stop', ['kill']);
+		} catch (e) {
+			this._logger.error(e);
+		}
+
+		this.setTunnelStatus(TunnelStates.disconnected());
 	}
 
 	private async updateTunnelProcess(): Promise<void> {
-		this.telemetryService.publicLog2<RemoteTunnelEnablementEvent, RemoteTunnelEnablementClassification>('remoteTunnel.enablement', { enabled: !!this._session });
-
+		this.telemetryService.publicLog2<RemoteTunnelEnablementEvent, RemoteTunnelEnablementClassification>('remoteTunnel.enablement', {
+			enabled: this._mode.active,
+			service: this._mode.active && this._mode.asService,
+		});
 
 		if (this._tunnelProcess) {
 			this._tunnelProcess.cancel();
 			this._tunnelProcess = undefined;
 		}
 
-		let isAttached = false;
-
+		let output = '';
+		let isServiceInstalled = false;
 		const onOutput = (a: string, isErr: boolean) => {
 			if (isErr) {
 				this._logger.error(a);
 			} else {
-				this._logger.info(a);
+				output += a;
 			}
 			if (!this.environmentService.isBuilt && a.startsWith('   Compiling')) {
 				this.setTunnelStatus(TunnelStates.connecting(localize('remoteTunnelService.building', 'Building CLI from sources')));
 			}
 		};
 
-		const statusProcess = this.runCodeTunneCommand('status', ['status'], onOutput);
+		const statusProcess = this.runCodeTunnelCommand('status', ['status'], onOutput);
 		this._tunnelProcess = statusProcess;
 		try {
-			const status = await statusProcess;
+			await statusProcess;
 			if (this._tunnelProcess !== statusProcess) {
 				return;
 			}
-			isAttached = status === 0;
-			this._logger.info(isAttached ? 'Other tunnel running, attaching...' : 'No other tunnel running');
-			if (!isAttached && !this._session) {
-				this._tunnelProcess = undefined;
+
+			// split and find the line, since in dev builds additional noise is
+			// added by cargo to the output.
+			const status: {
+				service_installed: boolean;
+				tunnel: object | null;
+			} = JSON.parse(output.trim().split('\n').find(l => l.startsWith('{'))!);
+
+			isServiceInstalled = status.service_installed;
+			this._logger.info(status.tunnel ? 'Other tunnel running, attaching...' : 'No other tunnel running');
+
+			// If a tunnel is running but the mode isn't "active", we'll still attach
+			// to the tunnel to show its state in the UI. If neither are true, disconnect
+			if (!status.tunnel && !this._mode.active) {
 				this.setTunnelStatus(TunnelStates.disconnected());
 				return;
 			}
 		} catch (e) {
 			this._logger.error(e);
-			this._tunnelProcess = undefined;
 			this.setTunnelStatus(TunnelStates.disconnected());
 			return;
+		} finally {
+			if (this._tunnelProcess === statusProcess) {
+				this._tunnelProcess = undefined;
+			}
 		}
 
-		const session = this._session;
-
+		const session = this._mode.active ? this._mode.session : undefined;
 		if (session && session.token) {
 			const token = session.token;
 			this.setTunnelStatus(TunnelStates.connecting(localize({ key: 'remoteTunnelService.authorizing', comment: ['{0} is a user account name, {1} a provider name (e.g. Github)'] }, 'Connecting as {0} ({1})', session.accountLabel, session.providerId)));
@@ -255,7 +299,7 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 				a = a.replaceAll(token, '*'.repeat(4));
 				onOutput(a, isErr);
 			};
-			const loginProcess = this.runCodeTunneCommand('login', ['user', 'login', '--provider', session.providerId, '--access-token', token, '--log', LogLevelToString(this._logger.getLevel())], onLoginOutput);
+			const loginProcess = this.runCodeTunnelCommand('login', ['user', 'login', '--provider', session.providerId, '--access-token', token, '--log', LogLevelToString(this._logger.getLevel())], onLoginOutput);
 			this._tunnelProcess = loginProcess;
 			try {
 				await loginProcess;
@@ -277,25 +321,67 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 		} else {
 			this.setTunnelStatus(TunnelStates.connecting(localize('remoteTunnelService.openTunnel', 'Opening tunnel')));
 		}
-		const args = ['--parent-process-id', String(process.pid), '--accept-server-license-terms', '--log', LogLevelToString(this._logger.getLevel())];
+		const args = ['--accept-server-license-terms', '--log', LogLevelToString(this._logger.getLevel())];
 		if (hostName) {
 			args.push('--name', hostName);
 		} else {
 			args.push('--random-name');
 		}
+
+		let serviceInstallFailed = false;
+		if (this._mode.active && this._mode.asService && !isServiceInstalled) {
+			// I thought about calling `code tunnel kill` here, but having multiple
+			// tunnel processes running is pretty much idempotent. If there's
+			// another tunnel process running, the service process will
+			// take over when it exits, no hard feelings.
+			serviceInstallFailed = await this.installTunnelService(args) === false;
+		}
+
+		return this.serverOrAttachTunnel(session, args, serviceInstallFailed);
+	}
+
+	private async installTunnelService(args: readonly string[]) {
+		let status: number;
+		try {
+			status = await this.runCodeTunnelCommand('serviceInstall', ['service', 'install', ...args]);
+		} catch (e) {
+			this._logger.error(e);
+			status = 1;
+		}
+
+		if (status !== 0) {
+			const msg = localize('remoteTunnelService.serviceInstallFailed', 'Failed to install tunnel as a service, starting in session...');
+			this._logger.warn(msg);
+			this.setTunnelStatus(TunnelStates.connecting(msg));
+			return false;
+		}
+
+		return true;
+	}
+
+	private async serverOrAttachTunnel(session: IRemoteTunnelSession | undefined, args: string[], serviceInstallFailed: boolean) {
+		args.push('--parent-process-id', String(process.pid));
+
 		if (this._preventSleep()) {
 			args.push('--no-sleep');
 		}
-		const serveCommand = this.runCodeTunneCommand('tunnel', args, (message: string, isErr: boolean) => {
+
+		let isAttached = false;
+		const serveCommand = this.runCodeTunnelCommand('tunnel', args, (message: string, isErr: boolean) => {
 			if (isErr) {
 				this._logger.error(message);
 			} else {
 				this._logger.info(message);
 			}
+
+			if (message.includes('Connected to an existing tunnel process')) {
+				isAttached = true;
+			}
+
 			const m = message.match(/Open this link in your browser (https:\/\/([^\/\s]+)\/([^\/\s]+)\/([^\/\s]+))/);
 			if (m) {
 				const info: ConnectionInfo = { link: m[1], domain: m[2], tunnelName: m[4], isAttached };
-				this.setTunnelStatus(TunnelStates.connected(info));
+				this.setTunnelStatus(TunnelStates.connected(info, serviceInstallFailed));
 			} else if (message.match(/error refreshing token/)) {
 				serveCommand.cancel();
 				this._onDidTokenFailedEmitter.fire(session);
@@ -308,14 +394,14 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 				// process exited unexpectedly
 				this._logger.info(`tunnel process terminated`);
 				this._tunnelProcess = undefined;
-				this._session = undefined;
+				this._mode = INACTIVE_TUNNEL_MODE;
 
 				this.setTunnelStatus(TunnelStates.disconnected());
 			}
 		});
 	}
 
-	private runCodeTunneCommand(logLabel: string, commandArgs: string[], onOutput: (message: string, isError: boolean) => void = () => { }): CancelablePromise<number> {
+	private runCodeTunnelCommand(logLabel: string, commandArgs: string[], onOutput: (message: string, isError: boolean) => void = this.defaultOnOutput): CancelablePromise<number> {
 		return createCancelablePromise<number>(token => {
 			return new Promise((resolve, reject) => {
 				if (token.isCancellationRequested) {
@@ -331,23 +417,23 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 					}
 				});
 				if (!this.environmentService.isBuilt) {
-					onOutput('Building tunnel CLI from sources and run', false);
-					onOutput(`${logLabel} Spawning: cargo run -- tunnel ${commandArgs.join(' ')}`, false);
+					onOutput('Building tunnel CLI from sources and run\n', false);
+					onOutput(`${logLabel} Spawning: cargo run -- tunnel ${commandArgs.join(' ')}\n`, false);
 					tunnelProcess = spawn('cargo', ['run', '--', 'tunnel', ...commandArgs], { cwd: join(this.environmentService.appRoot, 'cli'), stdio });
 				} else {
-					onOutput('Running tunnel CLI', false);
+					onOutput('Running tunnel CLI\n', false);
 					const tunnelCommand = this.getTunnelCommandLocation();
-					onOutput(`${logLabel} Spawning: ${tunnelCommand} tunnel ${commandArgs.join(' ')}`, false);
+					onOutput(`${logLabel} Spawning: ${tunnelCommand} tunnel ${commandArgs.join(' ')}\n`, false);
 					tunnelProcess = spawn(tunnelCommand, ['tunnel', ...commandArgs], { cwd: homedir(), stdio });
 				}
 
-				tunnelProcess.stdout!.on('data', data => {
+				tunnelProcess.stdout!.pipe(new StreamSplitter('\n')).on('data', data => {
 					if (tunnelProcess) {
 						const message = data.toString();
 						onOutput(message, false);
 					}
 				});
-				tunnelProcess.stderr!.on('data', data => {
+				tunnelProcess.stderr!.pipe(new StreamSplitter('\n')).on('data', data => {
 					if (tunnelProcess) {
 						const message = data.toString();
 						onOutput(message, true);
@@ -385,30 +471,33 @@ export class RemoteTunnelService extends Disposable implements IRemoteTunnelServ
 		return name || undefined;
 	}
 
-	private _restoreSession(): IRemoteTunnelSession | undefined {
+	private _restoreMode(): TunnelMode {
 		try {
 			const tunnelAccessSession = this.storageService.get(TUNNEL_ACCESS_SESSION, StorageScope.APPLICATION);
+			const asService = this.storageService.getBoolean(TUNNEL_ACCESS_IS_SERVICE, StorageScope.APPLICATION, false);
 			if (tunnelAccessSession) {
 				const session = JSON.parse(tunnelAccessSession) as IRemoteTunnelSession;
 				if (session && isString(session.accountLabel) && isString(session.sessionId) && isString(session.providerId)) {
-					return session;
+					return { active: true, session, asService };
 				}
 				this._logger.error('Problems restoring session from storage, invalid format', session);
 			}
 		} catch (e) {
 			this._logger.error('Problems restoring session from storage', e);
 		}
-		return undefined;
+		return INACTIVE_TUNNEL_MODE;
 	}
 
-	private _storeSession(session: IRemoteTunnelSession | undefined): void {
-		if (session) {
+	private _storeMode(mode: TunnelMode): void {
+		if (mode.active) {
 			const sessionWithoutToken = {
-				providerId: session.providerId, sessionId: session.sessionId, accountLabel: session.accountLabel
+				providerId: mode.session.providerId, sessionId: mode.session.sessionId, accountLabel: mode.session.accountLabel
 			};
 			this.storageService.store(TUNNEL_ACCESS_SESSION, JSON.stringify(sessionWithoutToken), StorageScope.APPLICATION, StorageTarget.MACHINE);
+			this.storageService.store(TUNNEL_ACCESS_IS_SERVICE, mode.asService, StorageScope.APPLICATION, StorageTarget.MACHINE);
 		} else {
 			this.storageService.remove(TUNNEL_ACCESS_SESSION, StorageScope.APPLICATION);
+			this.storageService.remove(TUNNEL_ACCESS_IS_SERVICE, StorageScope.APPLICATION);
 		}
 	}
 }
@@ -420,3 +509,12 @@ function isSameSession(a1: IRemoteTunnelSession | undefined, a2: IRemoteTunnelSe
 	return a1 === a2;
 }
 
+const isSameMode = (a: TunnelMode, b: TunnelMode) => {
+	if (a.active !== b.active) {
+		return false;
+	} else if (a.active && b.active) {
+		return a.asService === b.asService && isSameSession(a.session, b.session);
+	} else {
+		return true;
+	}
+};
