@@ -8,7 +8,7 @@ import { basename } from 'vs/base/common/path';
 import { localize } from 'vs/nls';
 import { CancellationToken, CancellationTokenSource } from 'vs/base/common/cancellation';
 import { toErrorMessage } from 'vs/base/common/errorMessage';
-import { canceled, isCancellationError } from 'vs/base/common/errors';
+import { CancellationError, isCancellationError } from 'vs/base/common/errors';
 import { IProcessEnvironment, isWindows, OS } from 'vs/base/common/platform';
 import { generateUuid } from 'vs/base/common/uuid';
 import { getSystemShell } from 'vs/base/node/shell';
@@ -16,13 +16,8 @@ import { NativeParsedArgs } from 'vs/platform/environment/common/argv';
 import { isLaunchedFromCli } from 'vs/platform/environment/node/argvHelper';
 import { ILogService } from 'vs/platform/log/common/log';
 import { Promises } from 'vs/base/common/async';
-
-/**
- * The maximum of time we accept to wait on resolving the shell
- * environment before giving up. This ensures we are not blocking
- * other tasks from running for a too long time period.
- */
-const MAX_SHELL_RESOLVE_TIME = 10000;
+import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
+import { clamp } from 'vs/base/common/numbers';
 
 let unixShellEnvPromise: Promise<typeof process.env> | undefined = undefined;
 
@@ -34,7 +29,7 @@ let unixShellEnvPromise: Promise<typeof process.env> | undefined = undefined;
  * - we hit a timeout of `MAX_SHELL_RESOLVE_TIME`
  * - any other error from spawning a shell to figure out the environment
  */
-export async function getResolvedShellEnv(logService: ILogService, args: NativeParsedArgs, env: IProcessEnvironment): Promise<typeof process.env> {
+export async function getResolvedShellEnv(configurationService: IConfigurationService, logService: ILogService, args: NativeParsedArgs, env: IProcessEnvironment): Promise<typeof process.env> {
 
 	// Skip if --force-disable-user-env
 	if (args['force-disable-user-env']) {
@@ -72,11 +67,17 @@ export async function getResolvedShellEnv(logService: ILogService, args: NativeP
 			unixShellEnvPromise = Promises.withAsyncBody<NodeJS.ProcessEnv>(async (resolve, reject) => {
 				const cts = new CancellationTokenSource();
 
+				let timeoutValue = 10000; // default to 10 seconds
+				const configuredTimeoutValue = configurationService.getValue<unknown>('application.shellEnvironmentResolutionTimeout');
+				if (typeof configuredTimeoutValue === 'number') {
+					timeoutValue = clamp(configuredTimeoutValue, 1, 120) * 1000 /* convert from seconds */;
+				}
+
 				// Give up resolving shell env after some time
 				const timeout = setTimeout(() => {
 					cts.dispose(true);
 					reject(new Error(localize('resolveShellEnvTimeout', "Unable to resolve your shell environment in a reasonable time. Please review your shell configuration and restart.")));
-				}, MAX_SHELL_RESOLVE_TIME);
+				}, timeoutValue);
 
 				// Resolve shell env and handle errors
 				try {
@@ -121,7 +122,7 @@ async function doResolveUnixShellEnv(logService: ILogService, token: Cancellatio
 
 	return new Promise<typeof process.env>((resolve, reject) => {
 		if (token.isCancellationRequested) {
-			return reject(canceled());
+			return reject(new CancellationError());
 		}
 
 		// handle popular non-POSIX shells
@@ -133,13 +134,16 @@ async function doResolveUnixShellEnv(logService: ILogService, token: Cancellatio
 			// you escape single quotes inside of a single quoted string.
 			command = `& '${process.execPath}' ${extraArgs} -p '''${mark}'' + JSON.stringify(process.env) + ''${mark}'''`;
 			shellArgs = ['-Login', '-Command'];
+		} else if (name === 'nu') { // nushell requires ^ before quoted path to treat it as a command
+			command = `^'${process.execPath}' ${extraArgs} -p '"${mark}" + JSON.stringify(process.env) + "${mark}"'`;
+			shellArgs = ['-i', '-l', '-c'];
 		} else {
 			command = `'${process.execPath}' ${extraArgs} -p '"${mark}" + JSON.stringify(process.env) + "${mark}"'`;
 
-			if (name === 'tcsh') {
+			if (name === 'tcsh' || name === 'csh') {
 				shellArgs = ['-ic'];
 			} else {
-				shellArgs = ['-ilc'];
+				shellArgs = ['-i', '-l', '-c'];
 			}
 		}
 
@@ -154,7 +158,7 @@ async function doResolveUnixShellEnv(logService: ILogService, token: Cancellatio
 		token.onCancellationRequested(() => {
 			child.kill();
 
-			return reject(canceled());
+			return reject(new CancellationError());
 		});
 
 		child.on('error', err => {
