@@ -5,7 +5,8 @@
 
 import { fail, strictEqual } from 'assert';
 import { TestInstantiationService } from 'vs/platform/instantiation/test/common/instantiationServiceMock';
-import { ConsoleLogger, ILogService, LogService } from 'vs/platform/log/common/log';
+import { ConsoleLogger, ILogService } from 'vs/platform/log/common/log';
+import { LogService } from 'vs/platform/log/common/logService';
 import { RequestStore } from 'vs/platform/terminal/common/requestStore';
 
 suite('RequestStore', () => {
@@ -16,6 +17,10 @@ suite('RequestStore', () => {
 		instantiationService.stub(ILogService, new LogService(new ConsoleLogger()));
 	});
 
+	teardown(() => {
+		instantiationService.dispose();
+	});
+
 	test('should resolve requests', async () => {
 		const store: RequestStore<{ data: string }, { arg: string }> = instantiationService.createInstance(RequestStore<{ data: string }, { arg: string }>, undefined);
 		let eventArgs: { requestId: number; arg: string } | undefined;
