@@ -178,4 +178,61 @@ suite('UserDataProfileService (Common)', () => {
 		assert.deepStrictEqual(testObject.profiles[1].id, profile.id);
 	});
 
+	test('profile using default profile for settings', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { settings: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { settings: true });
+		assert.strictEqual(profile.settingsResource.toString(), testObject.defaultProfile.settingsResource.toString());
+	});
+
+	test('profile using default profile for keybindings', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { keybindings: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { keybindings: true });
+		assert.strictEqual(profile.keybindingsResource.toString(), testObject.defaultProfile.keybindingsResource.toString());
+	});
+
+	test('profile using default profile for snippets', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { snippets: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { snippets: true });
+		assert.strictEqual(profile.snippetsHome.toString(), testObject.defaultProfile.snippetsHome.toString());
+	});
+
+	test('profile using default profile for tasks', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { tasks: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { tasks: true });
+		assert.strictEqual(profile.tasksResource.toString(), testObject.defaultProfile.tasksResource.toString());
+	});
+
+	test('profile using default profile for global state', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { globalState: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { globalState: true });
+		assert.strictEqual(profile.globalStorageHome.toString(), testObject.defaultProfile.globalStorageHome.toString());
+	});
+
+	test('profile using default profile for extensions', async () => {
+		const profile = await testObject.createNamedProfile('name', { useDefaultFlags: { extensions: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { extensions: true });
+		assert.strictEqual(profile.extensionsResource.toString(), testObject.defaultProfile.extensionsResource.toString());
+	});
+
+	test('update profile using default profile for keybindings', async () => {
+		let profile = await testObject.createNamedProfile('name');
+		profile = await testObject.updateProfile(profile, { useDefaultFlags: { keybindings: true } });
+
+		assert.strictEqual(profile.isDefault, false);
+		assert.deepStrictEqual(profile.useDefaultFlags, { keybindings: true });
+		assert.strictEqual(profile.keybindingsResource.toString(), testObject.defaultProfile.keybindingsResource.toString());
+	});
+
 });
