@@ -5,71 +5,19 @@
 
 import * as assert from 'assert';
 import { timeout } from 'vs/base/common/async';
-import { newWriteableBufferStream, VSBuffer } from 'vs/base/common/buffer';
+import { newWriteableBufferStream } from 'vs/base/common/buffer';
 import { CancellationToken } from 'vs/base/common/cancellation';
 import { Event } from 'vs/base/common/event';
 import { DisposableStore } from 'vs/base/common/lifecycle';
 import { isWeb } from 'vs/base/common/platform';
-import { ConfigurationSyncStore } from 'vs/base/common/product';
-import { URI } from 'vs/base/common/uri';
 import { runWithFakedTimers } from 'vs/base/test/common/timeTravelScheduler';
-import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
-import { IFileService } from 'vs/platform/files/common/files';
 import { NullLogService } from 'vs/platform/log/common/log';
-import product from 'vs/platform/product/common/product';
 import { IProductService } from 'vs/platform/product/common/productService';
 import { IRequestService } from 'vs/platform/request/common/request';
-import { IUserDataProfilesService } from 'vs/platform/userDataProfile/common/userDataProfile';
-import { IUserDataSyncStore, IUserDataSyncStoreManagementService, IUserDataSyncStoreService, SyncResource, UserDataSyncErrorCode, UserDataSyncStoreError } from 'vs/platform/userDataSync/common/userDataSync';
-import { RequestsSession, UserDataSyncStoreManagementService, UserDataSyncStoreService } from 'vs/platform/userDataSync/common/userDataSyncStoreService';
+import { IUserDataSyncStoreService, SyncResource, UserDataSyncErrorCode, UserDataSyncStoreError } from 'vs/platform/userDataSync/common/userDataSync';
+import { RequestsSession, UserDataSyncStoreService } from 'vs/platform/userDataSync/common/userDataSyncStoreService';
 import { UserDataSyncClient, UserDataSyncTestServer } from 'vs/platform/userDataSync/test/common/userDataSyncClient';
 
-suite('UserDataSyncStoreManagementService', () => {
-	const disposableStore = new DisposableStore();
-
-	teardown(() => disposableStore.clear());
-
-	test('test sync store is read from settings', async () => {
-		const client = disposableStore.add(new UserDataSyncClient(new UserDataSyncTestServer()));
-		await client.setUp();
-
-		client.instantiationService.stub(IProductService, {
-			_serviceBrand: undefined, ...product, ...{
-				'configurationSync.store': undefined
-			}
-		});
-
-		const configuredStore: ConfigurationSyncStore = {
-			url: 'http://configureHost:3000',
-			stableUrl: 'http://configureHost:3000',
-			insidersUrl: 'http://configureHost:3000',
-			canSwitch: false,
-			authenticationProviders: { 'configuredAuthProvider': { scopes: [] } }
-		};
-		await client.instantiationService.get(IFileService).writeFile(client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource, VSBuffer.fromString(JSON.stringify({
-			'configurationSync.store': configuredStore
-		})));
-		await client.instantiationService.get(IConfigurationService).reloadConfiguration();
-
-		const expected: IUserDataSyncStore = {
-			url: URI.parse('http://configureHost:3000'),
-			type: 'stable',
-			defaultUrl: URI.parse('http://configureHost:3000'),
-			stableUrl: URI.parse('http://configureHost:3000'),
-			insidersUrl: URI.parse('http://configureHost:3000'),
-			canSwitch: false,
-			authenticationProviders: [{ id: 'configuredAuthProvider', scopes: [] }]
-		};
-
-		const testObject: IUserDataSyncStoreManagementService = disposableStore.add(client.instantiationService.createInstance(UserDataSyncStoreManagementService));
-
-		assert.strictEqual(testObject.userDataSyncStore?.url.toString(), expected.url.toString());
-		assert.strictEqual(testObject.userDataSyncStore?.defaultUrl.toString(), expected.defaultUrl.toString());
-		assert.deepStrictEqual(testObject.userDataSyncStore?.authenticationProviders, expected.authenticationProviders);
-	});
-
-});
-
 suite('UserDataSyncStoreService', () => {
 
 	const disposableStore = new DisposableStore();
