@@ -25,10 +25,10 @@ import { FileService } from 'vs/platform/files/common/fileService';
 import { NullLogService } from 'vs/platform/log/common/log';
 import product from 'vs/platform/product/common/product';
 import { IProductService } from 'vs/platform/product/common/productService';
-import { StateMainService } from 'vs/platform/state/electron-main/stateMainService';
+import { SaveStrategy, StateService } from 'vs/platform/state/node/stateService';
 import { UriIdentityService } from 'vs/platform/uriIdentity/common/uriIdentityService';
 import { UserDataProfilesMainService } from 'vs/platform/userDataProfile/electron-main/userDataProfile';
-import { IRawFileWorkspaceFolder, IRawUriWorkspaceFolder, IWorkspaceIdentifier, WORKSPACE_EXTENSION } from 'vs/platform/workspace/common/workspace';
+import { IRawFileWorkspaceFolder, IRawUriWorkspaceFolder, WORKSPACE_EXTENSION } from 'vs/platform/workspace/common/workspace';
 import { IStoredWorkspace, IStoredWorkspaceFolder, IWorkspaceFolderCreationData, rewriteWorkspaceFileForNewLocation } from 'vs/platform/workspaces/common/workspaces';
 import { WorkspacesManagementMainService } from 'vs/platform/workspaces/electron-main/workspacesManagementMainService';
 
@@ -52,15 +52,12 @@ flakySuite('WorkspacesManagementMainService', () => {
 		declare readonly _serviceBrand: undefined;
 
 		isHotExitEnabled(): boolean { throw new Error('Method not implemented.'); }
-		getWorkspaceBackups(): IWorkspaceBackupInfo[] { throw new Error('Method not implemented.'); }
-		getFolderBackupPaths(): IFolderBackupInfo[] { throw new Error('Method not implemented.'); }
-		getEmptyWindowBackupPaths(): IEmptyWindowBackupInfo[] { throw new Error('Method not implemented.'); }
-		registerWorkspaceBackupSync(workspace: IWorkspaceBackupInfo, migrateFrom?: string | undefined): string { throw new Error('Method not implemented.'); }
-		registerFolderBackupSync(folder: IFolderBackupInfo): string { throw new Error('Method not implemented.'); }
-		registerEmptyWindowBackupSync(backupFolder?: string | undefined, remoteAuthority?: string | undefined): string { throw new Error('Method not implemented.'); }
-		unregisterWorkspaceBackupSync(workspace: IWorkspaceIdentifier): void { throw new Error('Method not implemented.'); }
-		unregisterFolderBackupSync(folderUri: URI): void { throw new Error('Method not implemented.'); }
-		unregisterEmptyWindowBackupSync(backupFolder: string): void { throw new Error('Method not implemented.'); }
+		getEmptyWindowBackups(): IEmptyWindowBackupInfo[] { throw new Error('Method not implemented.'); }
+		registerWorkspaceBackup(workspaceInfo: IWorkspaceBackupInfo): string;
+		registerWorkspaceBackup(workspaceInfo: IWorkspaceBackupInfo, migrateFrom: string): Promise<string>;
+		registerWorkspaceBackup(workspaceInfo: unknown, migrateFrom?: unknown): string | Promise<string> { throw new Error('Method not implemented.'); }
+		registerFolderBackup(folder: IFolderBackupInfo): string { throw new Error('Method not implemented.'); }
+		registerEmptyWindowBackup(empty: IEmptyWindowBackupInfo): string { throw new Error('Method not implemented.'); }
 		async getDirtyWorkspaces(): Promise<(IWorkspaceBackupInfo | IFolderBackupInfo)[]> { return []; }
 	}
 
@@ -85,10 +82,6 @@ flakySuite('WorkspacesManagementMainService', () => {
 		fs.writeFileSync(workspaceConfigPath, JSON.stringify(ws));
 	}
 
-	function createUntitledWorkspaceSync(folders: string[], names?: string[]) {
-		return service.createUntitledWorkspaceSync(folders.map((folder, index) => ({ uri: URI.file(folder), name: names ? names[index] : undefined } as IWorkspaceFolderCreationData)));
-	}
-
 	let testDir: string;
 	let untitledWorkspacesHomePath: string;
 	let environmentMainService: EnvironmentMainService;
@@ -116,7 +109,7 @@ flakySuite('WorkspacesManagementMainService', () => {
 
 		const logService = new NullLogService();
 		const fileService = new FileService(logService);
-		service = new WorkspacesManagementMainService(environmentMainService, logService, new UserDataProfilesMainService(new StateMainService(environmentMainService, logService, fileService), new UriIdentityService(fileService), environmentMainService, fileService, logService), new TestBackupMainService(), new TestDialogMainService(), productService);
+		service = new WorkspacesManagementMainService(environmentMainService, logService, new UserDataProfilesMainService(new StateService(SaveStrategy.DELAYED, environmentMainService, logService, fileService), new UriIdentityService(fileService), environmentMainService, fileService, logService), new TestBackupMainService(), new TestDialogMainService());
 
 		return pfs.Promises.mkdir(untitledWorkspacesHomePath, { recursive: true });
 	});
@@ -189,54 +182,6 @@ flakySuite('WorkspacesManagementMainService', () => {
 		assert.strictEqual(ws.remoteAuthority, 'server');
 	});
 
-	test('createWorkspaceSync (folders)', () => {
-		const workspace = createUntitledWorkspaceSync([cwd, tmpDir]);
-		assert.ok(workspace);
-		assert.ok(fs.existsSync(workspace.configPath.fsPath));
-		assert.ok(service.isUntitledWorkspace(workspace));
-
-		const ws = JSON.parse(fs.readFileSync(workspace.configPath.fsPath).toString()) as IStoredWorkspace;
-		assert.strictEqual(ws.folders.length, 2);
-		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[0]).path, cwd);
-		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[1]).path, tmpDir);
-
-		assert.ok(!(<IRawFileWorkspaceFolder>ws.folders[0]).name);
-		assert.ok(!(<IRawFileWorkspaceFolder>ws.folders[1]).name);
-	});
-
-	test('createWorkspaceSync (folders with names)', () => {
-		const workspace = createUntitledWorkspaceSync([cwd, tmpDir], ['currentworkingdirectory', 'tempdir']);
-		assert.ok(workspace);
-		assert.ok(fs.existsSync(workspace.configPath.fsPath));
-		assert.ok(service.isUntitledWorkspace(workspace));
-
-		const ws = JSON.parse(fs.readFileSync(workspace.configPath.fsPath).toString()) as IStoredWorkspace;
-		assert.strictEqual(ws.folders.length, 2);
-		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[0]).path, cwd);
-		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[1]).path, tmpDir);
-
-		assert.strictEqual((<IRawFileWorkspaceFolder>ws.folders[0]).name, 'currentworkingdirectory');
-		assert.strictEqual((<IRawFileWorkspaceFolder>ws.folders[1]).name, 'tempdir');
-	});
-
-	test('createUntitledWorkspaceSync (folders as other resource URIs)', () => {
-		const folder1URI = URI.parse('myscheme://server/work/p/f1');
-		const folder2URI = URI.parse('myscheme://server/work/o/f3');
-
-		const workspace = service.createUntitledWorkspaceSync([{ uri: folder1URI }, { uri: folder2URI }]);
-		assert.ok(workspace);
-		assert.ok(fs.existsSync(workspace.configPath.fsPath));
-		assert.ok(service.isUntitledWorkspace(workspace));
-
-		const ws = JSON.parse(fs.readFileSync(workspace.configPath.fsPath).toString()) as IStoredWorkspace;
-		assert.strictEqual(ws.folders.length, 2);
-		assert.strictEqual((<IRawUriWorkspaceFolder>ws.folders[0]).uri, folder1URI.toString(true));
-		assert.strictEqual((<IRawUriWorkspaceFolder>ws.folders[1]).uri, folder2URI.toString(true));
-
-		assert.ok(!(<IRawFileWorkspaceFolder>ws.folders[0]).name);
-		assert.ok(!(<IRawFileWorkspaceFolder>ws.folders[1]).name);
-	});
-
 	test('resolveWorkspace', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		assert.ok(await service.resolveLocalWorkspace(workspace.configPath));
@@ -260,58 +205,35 @@ flakySuite('WorkspacesManagementMainService', () => {
 		assert.ok(resolvedTransient?.transient);
 	});
 
-	test('resolveWorkspaceSync', async () => {
-		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
-		assert.ok(service.resolveLocalWorkspaceSync(workspace.configPath));
-
-		// make it a valid workspace path
-		const newPath = path.join(path.dirname(workspace.configPath.fsPath), `workspace.${WORKSPACE_EXTENSION}`);
-		fs.renameSync(workspace.configPath.fsPath, newPath);
-		workspace.configPath = URI.file(newPath);
-
-		const resolved = service.resolveLocalWorkspaceSync(workspace.configPath);
-		assert.strictEqual(2, resolved!.folders.length);
-		assertEqualURI(resolved!.configPath, workspace.configPath);
-		assert.ok(resolved!.id);
-		fs.writeFileSync(workspace.configPath.fsPath, JSON.stringify({ something: 'something' })); // invalid workspace
-
-		const resolvedInvalid = service.resolveLocalWorkspaceSync(workspace.configPath);
-		assert.ok(!resolvedInvalid);
-
-		fs.writeFileSync(workspace.configPath.fsPath, JSON.stringify({ transient: true, folders: [] })); // transient worksapce
-		const resolvedTransient = service.resolveLocalWorkspaceSync(workspace.configPath);
-		assert.ok(resolvedTransient?.transient);
-	});
-
-	test('resolveWorkspaceSync (support relative paths)', async () => {
+	test('resolveWorkspace (support relative paths)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		fs.writeFileSync(workspace.configPath.fsPath, JSON.stringify({ folders: [{ path: './ticino-playground/lib' }] }));
 
-		const resolved = service.resolveLocalWorkspaceSync(workspace.configPath);
+		const resolved = await service.resolveLocalWorkspace(workspace.configPath);
 		assertEqualURI(resolved!.folders[0].uri, URI.file(path.join(path.dirname(workspace.configPath.fsPath), 'ticino-playground', 'lib')));
 	});
 
-	test('resolveWorkspaceSync (support relative paths #2)', async () => {
+	test('resolveWorkspace (support relative paths #2)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		fs.writeFileSync(workspace.configPath.fsPath, JSON.stringify({ folders: [{ path: './ticino-playground/lib/../other' }] }));
 
-		const resolved = service.resolveLocalWorkspaceSync(workspace.configPath);
+		const resolved = await service.resolveLocalWorkspace(workspace.configPath);
 		assertEqualURI(resolved!.folders[0].uri, URI.file(path.join(path.dirname(workspace.configPath.fsPath), 'ticino-playground', 'other')));
 	});
 
-	test('resolveWorkspaceSync (support relative paths #3)', async () => {
+	test('resolveWorkspace (support relative paths #3)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		fs.writeFileSync(workspace.configPath.fsPath, JSON.stringify({ folders: [{ path: 'ticino-playground/lib' }] }));
 
-		const resolved = service.resolveLocalWorkspaceSync(workspace.configPath);
+		const resolved = await service.resolveLocalWorkspace(workspace.configPath);
 		assertEqualURI(resolved!.folders[0].uri, URI.file(path.join(path.dirname(workspace.configPath.fsPath), 'ticino-playground', 'lib')));
 	});
 
-	test('resolveWorkspaceSync (support invalid JSON via fault tolerant parsing)', async () => {
+	test('resolveWorkspace (support invalid JSON via fault tolerant parsing)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		fs.writeFileSync(workspace.configPath.fsPath, '{ "folders": [ { "path": "./ticino-playground/lib" } , ] }'); // trailing comma
 
-		const resolved = service.resolveLocalWorkspaceSync(workspace.configPath);
+		const resolved = await service.resolveLocalWorkspace(workspace.configPath);
 		assertEqualURI(resolved!.folders[0].uri, URI.file(path.join(path.dirname(workspace.configPath.fsPath), 'ticino-playground', 'lib')));
 	});
 
@@ -371,7 +293,7 @@ flakySuite('WorkspacesManagementMainService', () => {
 
 		const newContent = rewriteWorkspaceFileForNewLocation(origContent, workspace.configPath, false, workspaceConfigPath, extUriBiasedIgnorePathCase);
 		assert.strictEqual(0, newContent.indexOf('// this is a comment'));
-		service.deleteUntitledWorkspaceSync(workspace);
+		await service.deleteUntitledWorkspace(workspace);
 	});
 
 	test('rewriteWorkspaceFileForNewLocation (preserves forward slashes)', async () => {
@@ -384,7 +306,7 @@ flakySuite('WorkspacesManagementMainService', () => {
 		const newContent = rewriteWorkspaceFileForNewLocation(origContent, workspace.configPath, false, workspaceConfigPath, extUriBiasedIgnorePathCase);
 		const ws = (JSON.parse(newContent) as IStoredWorkspace);
 		assert.ok(ws.folders.every(f => (<IRawFileWorkspaceFolder>f).path.indexOf('\\') < 0));
-		service.deleteUntitledWorkspaceSync(workspace);
+		await service.deleteUntitledWorkspace(workspace);
 	});
 
 	(!isWindows ? test.skip : test)('rewriteWorkspaceFileForNewLocation (unc paths)', async () => {
@@ -402,34 +324,37 @@ flakySuite('WorkspacesManagementMainService', () => {
 		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[1]).path, folder2Location);
 		assertPathEquals((<IRawFileWorkspaceFolder>ws.folders[2]).path, 'inner/more');
 
-		service.deleteUntitledWorkspaceSync(workspace);
+		await service.deleteUntitledWorkspace(workspace);
 	});
 
-	test('deleteUntitledWorkspaceSync (untitled)', async () => {
+	test('deleteUntitledWorkspace (untitled)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
 		assert.ok(fs.existsSync(workspace.configPath.fsPath));
-		service.deleteUntitledWorkspaceSync(workspace);
+		await service.deleteUntitledWorkspace(workspace);
 		assert.ok(!fs.existsSync(workspace.configPath.fsPath));
 	});
 
-	test('deleteUntitledWorkspaceSync (saved)', async () => {
+	test('deleteUntitledWorkspace (saved)', async () => {
 		const workspace = await createUntitledWorkspace([cwd, tmpDir]);
-		service.deleteUntitledWorkspaceSync(workspace);
+		await service.deleteUntitledWorkspace(workspace);
 	});
 
-	test('getUntitledWorkspaceSync', async function () {
-		let untitled = service.getUntitledWorkspacesSync();
+	test('getUntitledWorkspace', async function () {
+		await service.initialize();
+		let untitled = service.getUntitledWorkspaces();
 		assert.strictEqual(untitled.length, 0);
 
 		const untitledOne = await createUntitledWorkspace([cwd, tmpDir]);
 		assert.ok(fs.existsSync(untitledOne.configPath.fsPath));
 
-		untitled = service.getUntitledWorkspacesSync();
+		await service.initialize();
+		untitled = service.getUntitledWorkspaces();
 		assert.strictEqual(1, untitled.length);
 		assert.strictEqual(untitledOne.id, untitled[0].workspace.id);
 
-		service.deleteUntitledWorkspaceSync(untitledOne);
-		untitled = service.getUntitledWorkspacesSync();
+		await service.deleteUntitledWorkspace(untitledOne);
+		await service.initialize();
+		untitled = service.getUntitledWorkspaces();
 		assert.strictEqual(0, untitled.length);
 	});
 });
