@@ -6,7 +6,7 @@
 import { DisposableStore } from 'vs/base/common/lifecycle';
 import { FileOperation, IFileService } from 'vs/platform/files/common/files';
 import { extHostCustomer, IExtHostContext } from 'vs/workbench/services/extensions/common/extHostCustomers';
-import { ExtHostContext, reviveWorkspaceEditDto } from '../common/extHost.protocol';
+import { ExtHostContext } from '../common/extHost.protocol';
 import { localize } from 'vs/nls';
 import { IWorkingCopyFileOperationParticipant, IWorkingCopyFileService, SourceTargetPair, IFileOperationUndoRedoInfo } from 'vs/workbench/services/workingCopy/common/workingCopyFileService';
 import { IBulkEditService } from 'vs/editor/browser/services/bulkEditService';
@@ -20,6 +20,8 @@ import { Action2, registerAction2 } from 'vs/platform/actions/common/actions';
 import { ServicesAccessor } from 'vs/platform/instantiation/common/instantiation';
 import { ILogService } from 'vs/platform/log/common/log';
 import { IEnvironmentService } from 'vs/platform/environment/common/environment';
+import { IUriIdentityService } from 'vs/platform/uriIdentity/common/uriIdentity';
+import { reviveWorkspaceEditDto } from 'vs/workbench/api/browser/mainThreadBulkEdits';
 
 @extHostCustomer
 export class MainThreadFileSystemEventService {
@@ -37,7 +39,8 @@ export class MainThreadFileSystemEventService {
 		@IDialogService dialogService: IDialogService,
 		@IStorageService storageService: IStorageService,
 		@ILogService logService: ILogService,
-		@IEnvironmentService envService: IEnvironmentService
+		@IEnvironmentService envService: IEnvironmentService,
+		@IUriIdentityService uriIdentService: IUriIdentityService
 	) {
 
 		const proxy = extHostContext.getProxy(ExtHostContext.ExtHostFileSystemEventService);
@@ -118,27 +121,49 @@ export class MainThreadFileSystemEventService {
 
 					if (needsConfirmation) {
 						// edit which needs confirmation -> always show dialog
-						const answer = await dialogService.show(Severity.Info, message, [localize('preview', "Show Preview"), localize('cancel', "Skip Changes")], { cancelId: 1 });
+						const { confirmed } = await dialogService.confirm({
+							type: Severity.Info,
+							message,
+							primaryButton: localize('preview', "Show &&Preview"),
+							cancelButton: localize('cancel', "Skip Changes")
+						});
 						showPreview = true;
-						if (answer.choice === 1) {
+						if (!confirmed) {
 							// no changes wanted
 							return;
 						}
 					} else {
 						// choice
-						const answer = await dialogService.show(Severity.Info, message,
-							[localize('ok', "OK"), localize('preview', "Show Preview"), localize('cancel', "Skip Changes")],
-							{
-								cancelId: 2,
-								checkbox: { label: localize('again', "Don't ask again") }
-							}
-						);
-						if (answer.choice === 2) {
+						enum Choice {
+							OK = 0,
+							Preview = 1,
+							Cancel = 2
+						}
+						const { result, checkboxChecked } = await dialogService.prompt<Choice>({
+							type: Severity.Info,
+							message,
+							buttons: [
+								{
+									label: localize({ key: 'ok', comment: ['&& denotes a mnemonic'] }, "&&OK"),
+									run: () => Choice.OK
+								},
+								{
+									label: localize({ key: 'preview', comment: ['&& denotes a mnemonic'] }, "Show &&Preview"),
+									run: () => Choice.Preview
+								}
+							],
+							cancelButton: {
+								label: localize('cancel', "Skip Changes"),
+								run: () => Choice.Cancel
+							},
+							checkbox: { label: localize('again', "Don't ask again") }
+						});
+						if (result === Choice.Cancel) {
 							// no changes wanted, don't persist cancel option
 							return;
 						}
-						showPreview = answer.choice === 1;
-						if (answer.checkboxChecked /* && answer.choice !== 2 */) {
+						showPreview = result === Choice.Preview;
+						if (checkboxChecked) {
 							storageService.store(MainThreadFileSystemEventService.MementoKeyAdditionalEdits, showPreview, StorageScope.PROFILE, StorageTarget.USER);
 						}
 					}
@@ -147,7 +172,7 @@ export class MainThreadFileSystemEventService {
 				logService.info('[onWill-handler] applying additional workspace edit from extensions', data.extensionNames);
 
 				await bulkEditService.apply(
-					reviveWorkspaceEditDto(data.edit),
+					reviveWorkspaceEditDto(data.edit, uriIdentService),
 					{ undoRedoGroupId: undoInfo?.undoRedoGroupId, showPreview }
 				);
 			}
