@@ -4,7 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { ok } from 'vs/base/common/assert';
-import { illegalArgument, readonly } from 'vs/base/common/errors';
+import { ReadonlyError, illegalArgument } from 'vs/base/common/errors';
 import { IdGenerator } from 'vs/base/common/idGenerator';
 import { TextEditorCursorStyle } from 'vs/editor/common/config/editorOptions';
 import { IRange } from 'vs/editor/common/core/range';
@@ -428,10 +428,10 @@ export class ExtHostTextEditor {
 
 		this.value = Object.freeze({
 			get document(): vscode.TextDocument {
-				return document.getValue();
+				return document.value;
 			},
 			set document(_value) {
-				throw readonly('document');
+				throw new ReadonlyError('document');
 			},
 			// --- selection
 			get selection(): Selection {
@@ -459,7 +459,7 @@ export class ExtHostTextEditor {
 				return that._visibleRanges;
 			},
 			set visibleRanges(_value: Range[]) {
-				throw readonly('visibleRanges');
+				throw new ReadonlyError('visibleRanges');
 			},
 			// --- options
 			get options(): vscode.TextEditorOptions {
@@ -475,14 +475,14 @@ export class ExtHostTextEditor {
 				return that._viewColumn;
 			},
 			set viewColumn(_value) {
-				throw readonly('viewColumn');
+				throw new ReadonlyError('viewColumn');
 			},
 			// --- edit
 			edit(callback: (edit: TextEditorEdit) => void, options: { undoStopBefore: boolean; undoStopAfter: boolean } = { undoStopBefore: true, undoStopAfter: true }): Promise<boolean> {
 				if (that._disposed) {
 					return Promise.reject(new Error('TextEditor#edit not possible on closed editors'));
 				}
-				const edit = new TextEditorEdit(document.getValue(), options);
+				const edit = new TextEditorEdit(document.value, options);
 				callback(edit);
 				return that._applyEdit(edit);
 			},
@@ -513,7 +513,7 @@ export class ExtHostTextEditor {
 						}
 					}
 				}
-				return _proxy.$tryInsertSnippet(id, document.getValue().version, snippet.value, ranges, options);
+				return _proxy.$tryInsertSnippet(id, document.value.version, snippet.value, ranges, options);
 			},
 			setDecorations(decorationType: vscode.TextEditorDecorationType, ranges: Range[] | vscode.DecorationOptions[]): void {
 				const willBeEmpty = (ranges.length === 0);
