@@ -40,7 +40,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('disposeCheck', () => {
 
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 
 		collection.dispose();
 		collection.dispose(); // that's OK
@@ -56,13 +56,13 @@ suite('ExtHostDiagnostics', () => {
 
 
 	test('diagnostic collection, forEach, clear, has', function () {
-		let collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		let collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		assert.strictEqual(collection.name, 'test');
 		collection.dispose();
 		assert.throws(() => collection.name);
 
 		let c = 0;
-		collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		collection.forEach(() => c++);
 		assert.strictEqual(c, 0);
 
@@ -99,7 +99,7 @@ suite('ExtHostDiagnostics', () => {
 	});
 
 	test('diagnostic collection, immutable read', function () {
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		collection.set(URI.parse('foo:bar'), [
 			new Diagnostic(new Range(0, 0, 1, 1), 'message-1'),
 			new Diagnostic(new Range(0, 0, 1, 1), 'message-2')
@@ -124,7 +124,7 @@ suite('ExtHostDiagnostics', () => {
 
 
 	test('diagnostics collection, set with dupliclated tuples', function () {
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		const uri = URI.parse('sc:hightower');
 		collection.set([
 			[uri, [new Diagnostic(new Range(0, 0, 0, 1), 'message-1')]],
@@ -175,7 +175,7 @@ suite('ExtHostDiagnostics', () => {
 	test('diagnostics collection, set tuple overrides, #11547', function () {
 
 		let lastEntries!: [UriComponents, IMarkerData[]][];
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new class extends DiagnosticsShape {
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new class extends DiagnosticsShape {
 			override $changeMany(owner: string, entries: [UriComponents, IMarkerData[]][]): void {
 				lastEntries = entries;
 				return super.$changeMany(owner, entries);
@@ -209,7 +209,7 @@ suite('ExtHostDiagnostics', () => {
 
 		const emitter = new Emitter<any>();
 		emitter.event(_ => eventCount += 1);
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new class extends DiagnosticsShape {
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new class extends DiagnosticsShape {
 			override $changeMany() {
 				changeCount += 1;
 			}
@@ -229,7 +229,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('diagnostics collection, tuples and undefined (small array), #15585', function () {
 
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		const uri = URI.parse('sc:hightower');
 		const uri2 = URI.parse('sc:nomad');
 		const diag = new Diagnostic(new Range(0, 0, 0, 1), 'ffff');
@@ -250,7 +250,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('diagnostics collection, tuples and undefined (large array), #15585', function () {
 
-		const collection = new DiagnosticCollection('test', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
+		const collection = new DiagnosticCollection('test', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), new Emitter());
 		const tuples: [URI, Diagnostic[]][] = [];
 
 		for (let i = 0; i < 500; i++) {
@@ -271,10 +271,10 @@ suite('ExtHostDiagnostics', () => {
 		}
 	});
 
-	test('diagnostic capping', function () {
+	test('diagnostic capping (max per file)', function () {
 
 		let lastEntries!: [UriComponents, IMarkerData[]][];
-		const collection = new DiagnosticCollection('test', 'test', 250, versionProvider, extUri, new class extends DiagnosticsShape {
+		const collection = new DiagnosticCollection('test', 'test', 100, 250, versionProvider, extUri, new class extends DiagnosticsShape {
 			override $changeMany(owner: string, entries: [UriComponents, IMarkerData[]][]): void {
 				lastEntries = entries;
 				return super.$changeMany(owner, entries);
@@ -298,9 +298,31 @@ suite('ExtHostDiagnostics', () => {
 		assert.strictEqual(lastEntries[0][1][250].severity, MarkerSeverity.Info);
 	});
 
+	test('diagnostic capping (max files)', function () {
+
+		let lastEntries!: [UriComponents, IMarkerData[]][];
+		const collection = new DiagnosticCollection('test', 'test', 2, 1, versionProvider, extUri, new class extends DiagnosticsShape {
+			override $changeMany(owner: string, entries: [UriComponents, IMarkerData[]][]): void {
+				lastEntries = entries;
+				return super.$changeMany(owner, entries);
+			}
+		}, new Emitter());
+
+		const diag = new Diagnostic(new Range(0, 0, 1, 1), 'Hello');
+
+
+		collection.set([
+			[URI.parse('aa:bb1'), [diag]],
+			[URI.parse('aa:bb2'), [diag]],
+			[URI.parse('aa:bb3'), [diag]],
+			[URI.parse('aa:bb4'), [diag]],
+		]);
+		assert.strictEqual(lastEntries.length, 3); // goes above the limit and then stops
+	});
+
 	test('diagnostic eventing', async function () {
 		const emitter = new Emitter<readonly URI[]>();
-		const collection = new DiagnosticCollection('ddd', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), emitter);
+		const collection = new DiagnosticCollection('ddd', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), emitter);
 
 		const diag1 = new Diagnostic(new Range(1, 1, 2, 3), 'diag1');
 		const diag2 = new Diagnostic(new Range(1, 1, 2, 3), 'diag2');
@@ -338,7 +360,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('vscode.languages.onDidChangeDiagnostics Does Not Provide Document URI #49582', async function () {
 		const emitter = new Emitter<readonly URI[]>();
-		const collection = new DiagnosticCollection('ddd', 'test', 100, versionProvider, extUri, new DiagnosticsShape(), emitter);
+		const collection = new DiagnosticCollection('ddd', 'test', 100, 100, versionProvider, extUri, new DiagnosticsShape(), emitter);
 
 		const diag1 = new Diagnostic(new Range(1, 1, 2, 3), 'diag1');
 
@@ -361,7 +383,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('diagnostics with related information', function (done) {
 
-		const collection = new DiagnosticCollection('ddd', 'test', 100, versionProvider, extUri, new class extends DiagnosticsShape {
+		const collection = new DiagnosticCollection('ddd', 'test', 100, 100, versionProvider, extUri, new class extends DiagnosticsShape {
 			override $changeMany(owner: string, entries: [UriComponents, IMarkerData[]][]) {
 
 				const [[, data]] = entries;
@@ -424,7 +446,7 @@ suite('ExtHostDiagnostics', () => {
 
 	test('Error updating diagnostics from extension #60394', function () {
 		let callCount = 0;
-		const collection = new DiagnosticCollection('ddd', 'test', 100, versionProvider, extUri, new class extends DiagnosticsShape {
+		const collection = new DiagnosticCollection('ddd', 'test', 100, 100, versionProvider, extUri, new class extends DiagnosticsShape {
 			override $changeMany(owner: string, entries: [UriComponents, IMarkerData[]][]) {
 				callCount += 1;
 			}
@@ -451,7 +473,7 @@ suite('ExtHostDiagnostics', () => {
 
 		const all: [UriComponents, IMarkerData[]][] = [];
 
-		const collection = new DiagnosticCollection('ddd', 'test', 100, uri => {
+		const collection = new DiagnosticCollection('ddd', 'test', 100, 100, uri => {
 			return 7;
 		}, extUri, new class extends DiagnosticsShape {
 			override $changeMany(_owner: string, entries: [UriComponents, IMarkerData[]][]) {
@@ -505,7 +527,7 @@ suite('ExtHostDiagnostics', () => {
 				startColumn: 1,
 				endLineNumber: 1,
 				endColumn: 1,
-				severity: 3
+				severity: MarkerSeverity.Info
 			}];
 
 			const p1 = Event.toPromise(diags.onDidChangeDiagnostics);
