@@ -7,13 +7,13 @@ import * as assert from 'assert';
 import { URI } from 'vs/base/common/uri';
 import { ExtensionIdentifier, IExtensionDescription, TargetPlatform } from 'vs/platform/extensions/common/extensions';
 import { DEFAULT_LOG_LEVEL, LogLevel } from 'vs/platform/log/common/log';
-import { ITelemetryInfo, TelemetryLevel } from 'vs/platform/telemetry/common/telemetry';
+import { TelemetryLevel } from 'vs/platform/telemetry/common/telemetry';
 import { TestTelemetryLoggerService } from 'vs/platform/telemetry/test/common/telemetryLogAppender.test';
 import { IExtHostInitDataService } from 'vs/workbench/api/common/extHostInitDataService';
-import { ExtHostTelemetry } from 'vs/workbench/api/common/extHostTelemetry';
+import { ExtHostTelemetry, ExtHostTelemetryLogger } from 'vs/workbench/api/common/extHostTelemetry';
 import { IEnvironment } from 'vs/workbench/services/extensions/common/extensionHostProtocol';
 import { mock } from 'vs/workbench/test/common/workbenchTestServices';
-import type { TelemetryAppender } from 'vscode';
+import type { TelemetryLoggerOptions, TelemetrySender } from 'vscode';
 
 interface TelemetryLoggerSpy {
 	dataArr: any[];
@@ -30,6 +30,7 @@ suite('ExtHostTelemetry', function () {
 		appRoot: undefined,
 		appName: 'test',
 		extensionTelemetryLogResource: URI.parse('fake'),
+		isExtensionTelemetryLoggingOnly: false,
 		appHost: 'test',
 		appLanguage: 'en',
 		globalStorageHome: URI.parse('fake'),
@@ -37,7 +38,7 @@ suite('ExtHostTelemetry', function () {
 		appUriScheme: 'test',
 	};
 
-	const mockTelemetryInfo: ITelemetryInfo = {
+	const mockTelemetryInfo = {
 		firstSessionDate: '2020-01-01T00:00:00.000Z',
 		sessionId: 'test',
 		machineId: 'test',
@@ -65,33 +66,57 @@ suite('ExtHostTelemetry', function () {
 	const createExtHostTelemetry = () => {
 		const extensionTelemetry = new ExtHostTelemetry(new class extends mock<IExtHostInitDataService>() {
 			override environment: IEnvironment = mockEnvironment;
-			override telemetryInfo: ITelemetryInfo = mockTelemetryInfo;
+			override telemetryInfo = mockTelemetryInfo;
 			override remote = mockRemote;
 		}, new TestTelemetryLoggerService(DEFAULT_LOG_LEVEL));
-		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, false, { usage: true, error: true });
+		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, true, { usage: true, error: true });
 		return extensionTelemetry;
 	};
 
-	const createLogger = (functionSpy: TelemetryLoggerSpy, extHostTelemetry?: ExtHostTelemetry) => {
+	const createLogger = (functionSpy: TelemetryLoggerSpy, extHostTelemetry?: ExtHostTelemetry, options?: TelemetryLoggerOptions) => {
 		const extensionTelemetry = extHostTelemetry ?? createExtHostTelemetry();
 		// This is the appender which the extension would contribute
-		const appender: TelemetryAppender = {
-			logEvent: (eventName: string, data) => {
+		const appender: TelemetrySender = {
+			sendEventData: (eventName: string, data) => {
 				functionSpy.dataArr.push({ eventName, data });
 			},
-			logException: (exception, data) => {
+			sendErrorData: (exception, data) => {
 				functionSpy.exceptionArr.push({ exception, data });
 			},
-			ignoreBuiltInCommonProperties: false,
 			flush: () => {
 				functionSpy.flushCalled = true;
 			}
 		};
 
-		const logger = extensionTelemetry.instantiateLogger(mockExtensionIdentifier, appender);
+		const logger = extensionTelemetry.instantiateLogger(mockExtensionIdentifier, appender, options);
 		return logger;
 	};
 
+	test('Validate sender instances', function () {
+		assert.throws(() => ExtHostTelemetryLogger.validateSender(<any>null));
+		assert.throws(() => ExtHostTelemetryLogger.validateSender(<any>1));
+		assert.throws(() => ExtHostTelemetryLogger.validateSender(<any>{}));
+		assert.throws(() => {
+			ExtHostTelemetryLogger.validateSender(<any>{
+				sendErrorData: () => { },
+				sendEventData: true
+			});
+		});
+		assert.throws(() => {
+			ExtHostTelemetryLogger.validateSender(<any>{
+				sendErrorData: 123,
+				sendEventData: () => { },
+			});
+		});
+		assert.throws(() => {
+			ExtHostTelemetryLogger.validateSender(<any>{
+				sendErrorData: () => { },
+				sendEventData: () => { },
+				flush: true
+			});
+		});
+	});
+
 	test('Ensure logger gets proper telemetry level during initialization', function () {
 		const extensionTelemetry = createExtHostTelemetry();
 		let config = extensionTelemetry.getTelemetryDetails();
@@ -100,19 +125,19 @@ suite('ExtHostTelemetry', function () {
 		assert.strictEqual(config.isErrorsEnabled, true);
 
 		// Initialize would never be called twice, but this is just for testing
-		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.ERROR, false, { usage: true, error: true });
+		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.ERROR, true, { usage: true, error: true });
 		config = extensionTelemetry.getTelemetryDetails();
 		assert.strictEqual(config.isCrashEnabled, true);
 		assert.strictEqual(config.isUsageEnabled, false);
 		assert.strictEqual(config.isErrorsEnabled, true);
 
-		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.CRASH, false, { usage: true, error: true });
+		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.CRASH, true, { usage: true, error: true });
 		config = extensionTelemetry.getTelemetryDetails();
 		assert.strictEqual(config.isCrashEnabled, true);
 		assert.strictEqual(config.isUsageEnabled, false);
 		assert.strictEqual(config.isErrorsEnabled, false);
 
-		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, false, { usage: false, error: true });
+		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, true, { usage: false, error: true });
 		config = extensionTelemetry.getTelemetryDetails();
 		assert.strictEqual(config.isCrashEnabled, true);
 		assert.strictEqual(config.isUsageEnabled, false);
@@ -149,6 +174,38 @@ suite('ExtHostTelemetry', function () {
 
 	});
 
+	test('Simple log event to TelemetryLogger with options', function () {
+		const functionSpy: TelemetryLoggerSpy = { dataArr: [], exceptionArr: [], flushCalled: false };
+
+		const logger = createLogger(functionSpy, undefined, { additionalCommonProperties: { 'common.foo': 'bar' } });
+
+		logger.logUsage('test-event', { 'test-data': 'test-data' });
+		assert.strictEqual(functionSpy.dataArr.length, 1);
+		assert.strictEqual(functionSpy.dataArr[0].eventName, `${mockExtensionIdentifier.name}/test-event`);
+		assert.strictEqual(functionSpy.dataArr[0].data['test-data'], 'test-data');
+		assert.strictEqual(functionSpy.dataArr[0].data['common.foo'], 'bar');
+
+		logger.logUsage('test-event', { 'test-data': 'test-data' });
+		assert.strictEqual(functionSpy.dataArr.length, 2);
+
+		logger.logError('test-event', { 'test-data': 'test-data' });
+		assert.strictEqual(functionSpy.dataArr.length, 3);
+
+		logger.logError(new Error('test-error'), { 'test-data': 'test-data' });
+		assert.strictEqual(functionSpy.dataArr.length, 3);
+		assert.strictEqual(functionSpy.exceptionArr.length, 1);
+
+
+		// Assert not flushed
+		assert.strictEqual(functionSpy.flushCalled, false);
+
+		// Call flush and assert that flush occurs
+		logger.dispose();
+		assert.strictEqual(functionSpy.flushCalled, true);
+
+	});
+
+
 	test('Ensure logger properly cleans PII', function () {
 		const functionSpy: TelemetryLoggerSpy = { dataArr: [], exceptionArr: [], flushCalled: false };
 
@@ -178,10 +235,10 @@ suite('ExtHostTelemetry', function () {
 		const loggerService = new TestTelemetryLoggerService(LogLevel.Trace);
 		const extensionTelemetry = new ExtHostTelemetry(new class extends mock<IExtHostInitDataService>() {
 			override environment: IEnvironment = mockEnvironment;
-			override telemetryInfo: ITelemetryInfo = mockTelemetryInfo;
+			override telemetryInfo = mockTelemetryInfo;
 			override remote = mockRemote;
 		}, loggerService);
-		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, false, { usage: true, error: true });
+		extensionTelemetry.$initializeTelemetryLevel(TelemetryLevel.USAGE, true, { usage: true, error: true });
 
 		const functionSpy: TelemetryLoggerSpy = { dataArr: [], exceptionArr: [], flushCalled: false };
 
