@@ -13,8 +13,6 @@ import { ConfigurationTarget, IConfigurationService } from 'vs/platform/configur
 import { INotificationHandle, INotificationService, NotificationPriority } from 'vs/platform/notification/common/notification';
 import { IWorkbenchContribution } from 'vs/workbench/common/contributions';
 import { IStatusbarEntryAccessor, IStatusbarService, StatusbarAlignment } from 'vs/workbench/services/statusbar/browser/statusbar';
-import { themeColorFromId } from 'vs/platform/theme/common/themeService';
-import { STATUS_BAR_PROMINENT_ITEM_BACKGROUND, STATUS_BAR_PROMINENT_ITEM_FOREGROUND } from 'vs/workbench/common/theme';
 
 export class AccessibilityStatus extends Disposable implements IWorkbenchContribution {
 	private screenReaderNotification: INotificationHandle | null = null;
@@ -40,29 +38,27 @@ export class AccessibilityStatus extends Disposable implements IWorkbenchContrib
 	}
 
 	private showScreenReaderNotification(): void {
-		if (!this.screenReaderNotification) {
-			this.screenReaderNotification = this.notificationService.prompt(
-				Severity.Info,
-				localize('screenReaderDetectedExplanation.question', "Are you using a screen reader to operate VS Code?"),
-				[{
-					label: localize('screenReaderDetectedExplanation.answerYes', "Yes"),
-					run: () => {
-						this.configurationService.updateValue('editor.accessibilitySupport', 'on', ConfigurationTarget.USER);
-					}
-				}, {
-					label: localize('screenReaderDetectedExplanation.answerNo', "No"),
-					run: () => {
-						this.configurationService.updateValue('editor.accessibilitySupport', 'off', ConfigurationTarget.USER);
-					}
-				}],
-				{
-					sticky: true,
-					priority: NotificationPriority.URGENT
+		this.screenReaderNotification = this.notificationService.prompt(
+			Severity.Info,
+			localize('screenReaderDetectedExplanation.question', "Are you using a screen reader to operate VS Code?"),
+			[{
+				label: localize('screenReaderDetectedExplanation.answerYes', "Yes"),
+				run: () => {
+					this.configurationService.updateValue('editor.accessibilitySupport', 'on', ConfigurationTarget.USER);
 				}
-			);
+			}, {
+				label: localize('screenReaderDetectedExplanation.answerNo', "No"),
+				run: () => {
+					this.configurationService.updateValue('editor.accessibilitySupport', 'off', ConfigurationTarget.USER);
+				}
+			}],
+			{
+				sticky: true,
+				priority: NotificationPriority.URGENT
+			}
+		);
 
-			Event.once(this.screenReaderNotification.onDidClose)(() => this.screenReaderNotification = null);
-		}
+		Event.once(this.screenReaderNotification.onDidClose)(() => this.screenReaderNotification = null);
 	}
 	private updateScreenReaderModeElement(visible: boolean): void {
 		if (visible) {
@@ -73,8 +69,7 @@ export class AccessibilityStatus extends Disposable implements IWorkbenchContrib
 					text,
 					ariaLabel: text,
 					command: 'showEditorScreenReaderNotification',
-					backgroundColor: themeColorFromId(STATUS_BAR_PROMINENT_ITEM_BACKGROUND),
-					color: themeColorFromId(STATUS_BAR_PROMINENT_ITEM_FOREGROUND)
+					kind: 'prominent'
 				}, 'status.editor.screenReaderMode', StatusbarAlignment.RIGHT, 100.6);
 			}
 		} else {
