@@ -46,6 +46,9 @@ export class ViewsService extends Disposable implements IViewsService {
 	private readonly _onDidChangeViewContainerVisibility = this._register(new Emitter<{ id: string; visible: boolean; location: ViewContainerLocation }>());
 	readonly onDidChangeViewContainerVisibility = this._onDidChangeViewContainerVisibility.event;
 
+	private readonly _onDidChangeFocusedView = this._register(new Emitter<void>());
+	readonly onDidChangeFocusedView = this._onDidChangeFocusedView.event;
+
 	private readonly visibleViewContextKeys: Map<string, IContextKey<boolean>>;
 	private readonly focusedViewContextKey: IContextKey<string>;
 
@@ -235,6 +238,11 @@ export class ViewsService extends Disposable implements IViewsService {
 		return null;
 	}
 
+	getFocusedViewName(): string {
+		const viewId: string = this.contextKeyService.getContextKeyValue(FocusedViewContext.key) ?? '';
+		return this.viewDescriptorService.getViewDescriptorById(viewId.toString())?.name ?? '';
+	}
+
 	async openView<T extends IView>(id: string, focus?: boolean): Promise<T | null> {
 		const viewContainer = this.viewDescriptorService.getViewContainerByViewId(id);
 		if (!viewContainer) {
@@ -367,13 +375,16 @@ export class ViewsService extends Disposable implements IViewsService {
 					const viewsService = serviceAccessor.get(IViewsService);
 					const viewContainerLocation = viewDescriptorService.getViewContainerLocation(viewContainer);
 					switch (viewContainerLocation) {
-						case ViewContainerLocation.Sidebar:
-							if (!viewsService.isViewContainerVisible(viewContainer.id) || !layoutService.hasFocus(Parts.SIDEBAR_PART)) {
+						case ViewContainerLocation.AuxiliaryBar:
+						case ViewContainerLocation.Sidebar: {
+							const part = viewContainerLocation === ViewContainerLocation.Sidebar ? Parts.SIDEBAR_PART : Parts.AUXILIARYBAR_PART;
+							if (!viewsService.isViewContainerVisible(viewContainer.id) || !layoutService.hasFocus(part)) {
 								await viewsService.openViewContainer(viewContainer.id, true);
 							} else {
 								editorGroupService.activeGroup.focus();
 							}
 							break;
+						}
 						case ViewContainerLocation.Panel:
 							if (!viewsService.isViewContainerVisible(viewContainer.id) || !layoutService.hasFocus(Parts.PANEL_PART)) {
 								await viewsService.openViewContainer(viewContainer.id, true);
@@ -613,10 +624,16 @@ export class ViewsService extends Disposable implements IViewsService {
 		disposables.add(viewPaneContainer.onDidAddViews(views => this.onViewsAdded(views)));
 		disposables.add(viewPaneContainer.onDidChangeViewVisibility(view => this.onViewsVisibilityChanged(view, view.isBodyVisible())));
 		disposables.add(viewPaneContainer.onDidRemoveViews(views => this.onViewsRemoved(views)));
-		disposables.add(viewPaneContainer.onDidFocusView(view => this.focusedViewContextKey.set(view.id)));
+		disposables.add(viewPaneContainer.onDidFocusView(view => {
+			if (this.focusedViewContextKey.get() !== view.id) {
+				this.focusedViewContextKey.set(view.id);
+				this._onDidChangeFocusedView.fire();
+			}
+		}));
 		disposables.add(viewPaneContainer.onDidBlurView(view => {
 			if (this.focusedViewContextKey.get() === view.id) {
 				this.focusedViewContextKey.reset();
+				this._onDidChangeFocusedView.fire();
 			}
 		}));
 
