@@ -11,10 +11,10 @@ import { TEXT_DIFF_EDITOR_ID, BINARY_DIFF_EDITOR_ID, Verbosity, IEditorDescripto
 import { BaseTextEditorModel } from 'vs/workbench/common/editor/textEditorModel';
 import { DiffEditorModel } from 'vs/workbench/common/editor/diffEditorModel';
 import { TextDiffEditorModel } from 'vs/workbench/common/editor/textDiffEditorModel';
-import { withNullAsUndefined } from 'vs/base/common/types';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
 import { IEditorService } from 'vs/workbench/services/editor/common/editorService';
 import { shorten } from 'vs/base/common/labels';
+import { IEditorOptions } from 'vs/platform/editor/common/editor';
 
 interface IDiffEditorInputLabels {
 	name: string;
@@ -164,13 +164,13 @@ export class DiffEditorInput extends SideBySideEditorInput implements IDiffEdito
 		}
 	}
 
-	override async resolve(): Promise<EditorModel> {
+	override async resolve(options?: IEditorOptions): Promise<EditorModel> {
 
 		// Create Model - we never reuse our cached model if refresh is true because we cannot
 		// decide for the inputs within if the cached model can be reused or not. There may be
 		// inputs that need to be loaded again and thus we always recreate the model and dispose
 		// the previous one - if any.
-		const resolvedModel = await this.createModel();
+		const resolvedModel = await this.createModel(options);
 		this.cachedModel?.dispose();
 
 		this.cachedModel = resolvedModel;
@@ -186,12 +186,12 @@ export class DiffEditorInput extends SideBySideEditorInput implements IDiffEdito
 		return editorPanes.find(editorPane => editorPane.typeId === TEXT_DIFF_EDITOR_ID);
 	}
 
-	private async createModel(): Promise<DiffEditorModel> {
+	private async createModel(options?: IEditorOptions): Promise<DiffEditorModel> {
 
 		// Join resolve call over two inputs and build diff editor model
 		const [originalEditorModel, modifiedEditorModel] = await Promise.all([
-			this.original.resolve(),
-			this.modified.resolve()
+			this.original.resolve(options),
+			this.modified.resolve(options)
 		]);
 
 		// If both are text models, return textdiffeditor model
@@ -200,7 +200,7 @@ export class DiffEditorInput extends SideBySideEditorInput implements IDiffEdito
 		}
 
 		// Otherwise return normal diff model
-		return new DiffEditorModel(withNullAsUndefined(originalEditorModel), withNullAsUndefined(modifiedEditorModel));
+		return new DiffEditorModel(originalEditorModel ?? undefined, modifiedEditorModel ?? undefined);
 	}
 
 	override toUntyped(options?: { preserveViewState: GroupIdentifier }): (IResourceDiffEditorInput & IResourceSideBySideEditorInput) | undefined {
