@@ -10,6 +10,7 @@ import { IFileService } from 'vs/platform/files/common/files';
 import { ILabelService } from 'vs/platform/label/common/label';
 import { dirname, isEqual } from 'vs/base/common/resources';
 import { IFilesConfigurationService } from 'vs/workbench/services/filesConfiguration/common/filesConfigurationService';
+import { IMarkdownString } from 'vs/base/common/htmlContent';
 
 /**
  * The base class for all editor inputs that open resources.
@@ -174,4 +175,8 @@ export abstract class AbstractResourceEditorInput extends EditorInput implements
 				return this.mediumTitle;
 		}
 	}
+
+	override isReadonly(): boolean | IMarkdownString {
+		return this.filesConfigurationService.isReadonly(this.resource);
+	}
 }
