@@ -3,6 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
+import { CancellationTokenSource } from 'vs/base/common/cancellation';
 import { Codicon } from 'vs/base/common/codicons';
 import { KeyCode, KeyMod } from 'vs/base/common/keyCodes';
 import { ICodeEditor, isCodeEditor, isDiffEditor } from 'vs/editor/browser/editorBrowser';
@@ -10,8 +11,10 @@ import { ServicesAccessor } from 'vs/editor/browser/editorExtensions';
 import { IBulkEditService, ResourceTextEdit } from 'vs/editor/browser/services/bulkEditService';
 import { ICodeEditorService } from 'vs/editor/browser/services/codeEditorService';
 import { Range } from 'vs/editor/common/core/range';
+import { RelatedContextItem, WorkspaceEdit } from 'vs/editor/common/languages';
 import { ILanguageService } from 'vs/editor/common/languages/language';
 import { ITextModel } from 'vs/editor/common/model';
+import { ILanguageFeaturesService } from 'vs/editor/common/services/languageFeatures';
 import { CopyAction } from 'vs/editor/contrib/clipboard/browser/clipboard';
 import { localize } from 'vs/nls';
 import { Action2, MenuId, registerAction2 } from 'vs/platform/actions/common/actions';
@@ -89,6 +92,11 @@ export function registerChatCodeBlockActions() {
 				return;
 			}
 
+			if (context.element.errorDetails?.responseIsFiltered) {
+				// When run from command palette
+				return;
+			}
+
 			const clipboardService = accessor.get(IClipboardService);
 			clipboardService.writeText(context.code);
 
@@ -180,6 +188,11 @@ export function registerChatCodeBlockActions() {
 			const editorService = accessor.get(IEditorService);
 			const textFileService = accessor.get(ITextFileService);
 
+			if (context.element.errorDetails?.responseIsFiltered) {
+				// When run from command palette
+				return;
+			}
+
 			if (editorService.activeEditorPane?.getId() === NOTEBOOK_EDITOR_ID) {
 				return this.handleNotebookEditor(accessor, editorService.activeEditorPane.getControl() as INotebookEditor, context);
 			}
@@ -232,17 +245,44 @@ export function registerChatCodeBlockActions() {
 			this.notifyUserAction(accessor, context);
 		}
 
-		private async handleTextEditor(accessor: ServicesAccessor, codeEditor: ICodeEditor, activeModel: ITextModel, context: IChatCodeBlockActionContext) {
-			this.notifyUserAction(accessor, context);
+		private async handleTextEditor(accessor: ServicesAccessor, codeEditor: ICodeEditor, activeModel: ITextModel, chatCodeBlockActionContext: IChatCodeBlockActionContext) {
+			this.notifyUserAction(accessor, chatCodeBlockActionContext);
+
 			const bulkEditService = accessor.get(IBulkEditService);
 			const codeEditorService = accessor.get(ICodeEditorService);
 
-			const activeSelection = codeEditor.getSelection() ?? new Range(activeModel.getLineCount(), 1, activeModel.getLineCount(), 1);
-			await bulkEditService.apply([new ResourceTextEdit(activeModel.uri, {
-				range: activeSelection,
-				text: context.code,
-			})]);
+			const mappedEditsProviders = accessor.get(ILanguageFeaturesService).mappedEditsProvider.ordered(activeModel);
 
+			// try applying workspace edit that was returned by a MappedEditsProvider, else simply insert at selection
+
+			let workspaceEdit: WorkspaceEdit | null = null;
+
+			if (mappedEditsProviders.length > 0) {
+				const mostRelevantProvider = mappedEditsProviders[0];
+
+				const selections = codeEditor.getSelections() ?? [];
+				const mappedEditsContext = {
+					selections,
+					related: [] as RelatedContextItem[], // TODO@ulugbekna: we do have not yet decided what to populate this with
+				};
+				const cancellationTokenSource = new CancellationTokenSource();
+
+				workspaceEdit = await mostRelevantProvider.provideMappedEdits(
+					activeModel,
+					[chatCodeBlockActionContext.code],
+					mappedEditsContext,
+					cancellationTokenSource.token);
+			}
+
+			if (workspaceEdit) {
+				await bulkEditService.apply(workspaceEdit);
+			} else {
+				const activeSelection = codeEditor.getSelection() ?? new Range(activeModel.getLineCount(), 1, activeModel.getLineCount(), 1);
+				await bulkEditService.apply([new ResourceTextEdit(activeModel.uri, {
+					range: activeSelection,
+					text: chatCodeBlockActionContext.code,
+				})]);
+			}
 			codeEditorService.listCodeEditors().find(editor => editor.getModel()?.uri.toString() === activeModel.uri.toString())?.focus();
 		}
 
@@ -282,6 +322,11 @@ export function registerChatCodeBlockActions() {
 		}
 
 		override async runWithContext(accessor: ServicesAccessor, context: IChatCodeBlockActionContext) {
+			if (context.element.errorDetails?.responseIsFiltered) {
+				// When run from command palette
+				return;
+			}
+
 			const editorService = accessor.get(IEditorService);
 			const chatService = accessor.get(IChatService);
 			editorService.openEditor(<IUntitledTextResourceEditorInput>{ contents: context.code, languageId: context.languageId, resource: undefined });
@@ -328,6 +373,11 @@ export function registerChatCodeBlockActions() {
 		}
 
 		override async runWithContext(accessor: ServicesAccessor, context: IChatCodeBlockActionContext) {
+			if (context.element.errorDetails?.responseIsFiltered) {
+				// When run from command palette
+				return;
+			}
+
 			const chatService = accessor.get(IChatService);
 			const terminalService = accessor.get(ITerminalService);
 			const editorService = accessor.get(IEditorService);
