@@ -5,12 +5,12 @@
 
 import { DeferredPromise } from 'vs/base/common/async';
 import { Emitter, Event } from 'vs/base/common/event';
-import { IMarkdownString, MarkdownString } from 'vs/base/common/htmlContent';
+import { IMarkdownString, MarkdownString, isMarkdownString } from 'vs/base/common/htmlContent';
 import { Disposable } from 'vs/base/common/lifecycle';
 import { URI, UriComponents } from 'vs/base/common/uri';
 import { generateUuid } from 'vs/base/common/uuid';
 import { ILogService } from 'vs/platform/log/common/log';
-import { IChat, IChatFollowup, IChatProgress, IChatReplyFollowup, IChatResponse, IChatResponseErrorDetails, InteractiveSessionVoteDirection } from 'vs/workbench/contrib/chat/common/chatService';
+import { IChat, IChatFollowup, IChatProgress, IChatReplyFollowup, IChatResponse, IChatResponseErrorDetails, IChatResponseProgressFileTreeData, InteractiveSessionVoteDirection } from 'vs/workbench/contrib/chat/common/chatService';
 
 export interface IChatRequestModel {
 	readonly id: string;
@@ -22,6 +22,13 @@ export interface IChatRequestModel {
 	readonly response: IChatResponseModel | undefined;
 }
 
+export interface IResponse {
+	readonly value: (IMarkdownString | IPlaceholderMarkdownString | IChatResponseProgressFileTreeData)[];
+	onDidChangeValue: Event<void>;
+	updateContent(responsePart: string | IMarkdownString | { treeData: IChatResponseProgressFileTreeData } | { placeholder: string; resolvedContent?: Promise<string | IMarkdownString | { treeData: IChatResponseProgressFileTreeData }> }, quiet?: boolean): void;
+	asString(): string;
+}
+
 export interface IChatResponseModel {
 	readonly onDidChange: Event<void>;
 	readonly id: string;
@@ -30,7 +37,7 @@ export interface IChatResponseModel {
 	readonly username: string;
 	readonly avatarIconUri?: URI;
 	readonly session: IChatModel;
-	readonly response: IMarkdownString;
+	readonly response: IResponse;
 	readonly isComplete: boolean;
 	readonly isCanceled: boolean;
 	readonly vote: InteractiveSessionVoteDirection | undefined;
@@ -81,55 +88,99 @@ export class ChatRequestModel implements IChatRequestModel {
 	}
 }
 
+export interface IPlaceholderMarkdownString extends IMarkdownString {
+	isPlaceholder: boolean;
+}
 
-interface ResponsePart { string: IMarkdownString; resolving?: boolean }
-class Response {
+type ResponsePart = { string: IMarkdownString; isPlaceholder?: boolean } | { treeData: IChatResponseProgressFileTreeData; isPlaceholder?: undefined };
+export class Response implements IResponse {
 	private _onDidChangeValue = new Emitter<void>();
 	public get onDidChangeValue() {
 		return this._onDidChangeValue.event;
 	}
 
+	// responseParts internally tracks all the response parts, including strings which are currently resolving, so that they can be updated when they do resolve
 	private _responseParts: ResponsePart[];
-	private _responseRepr: IMarkdownString;
+	// responseData externally presents the response parts with consolidated contiguous strings (including strings which were previously resolving)
+	private _responseData: (IMarkdownString | IPlaceholderMarkdownString | IChatResponseProgressFileTreeData)[];
+	// responseRepr externally presents the response parts with consolidated contiguous strings (excluding tree data)
+	private _responseRepr: string;
 
-	get value(): IMarkdownString {
+	get value(): (IMarkdownString | IPlaceholderMarkdownString | IChatResponseProgressFileTreeData)[] {
+		return this._responseData;
+	}
+
+	constructor(value: IMarkdownString | (IMarkdownString | IChatResponseProgressFileTreeData)[]) {
+		this._responseData = Array.isArray(value) ? value : [value];
+		this._responseParts = Array.isArray(value) ? value.map((v) => ('value' in v ? { string: v } : { treeData: v })) : [{ string: value }];
+		this._responseRepr = this._responseParts.map((part) => {
+			if (isCompleteInteractiveProgressTreeData(part)) {
+				return '';
+			}
+			return part.string.value;
+		}).join('\n');
+	}
+
+	asString(): string {
 		return this._responseRepr;
 	}
 
-	constructor(value: IMarkdownString) {
-		this._responseRepr = value;
-		this._responseParts = [{ string: value }];
-	}
-
-	updateContent(responsePart: string | { placeholder: string; resolvedContent?: Promise<string> }, quiet?: boolean): void {
-		if (typeof responsePart === 'string') {
+	updateContent(responsePart: string | IMarkdownString | { treeData: IChatResponseProgressFileTreeData } | { placeholder: string; resolvedContent?: Promise<string | { treeData: IChatResponseProgressFileTreeData }> }, quiet?: boolean): void {
+		if (typeof responsePart === 'string' || isMarkdownString(responsePart)) {
 			const responsePartLength = this._responseParts.length - 1;
 			const lastResponsePart = this._responseParts[responsePartLength];
 
-			if (lastResponsePart.resolving === true) {
-				// The last part is resolving, start a new part
-				this._responseParts.push({ string: new MarkdownString(responsePart) });
+			if (lastResponsePart.isPlaceholder === true || isCompleteInteractiveProgressTreeData(lastResponsePart)) {
+				// The last part is resolving or a tree data item, start a new part
+				this._responseParts.push({ string: typeof responsePart === 'string' ? new MarkdownString(responsePart) : responsePart });
 			} else {
-				// Combine this part with the last, non-resolving part
-				this._responseParts[responsePartLength] = { string: new MarkdownString(lastResponsePart.string.value + responsePart) };
+				// Combine this part with the last, non-resolving string part
+				if (isMarkdownString(responsePart)) {
+					this._responseParts[responsePartLength] = { string: new MarkdownString(lastResponsePart.string.value + responsePart.value, responsePart) };
+				} else {
+					this._responseParts[responsePartLength] = { string: new MarkdownString(lastResponsePart.string.value + responsePart, lastResponsePart.string) };
+				}
 			}
 
 			this._updateRepr(quiet);
-		} else {
+		} else if ('placeholder' in responsePart) {
 			// Add a new resolving part
-			const responsePosition = this._responseParts.push({ string: new MarkdownString(responsePart.placeholder), resolving: true }) - 1;
+			const responsePosition = this._responseParts.push({ string: new MarkdownString(responsePart.placeholder), isPlaceholder: true }) - 1;
 			this._updateRepr(quiet);
 
 			responsePart.resolvedContent?.then((content) => {
 				// Replace the resolving part's content with the resolved response
-				this._responseParts[responsePosition] = { string: new MarkdownString(content), resolving: true };
-				this._updateRepr(quiet);
+				if (typeof content === 'string') {
+					this._responseParts[responsePosition] = { string: new MarkdownString(content), isPlaceholder: true };
+					this._updateRepr(quiet);
+				} else if (content.treeData) {
+					this._responseParts[responsePosition] = { treeData: content.treeData };
+					this._updateRepr(quiet);
+				}
 			});
+		} else if (isCompleteInteractiveProgressTreeData(responsePart)) {
+			this._responseParts.push(responsePart);
+			this._updateRepr(quiet);
 		}
 	}
 
 	private _updateRepr(quiet?: boolean) {
-		this._responseRepr = new MarkdownString(this._responseParts.map(r => r.string.value).join('\n\n'));
+		this._responseData = this._responseParts.map(part => {
+			if (isCompleteInteractiveProgressTreeData(part)) {
+				return part.treeData;
+			} else if (part.isPlaceholder) {
+				return { ...part.string, isPlaceholder: true };
+			}
+			return part.string;
+		});
+
+		this._responseRepr = this._responseParts.map(part => {
+			if (isCompleteInteractiveProgressTreeData(part)) {
+				return '';
+			}
+			return part.string.value;
+		}).join('\n\n');
+
 		if (!quiet) {
 			this._onDidChangeValue.fire();
 		}
@@ -167,9 +218,9 @@ export class ChatResponseModel extends Disposable implements IChatResponseModel
 		return this._followups;
 	}
 
-	private _response: Response;
-	public get response(): IMarkdownString {
-		return this._response.value;
+	private _response: IResponse;
+	public get response(): IResponse {
+		return this._response;
 	}
 
 	public get errorDetails(): IChatResponseErrorDetails | undefined {
@@ -189,7 +240,7 @@ export class ChatResponseModel extends Disposable implements IChatResponseModel
 	}
 
 	constructor(
-		_response: IMarkdownString,
+		_response: IMarkdownString | (IMarkdownString | IChatResponseProgressFileTreeData)[],
 		public readonly session: ChatModel,
 		private _isComplete: boolean = false,
 		private _isCanceled = false,
@@ -204,7 +255,7 @@ export class ChatResponseModel extends Disposable implements IChatResponseModel
 		this._id = 'response_' + ChatResponseModel.nextId++;
 	}
 
-	updateContent(responsePart: string | { placeholder: string; resolvedContent?: Promise<string> }, quiet?: boolean) {
+	updateContent(responsePart: string | IMarkdownString | { treeData: IChatResponseProgressFileTreeData } | { placeholder: string; resolvedContent?: Promise<string | IMarkdownString | { treeData: IChatResponseProgressFileTreeData }> }, quiet?: boolean) {
 		this._response.updateContent(responsePart, quiet);
 	}
 
@@ -261,7 +312,7 @@ export interface ISerializableChatsData {
 export interface ISerializableChatRequestData {
 	providerRequestId: string | undefined;
 	message: string;
-	response: string | undefined;
+	response: (IMarkdownString | IChatResponseProgressFileTreeData)[] | undefined;
 	responseErrorDetails: IChatResponseErrorDetails | undefined;
 	followups: IChatFollowup[] | undefined;
 	isCanceled: boolean | undefined;
@@ -433,7 +484,7 @@ export class ChatModel extends Disposable implements IChatModel {
 		return requests.map((raw: ISerializableChatRequestData) => {
 			const request = new ChatRequestModel(this, raw.message, raw.providerRequestId);
 			if (raw.response || raw.responseErrorDetails) {
-				request.response = new ChatResponseModel(new MarkdownString(raw.response), this, true, raw.isCanceled, raw.vote, raw.providerRequestId, raw.responseErrorDetails, raw.followups);
+				request.response = new ChatResponseModel(raw.response ?? [new MarkdownString(raw.response)], this, true, raw.isCanceled, raw.vote, raw.providerRequestId, raw.responseErrorDetails, raw.followups);
 			}
 			return request;
 		});
@@ -508,7 +559,7 @@ export class ChatModel extends Disposable implements IChatModel {
 
 		if ('content' in progress) {
 			request.response.updateContent(progress.content, quiet);
-		} else if ('placeholder' in progress) {
+		} else if ('placeholder' in progress || isCompleteInteractiveProgressTreeData(progress)) {
 			request.response.updateContent(progress, quiet);
 		} else {
 			request.setProviderRequestId(progress.requestId);
@@ -653,3 +704,7 @@ export class ChatWelcomeMessageModel implements IChatWelcomeMessageModel {
 		return this.session.responderAvatarIconUri;
 	}
 }
+
+export function isCompleteInteractiveProgressTreeData(item: unknown): item is { treeData: IChatResponseProgressFileTreeData } {
+	return typeof item === 'object' && !!item && 'treeData' in item;
+}
