@@ -6,23 +6,27 @@
 import { CancelablePromise, createCancelablePromise } from 'vs/base/common/async';
 import { CancellationToken } from 'vs/base/common/cancellation';
 import { Emitter, Event } from 'vs/base/common/event';
-import { MarkdownString } from 'vs/base/common/htmlContent';
+import { MarkdownString, isMarkdownString } from 'vs/base/common/htmlContent';
 import { Iterable } from 'vs/base/common/iterator';
 import { Disposable, IDisposable, toDisposable } from 'vs/base/common/lifecycle';
+import { revive } from 'vs/base/common/marshalling';
 import { StopWatch } from 'vs/base/common/stopwatch';
-import { withNullAsUndefined } from 'vs/base/common/types';
 import { URI, UriComponents } from 'vs/base/common/uri';
 import { localize } from 'vs/nls';
 import { CommandsRegistry } from 'vs/platform/commands/common/commands';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
 import { ILogService } from 'vs/platform/log/common/log';
+import { Progress } from 'vs/platform/progress/common/progress';
 import { IStorageService, StorageScope, StorageTarget } from 'vs/platform/storage/common/storage';
 import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
 import { IWorkspaceContextService } from 'vs/platform/workspace/common/workspace';
 import { CONTEXT_PROVIDER_EXISTS } from 'vs/workbench/contrib/chat/common/chatContextKeys';
-import { ChatModel, ChatWelcomeMessageModel, IChatModel, ISerializableChatData, ISerializableChatsData } from 'vs/workbench/contrib/chat/common/chatModel';
-import { IChat, IChatCompleteResponse, IChatDetail, IChatDynamicRequest, IChatProgress, IChatProvider, IChatProviderInfo, IChatReplyFollowup, IChatService, IChatTransferredSessionData, IChatUserActionEvent, ISlashCommand, ISlashCommandProvider, InteractiveSessionCopyKind, InteractiveSessionVoteDirection } from 'vs/workbench/contrib/chat/common/chatService';
+import { ChatModel, ChatWelcomeMessageModel, IChatModel, ISerializableChatData, ISerializableChatsData, isCompleteInteractiveProgressTreeData } from 'vs/workbench/contrib/chat/common/chatModel';
+import { ChatMessageRole, IChatMessage } from 'vs/workbench/contrib/chat/common/chatProvider';
+import { IChat, IChatCompleteResponse, IChatDetail, IChatDynamicRequest, IChatFollowup, IChatProgress, IChatProvider, IChatProviderInfo, IChatReplyFollowup, IChatRequest, IChatResponse, IChatService, IChatTransferredSessionData, IChatUserActionEvent, ISlashCommand, InteractiveSessionCopyKind, InteractiveSessionVoteDirection } from 'vs/workbench/contrib/chat/common/chatService';
+import { IChatSlashCommandService, IChatSlashFragment } from 'vs/workbench/contrib/chat/common/chatSlashCommands';
+import { IChatVariablesService } from 'vs/workbench/contrib/chat/common/chatVariables';
 import { IExtensionService } from 'vs/workbench/services/extensions/common/extensions';
 
 const serializedChatKey = 'interactive.sessions';
@@ -122,7 +126,7 @@ export class ChatService extends Disposable implements IChatService {
 	declare _serviceBrand: undefined;
 
 	private readonly _providers = new Map<string, IChatProvider>();
-	private readonly _slashCommandProviders = new Set<ISlashCommandProvider>();
+
 	private readonly _sessionModels = new Map<string, ChatModel>();
 	private readonly _pendingRequests = new Map<string, CancelablePromise<void>>();
 	private readonly _persistedSessions: ISerializableChatsData;
@@ -146,7 +150,9 @@ export class ChatService extends Disposable implements IChatService {
 		@IInstantiationService private readonly instantiationService: IInstantiationService,
 		@ITelemetryService private readonly telemetryService: ITelemetryService,
 		@IContextKeyService private readonly contextKeyService: IContextKeyService,
-		@IWorkspaceContextService private readonly workspaceContextService: IWorkspaceContextService
+		@IWorkspaceContextService private readonly workspaceContextService: IWorkspaceContextService,
+		@IChatSlashCommandService private readonly chatSlashCommandService: IChatSlashCommandService,
+		@IChatVariablesService private readonly chatVariablesService: IChatVariablesService
 	) {
 		super();
 
@@ -239,12 +245,26 @@ export class ChatService extends Disposable implements IChatService {
 
 	private deserializeChats(sessionData: string): ISerializableChatsData {
 		try {
-			const arrayOfSessions: ISerializableChatData[] = JSON.parse(sessionData);
+			const arrayOfSessions: ISerializableChatData[] = revive(JSON.parse(sessionData)); // Revive serialized URIs in session data
 			if (!Array.isArray(arrayOfSessions)) {
 				throw new Error('Expected array');
 			}
 
 			const sessions = arrayOfSessions.reduce((acc, session) => {
+				// Revive serialized markdown strings in response data
+				for (const request of session.requests) {
+					if (Array.isArray(request.response)) {
+						request.response = request.response.map((response) => {
+							if (typeof response === 'string') {
+								return new MarkdownString(response);
+							}
+							return response;
+						});
+					} else if (typeof request.response === 'string') {
+						request.response = [new MarkdownString(request.response)];
+					}
+				}
+
 				acc[session.sessionId] = session;
 				return acc;
 			}, {} as ISerializableChatsData);
@@ -336,7 +356,7 @@ export class ChatService extends Disposable implements IChatService {
 
 		let session: IChat | undefined;
 		try {
-			session = withNullAsUndefined(await provider.prepareSession(model.providerState, token));
+			session = await provider.prepareSession(model.providerState, token) ?? undefined;
 		} catch (err) {
 			this.trace('initializeSession', `Provider initializeSession threw: ${err}`);
 		}
@@ -347,7 +367,7 @@ export class ChatService extends Disposable implements IChatService {
 
 		this.trace('startSession', `Provider returned session`);
 
-		const welcomeMessage = model.welcomeMessage ? undefined : withNullAsUndefined(await provider.provideWelcomeMessage?.(token));
+		const welcomeMessage = model.welcomeMessage ? undefined : await provider.provideWelcomeMessage?.(token) ?? undefined;
 		const welcomeModel = welcomeMessage && new ChatWelcomeMessageModel(
 			model, welcomeMessage.map(item => typeof item === 'string' ? new MarkdownString(item) : item as IChatReplyFollowup[]));
 
@@ -430,9 +450,12 @@ export class ChatService extends Disposable implements IChatService {
 
 				gotProgress = true;
 				if ('content' in progress) {
-					this.trace('sendRequest', `Provider returned progress for session ${model.sessionId}, ${progress.content.length} chars`);
+					this.trace('sendRequest', `Provider returned progress for session ${model.sessionId}, ${typeof progress.content === 'string' ? progress.content.length : progress.content.value.length} chars`);
 				} else if ('placeholder' in progress) {
 					this.trace('sendRequest', `Provider returned placeholder for session ${model.sessionId}, ${progress.placeholder}`);
+				} else if (isCompleteInteractiveProgressTreeData(progress)) {
+					// This isn't exposed in API
+					this.trace('sendRequest', `Provider returned tree data for session ${model.sessionId}, ${progress.treeData.label}`);
 				} else {
 					this.trace('sendRequest', `Provider returned id for session ${model.sessionId}, ${progress.requestId}`);
 				}
@@ -441,7 +464,7 @@ export class ChatService extends Disposable implements IChatService {
 			};
 
 			const stopWatch = new StopWatch(false);
-			token.onCancellationRequested(() => {
+			const listener = token.onCancellationRequested(() => {
 				this.trace('sendRequest', `Request for session ${model.sessionId} was cancelled`);
 				this.telemetryService.publicLog2<ChatProviderInvokedEvent, ChatProviderInvokedClassification>('interactiveSessionProviderInvoked', {
 					providerId: provider.id,
@@ -455,42 +478,91 @@ export class ChatService extends Disposable implements IChatService {
 
 				model.cancelRequest(request);
 			});
-			if (usedSlashCommand?.command) {
-				this._onDidSubmitSlashCommand.fire({ slashCommand: usedSlashCommand.command, sessionId: model.sessionId });
-			}
-			let rawResponse = await provider.provideReply({ session: model.session!, message: resolvedCommand }, progressCallback, token);
-			if (token.isCancellationRequested) {
-				return;
-			} else {
-				if (!rawResponse) {
-					this.trace('sendRequest', `Provider returned no response for session ${model.sessionId}`);
-					rawResponse = { session: model.session!, errorDetails: { message: localize('emptyResponse', "Provider returned null response") } };
+
+			try {
+				if (usedSlashCommand?.command) {
+					this._onDidSubmitSlashCommand.fire({ slashCommand: usedSlashCommand.command, sessionId: model.sessionId });
 				}
 
-				const result = rawResponse.errorDetails?.responseIsFiltered ? 'filtered' :
-					rawResponse.errorDetails && gotProgress ? 'errorWithOutput' :
-						rawResponse.errorDetails ? 'error' :
-							'success';
-				this.telemetryService.publicLog2<ChatProviderInvokedEvent, ChatProviderInvokedClassification>('interactiveSessionProviderInvoked', {
-					providerId: provider.id,
-					timeToFirstProgress: rawResponse.timings?.firstProgress ?? 0,
-					totalTime: rawResponse.timings?.totalElapsed ?? 0,
-					result,
-					requestType,
-					slashCommand: usedSlashCommand?.command
-				});
-				model.setResponse(request, rawResponse);
-				this.trace('sendRequest', `Provider returned response for session ${model.sessionId}`);
+				let rawResponse: IChatResponse | null | undefined;
+				let slashCommandFollowups: IChatFollowup[] | void = [];
+
+				if ((typeof resolvedCommand === 'string' && typeof message === 'string' && this.chatSlashCommandService.hasCommand(resolvedCommand))) {
+					// contributed slash commands
+					// TODO: spell this out in the UI
+					const history: IChatMessage[] = [];
+					for (const request of model.getRequests()) {
+						if (typeof request.message !== 'string' || !request.response) {
+							continue;
+						}
+						if (isMarkdownString(request.response.response.value)) {
+							history.push({ role: ChatMessageRole.User, content: request.message });
+							history.push({ role: ChatMessageRole.Assistant, content: request.response.response.value.value });
+						}
+					}
+					const commandResult = await this.chatSlashCommandService.executeCommand(resolvedCommand, message.substring(resolvedCommand.length + 1).trimStart(), new Progress<IChatSlashFragment>(p => {
+						const { content } = p;
+						const data = isCompleteInteractiveProgressTreeData(content) ? content : { content };
+						progressCallback(data);
+					}), history, token);
+					slashCommandFollowups = commandResult?.followUp;
+					rawResponse = { session: model.session! };
 
-				// TODO refactor this or rethink the API https://github.com/microsoft/vscode-copilot/issues/593
-				if (provider.provideFollowups) {
-					Promise.resolve(provider.provideFollowups(model.session!, CancellationToken.None)).then(followups => {
-						model.setFollowups(request, withNullAsUndefined(followups));
-						model.completeResponse(request);
-					});
 				} else {
-					model.completeResponse(request);
+					const request: IChatRequest = {
+						session: model.session!,
+						message: resolvedCommand,
+						variables: {}
+					};
+
+					if (typeof request.message === 'string') {
+						const varResult = await this.chatVariablesService.resolveVariables(request.message, model, token);
+						request.variables = varResult.variables;
+						request.message = varResult.prompt;
+					}
+
+					rawResponse = await provider.provideReply(request, progressCallback, token);
 				}
+
+				if (token.isCancellationRequested) {
+					return;
+				} else {
+					if (!rawResponse) {
+						this.trace('sendRequest', `Provider returned no response for session ${model.sessionId}`);
+						rawResponse = { session: model.session!, errorDetails: { message: localize('emptyResponse', "Provider returned null response") } };
+					}
+
+					const result = rawResponse.errorDetails?.responseIsFiltered ? 'filtered' :
+						rawResponse.errorDetails && gotProgress ? 'errorWithOutput' :
+							rawResponse.errorDetails ? 'error' :
+								'success';
+					this.telemetryService.publicLog2<ChatProviderInvokedEvent, ChatProviderInvokedClassification>('interactiveSessionProviderInvoked', {
+						providerId: provider.id,
+						timeToFirstProgress: rawResponse.timings?.firstProgress ?? 0,
+						totalTime: rawResponse.timings?.totalElapsed ?? 0,
+						result,
+						requestType,
+						slashCommand: usedSlashCommand?.command
+					});
+					model.setResponse(request, rawResponse);
+					this.trace('sendRequest', `Provider returned response for session ${model.sessionId}`);
+
+					// TODO refactor this or rethink the API https://github.com/microsoft/vscode-copilot/issues/593
+					if (provider.provideFollowups) {
+						Promise.resolve(provider.provideFollowups(model.session!, CancellationToken.None)).then(providerFollowups => {
+							const allFollowups = providerFollowups?.concat(slashCommandFollowups ?? []);
+							model.setFollowups(request, allFollowups ?? undefined);
+							model.completeResponse(request);
+						});
+					} else if (slashCommandFollowups?.length) {
+						model.setFollowups(request, slashCommandFollowups);
+						model.completeResponse(request);
+					} else {
+						model.completeResponse(request);
+					}
+				}
+			} finally {
+				listener.dispose();
 			}
 		});
 		this._pendingRequests.set(model.sessionId, rawResponsePromise);
@@ -519,11 +591,10 @@ export class ChatService extends Disposable implements IChatService {
 	private async handleSlashCommand(sessionId: string, command: string): Promise<string> {
 		const slashCommands = await this.getSlashCommands(sessionId, CancellationToken.None);
 		for (const slashCommand of slashCommands ?? []) {
-			if (command.startsWith(`/${slashCommand.command}`) && slashCommand.provider) {
-				return await slashCommand.provider.resolveSlashCommand(command, CancellationToken.None) ?? command;
+			if (command.startsWith(`/${slashCommand.command}`) && this.chatSlashCommandService.hasCommand(slashCommand.command)) {
+				return slashCommand.command;
 			}
 		}
-
 		return command;
 	}
 
@@ -539,26 +610,27 @@ export class ChatService extends Disposable implements IChatService {
 			throw new Error(`Unknown provider: ${model.providerId}`);
 		}
 
-		if (!provider.provideSlashCommands) {
-			return;
-		}
+		const serviceResults = this.chatSlashCommandService.getCommands().map(data => {
+			return <ISlashCommand>{
+				command: data.command,
+				detail: data.detail,
+				sortText: data.sortText,
+				executeImmediately: data.executeImmediately
+			};
+		});
 
-		const mainProviderRequest = provider.provideSlashCommands(model.session!, token);
-		const slashCommandProviders = Array.from(this._slashCommandProviders).filter(p => p.chatProviderId === model.providerId);
-		const providerResults = Promise.all([
-			mainProviderRequest,
-			...slashCommandProviders.map(p => Promise.resolve(p.provideSlashCommands(token))
-				.then(commands => commands?.map(c => ({ ...c, provider: p }))))
-		]);
+		const mainProviderRequest = provider.provideSlashCommands?.(model.session!, token);
 
 		try {
-			const slashCommands = (await providerResults).filter(c => !!c) as ISlashCommand[][];
-			return withNullAsUndefined(slashCommands.flat());
+			const providerResults = await mainProviderRequest;
+			if (providerResults) {
+				return providerResults.concat(serviceResults);
+			}
+			return serviceResults;
+
 		} catch (e) {
 			this.logService.error(e);
-
-			// If one of the other contributed providers fails, return the main provider's result
-			return withNullAsUndefined(await mainProviderRequest);
+			return serviceResults;
 		}
 	}
 
@@ -610,13 +682,22 @@ export class ChatService extends Disposable implements IChatService {
 
 		await model.waitForInitialization();
 		const request = model.addRequest(message);
-		model.acceptResponseProgress(request, {
-			content: response.message,
-		}, true);
+		if (typeof response.message === 'string') {
+			model.acceptResponseProgress(request, { content: response.message });
+		} else {
+			for (const part of response.message) {
+				const progress = isMarkdownString(part) ? { content: part.value } : { treeData: part };
+				model.acceptResponseProgress(request, progress, true);
+			}
+		}
 		model.setResponse(request, {
 			session: model.session!,
 			errorDetails: response.errorDetails,
 		});
+		if (response.followups !== undefined) {
+			model.setFollowups(request, response.followups);
+		}
+		model.completeResponse(request);
 	}
 
 	cancelCurrentRequestForSession(sessionId: string): void {
@@ -659,16 +740,6 @@ export class ChatService extends Disposable implements IChatService {
 		});
 	}
 
-	registerSlashCommandProvider(provider: ISlashCommandProvider): IDisposable {
-		this.trace('registerProvider', `Adding new slash command provider`);
-
-		this._slashCommandProviders.add(provider);
-		return toDisposable(() => {
-			this.trace('registerProvider', `Disposing slash command provider`);
-			this._slashCommandProviders.delete(provider);
-		});
-	}
-
 	getProviderInfos(): IChatProviderInfo[] {
 		return Array.from(this._providers.values()).map(provider => {
 			return {
