@@ -6,6 +6,7 @@
 import './menuPreventer';
 import './accessibility/accessibility';
 import './diffEditorHelper';
+import './editorFeatures';
 import './editorSettingsMigration';
 import './inspectKeybindings';
 import './largeFileOptimizations';
@@ -21,3 +22,4 @@ import './toggleRenderWhitespace';
 import './toggleWordWrap';
 import './untitledTextEditorHint/untitledTextEditorHint';
 import './workbenchReferenceSearch';
+import './editorLineNumberMenu';
