@@ -80,14 +80,14 @@ export interface ICommentService {
 	readonly onDidUpdateCommentingRanges: Event<{ owner: string }>;
 	readonly onDidChangeActiveCommentingRange: Event<{ range: Range; commentingRangesInfo: CommentingRanges }>;
 	readonly onDidSetDataProvider: Event<void>;
-	readonly onDidDeleteDataProvider: Event<string>;
+	readonly onDidDeleteDataProvider: Event<string | undefined>;
 	readonly onDidChangeCommentingEnabled: Event<boolean>;
 	readonly isCommentingEnabled: boolean;
 	setDocumentComments(resource: URI, commentInfos: ICommentInfo[]): void;
 	setWorkspaceComments(owner: string, commentsByResource: CommentThread<IRange | ICellRange>[]): void;
 	removeWorkspaceComments(owner: string): void;
 	registerCommentController(owner: string, commentControl: ICommentController): void;
-	unregisterCommentController(owner: string): void;
+	unregisterCommentController(owner?: string): void;
 	getCommentController(owner: string): ICommentController | undefined;
 	createCommentThreadTemplate(owner: string, resource: URI, range: Range | undefined): void;
 	updateCommentThreadTemplate(owner: string, threadHandle: number, range: Range): Promise<void>;
@@ -111,8 +111,8 @@ export class CommentService extends Disposable implements ICommentService {
 	private readonly _onDidSetDataProvider: Emitter<void> = this._register(new Emitter<void>());
 	readonly onDidSetDataProvider: Event<void> = this._onDidSetDataProvider.event;
 
-	private readonly _onDidDeleteDataProvider: Emitter<string> = this._register(new Emitter<string>());
-	readonly onDidDeleteDataProvider: Event<string> = this._onDidDeleteDataProvider.event;
+	private readonly _onDidDeleteDataProvider: Emitter<string | undefined> = this._register(new Emitter<string | undefined>());
+	readonly onDidDeleteDataProvider: Event<string | undefined> = this._onDidDeleteDataProvider.event;
 
 	private readonly _onDidSetResourceCommentInfos: Emitter<IResourceCommentThreadEvent> = this._register(new Emitter<IResourceCommentThreadEvent>());
 	readonly onDidSetResourceCommentInfos: Event<IResourceCommentThreadEvent> = this._onDidSetResourceCommentInfos.event;
@@ -239,8 +239,12 @@ export class CommentService extends Disposable implements ICommentService {
 		this._onDidSetDataProvider.fire();
 	}
 
-	unregisterCommentController(owner: string): void {
-		this._commentControls.delete(owner);
+	unregisterCommentController(owner?: string): void {
+		if (owner) {
+			this._commentControls.delete(owner);
+		} else {
+			this._commentControls.clear();
+		}
 		this._onDidDeleteDataProvider.fire(owner);
 	}
 
