@@ -28,6 +28,7 @@ import { commentThreadStateBackgroundColorVar, commentThreadStateColorVar } from
 import { ICellRange } from 'vs/workbench/contrib/notebook/common/notebookRange';
 import { FontInfo } from 'vs/editor/common/config/fontInfo';
 import { IContextMenuService } from 'vs/platform/contextview/browser/contextView';
+import { registerNavigableContainer } from 'vs/workbench/browser/actions/widgetNavigationCommands';
 
 export const COMMENTEDITOR_DECORATION_KEY = 'commenteditordecoration';
 
@@ -91,6 +92,21 @@ export class CommentThreadWidget<T extends IRange | ICellRange = IRange> extends
 		const bodyElement = <HTMLDivElement>dom.$('.body');
 		container.appendChild(bodyElement);
 
+		const tracker = this._register(dom.trackFocus(bodyElement));
+		this._register(registerNavigableContainer({
+			focusNotifiers: [tracker],
+			focusNextWidget: () => {
+				if (!this._commentReply?.isCommentEditorFocused()) {
+					this._commentReply?.expandReplyAreaAndFocusCommentEditor();
+				}
+			},
+			focusPreviousWidget: () => {
+				if (this._commentReply?.isCommentEditorFocused() && this._commentThread.comments?.length) {
+					this._body.focus();
+				}
+			}
+		}));
+
 		this._body = this._scopedInstatiationService.createInstance(
 			CommentThreadBody,
 			this._owner,
