@@ -6,6 +6,8 @@
 export interface ICommentsConfiguration {
 	openView: 'never' | 'file' | 'firstFile';
 	useRelativeTime: boolean;
+	visible: boolean;
+	maxHeight: boolean;
 }
 
 export const COMMENTS_SECTION = 'comments';
