@@ -4,6 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { VSBuffer } from 'vs/base/common/buffer';
+import { IMarkdownString } from 'vs/base/common/htmlContent';
 import { IReference } from 'vs/base/common/lifecycle';
 import { Schemas } from 'vs/base/common/network';
 import { basename } from 'vs/base/common/path';
@@ -251,6 +252,13 @@ export class CustomEditorInput extends LazilyResolvedWebviewEditorInput {
 		return CustomEditorInput.create(this.instantiationService, this.resource, this.viewType, this.group, this.webview.options);
 	}
 
+	public override isReadonly(): boolean | IMarkdownString {
+		if (!this._modelRef) {
+			return this.filesConfigurationService.isReadonly(this.resource);
+		}
+		return this._modelRef.object.isReadonly();
+	}
+
 	public override isDirty(): boolean {
 		if (!this._modelRef) {
 			return !!this._defaultDirtyState;
