@@ -14,10 +14,12 @@ import { coalesce } from 'vs/base/common/arrays';
 import { CancellationToken, CancellationTokenSource } from 'vs/base/common/cancellation';
 import { KeyCode } from 'vs/base/common/keyCodes';
 import * as lifecycle from 'vs/base/common/lifecycle';
+import { clamp } from 'vs/base/common/numbers';
 import { isMacintosh } from 'vs/base/common/platform';
 import { ScrollbarVisibility } from 'vs/base/common/scrollable';
 import { ContentWidgetPositionPreference, ICodeEditor, IContentWidget, IContentWidgetPosition } from 'vs/editor/browser/editorBrowser';
 import { ConfigurationChangedEvent, EditorOption } from 'vs/editor/common/config/editorOptions';
+import { IDimension } from 'vs/editor/common/core/dimension';
 import { Position } from 'vs/editor/common/core/position';
 import { Range } from 'vs/editor/common/core/range';
 import { ModelDecorationOptions } from 'vs/editor/common/model/textModel';
@@ -91,6 +93,9 @@ export class DebugHoverWidget implements IContentWidget {
 	private scrollbar!: DomScrollableElement;
 	private debugHoverComputer: DebugHoverComputer;
 
+	private expressionToRender: IExpression | undefined;
+	private isUpdatingTree = false;
+
 	constructor(
 		private editor: ICodeEditor,
 		@IDebugService private readonly debugService: IDebugService,
@@ -138,7 +143,18 @@ export class DebugHoverWidget implements IContentWidget {
 		this.domNode.style.border = `1px solid ${asCssVariable(editorHoverBorder)}`;
 		this.domNode.style.color = asCssVariable(editorHoverForeground);
 
-		this.toDispose.push(this.tree.onDidChangeContentHeight(() => this.layoutTreeAndContainer(false)));
+		this.toDispose.push(this.tree.onDidChangeContentHeight(() => {
+			if (!this.isUpdatingTree) {
+				// Don't do a layout in the middle of the async setInput
+				this.layoutTreeAndContainer();
+			}
+		}));
+		this.toDispose.push(this.tree.onDidChangeContentWidth(() => {
+			if (!this.isUpdatingTree) {
+				// Don't do a layout in the middle of the async setInput
+				this.layoutTreeAndContainer();
+			}
+		}));
 
 		this.registerListeners();
 		this.editor.addContentWidget(this);
@@ -261,10 +277,10 @@ export class DebugHoverWidget implements IContentWidget {
 
 		this.valueContainer.hidden = true;
 
-		await this.tree.setInput(expression);
+		this.expressionToRender = expression;
 		this.complexValueTitle.textContent = expression.value;
 		this.complexValueTitle.title = expression.value;
-		this.layoutTreeAndContainer(true);
+		this.editor.layoutContentWidget(this);
 		this.tree.scrollTop = 0;
 		this.tree.scrollLeft = 0;
 		this.complexValueContainer.hidden = false;
@@ -275,15 +291,38 @@ export class DebugHoverWidget implements IContentWidget {
 		}
 	}
 
-	private layoutTreeAndContainer(initialLayout: boolean): void {
+	private layoutTreeAndContainer(): void {
+		this.layoutTree();
+		this.editor.layoutContentWidget(this);
+	}
+
+	private layoutTree(): void {
 		const scrollBarHeight = 10;
 		const treeHeight = Math.min(Math.max(266, this.editor.getLayoutInfo().height * 0.55), this.tree.contentHeight + scrollBarHeight);
+
+		const realTreeWidth = this.tree.contentWidth;
+		const treeWidth = clamp(realTreeWidth, 400, 550);
+		this.tree.layout(treeHeight, treeWidth);
 		this.treeContainer.style.height = `${treeHeight}px`;
-		this.tree.layout(treeHeight, initialLayout ? 400 : undefined);
-		this.editor.layoutContentWidget(this);
 		this.scrollbar.scanDomNode();
 	}
 
+	beforeRender(): IDimension | null {
+		// beforeRender will be called each time the hover size changes, and the content widget is layed out again.
+		if (this.expressionToRender) {
+			const expression = this.expressionToRender;
+			this.expressionToRender = undefined;
+
+			// Do this in beforeRender once the content widget is no longer display=none so that its elements' sizes will be measured correctly.
+			this.isUpdatingTree = true;
+			this.tree.setInput(expression).finally(() => {
+				this.isUpdatingTree = false;
+			});
+		}
+
+		return null;
+	}
+
 	afterRender(positionPreference: ContentWidgetPositionPreference | null) {
 		if (positionPreference) {
 			// Remember where the editor placed you to keep position stable #109226
