@@ -41,6 +41,7 @@ import { isAbsolute } from 'vs/base/common/path';
 import { Constants } from 'vs/base/common/uint';
 import { applyFontInfo } from 'vs/editor/browser/config/domFontInfo';
 import { binarySearch2 } from 'vs/base/common/arrays';
+import { ILogService } from 'vs/platform/log/common/log';
 
 interface IDisassembledInstructionEntry {
 	allowBreakpoint: boolean;
@@ -581,7 +582,8 @@ class InstructionRenderer extends Disposable implements ITableRenderer<IDisassem
 		@IThemeService themeService: IThemeService,
 		@IEditorService private readonly editorService: IEditorService,
 		@ITextModelService private readonly textModelService: ITextModelService,
-		@IUriIdentityService readonly uriService: IUriIdentityService,
+		@IUriIdentityService private readonly uriService: IUriIdentityService,
+		@ILogService private readonly logService: ILogService,
 	) {
 		super();
 
@@ -741,7 +743,7 @@ class InstructionRenderer extends Disposable implements ITableRenderer<IDisassem
 			return this.uriService.asCanonicalUri(URI.file(path));
 		}
 
-		return getUriFromSource(instruction.location!, instruction.location!.path, this._disassemblyView.debugSession!.getId(), this.uriService);
+		return getUriFromSource(instruction.location!, instruction.location!.path, this._disassemblyView.debugSession!.getId(), this.uriService, this.logService);
 	}
 
 	private applyFontInfo(element: HTMLElement) {
