@@ -147,7 +147,11 @@ export class TextFileEditor extends AbstractTextCodeEditor<ICodeEditorViewState>
 			// was already asked for being readonly or not. The rationale is that
 			// a resolved model might have more specific information about being
 			// readonly or not that the input did not have.
-			control.updateOptions({ readOnly: textFileModel.isReadonly() });
+			control.updateOptions(this.getReadonlyConfiguration(textFileModel.isReadonly()));
+
+			if (control.handleInitialized) {
+				control.handleInitialized();
+			}
 		} catch (error) {
 			await this.handleSetInputError(error, input, options);
 		}
