@@ -3,26 +3,34 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { VSBuffer } from 'vs/base/common/buffer';
 import { Event } from 'vs/base/common/event';
 import { IReference } from 'vs/base/common/lifecycle';
 import * as paths from 'vs/base/common/path';
-import { isEqual } from 'vs/base/common/resources';
+import { isEqual, joinPath } from 'vs/base/common/resources';
 import { URI } from 'vs/base/common/uri';
+import { PLAINTEXT_LANGUAGE_ID } from 'vs/editor/common/languages/modesRegistry';
 import { IResolvedTextEditorModel, ITextModelService } from 'vs/editor/common/services/resolverService';
+import { IFileDialogService } from 'vs/platform/dialogs/common/dialogs';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
-import { IUntypedEditorInput } from 'vs/workbench/common/editor';
+import { EditorInputCapabilities, GroupIdentifier, ISaveOptions, IUntypedEditorInput } from 'vs/workbench/common/editor';
 import { EditorInput } from 'vs/workbench/common/editor/editorInput';
 import { IInteractiveDocumentService } from 'vs/workbench/contrib/interactive/browser/interactiveDocumentService';
 import { IInteractiveHistoryService } from 'vs/workbench/contrib/interactive/browser/interactiveHistoryService';
-import { NotebookCellTextModel } from 'vs/workbench/contrib/notebook/common/model/notebookCellTextModel';
-import { NotebookTextModel } from 'vs/workbench/contrib/notebook/common/model/notebookTextModel';
-import { CellKind, ICellDto2, IOutputDto, IResolvedNotebookEditorModel, NotebookCellCollapseState, NotebookCellInternalMetadata, NotebookCellMetadata } from 'vs/workbench/contrib/notebook/common/notebookCommon';
+import { IResolvedNotebookEditorModel } from 'vs/workbench/contrib/notebook/common/notebookCommon';
 import { ICompositeNotebookEditorInput, NotebookEditorInput } from 'vs/workbench/contrib/notebook/common/notebookEditorInput';
+import { INotebookService } from 'vs/workbench/contrib/notebook/common/notebookService';
 
 export class InteractiveEditorInput extends EditorInput implements ICompositeNotebookEditorInput {
-	static create(instantiationService: IInstantiationService, resource: URI, inputResource: URI, title?: string) {
-		return instantiationService.createInstance(InteractiveEditorInput, resource, inputResource, title);
+	static create(instantiationService: IInstantiationService, resource: URI, inputResource: URI, title?: string, language?: string) {
+		return instantiationService.createInstance(InteractiveEditorInput, resource, inputResource, title, language);
+	}
+
+	private static windowNames: Record<string, string> = {};
+
+	static setName(notebookUri: URI, title: string | undefined) {
+		if (title) {
+			this.windowNames[notebookUri.path] = title;
+		}
 	}
 
 	static readonly ID: string = 'workbench.input.interactive';
@@ -35,7 +43,12 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 		return InteractiveEditorInput.ID;
 	}
 
-	private _initTitle?: string;
+	private name: string;
+
+	get language() {
+		return this._inputModelRef?.object.textEditorModel.getLanguageId() ?? this._initLanguage;
+	}
+	private _initLanguage?: string;
 
 	private _notebookEditorInput: NotebookEditorInput;
 	get notebookEditorInput() {
@@ -74,17 +87,20 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 		resource: URI,
 		inputResource: URI,
 		title: string | undefined,
+		languageId: string | undefined,
 		@IInstantiationService instantiationService: IInstantiationService,
 		@ITextModelService textModelService: ITextModelService,
-
 		@IInteractiveDocumentService interactiveDocumentService: IInteractiveDocumentService,
-		@IInteractiveHistoryService historyService: IInteractiveHistoryService
+		@IInteractiveHistoryService historyService: IInteractiveHistoryService,
+		@INotebookService private readonly _notebookService: INotebookService,
+		@IFileDialogService private readonly _fileDialogService: IFileDialogService
 	) {
 		const input = NotebookEditorInput.create(instantiationService, resource, 'interactive', {});
 		super();
 		this._notebookEditorInput = input;
 		this._register(this._notebookEditorInput);
-		this._initTitle = title;
+		this.name = title ?? InteractiveEditorInput.windowNames[resource.path] ?? paths.basename(resource.path, paths.extname(resource.path));
+		this._initLanguage = languageId;
 		this._resource = resource;
 		this._inputResource = inputResource;
 		this._inputResolver = null;
@@ -113,8 +129,10 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 		this._register(this.primary.onDidChangeCapabilities(() => this._onDidChangeCapabilities.fire()));
 	}
 
-	override isDirty() {
-		return false;
+	override get capabilities(): EditorInputCapabilities {
+		return EditorInputCapabilities.Untitled
+			| EditorInputCapabilities.Readonly
+			| EditorInputCapabilities.Scratchpad;
 	}
 
 	private async _resolveEditorModel() {
@@ -134,30 +152,58 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 			return this._inputResolver;
 		}
 
-		this._inputResolver = this._resolveEditorModel().then(editorModel => {
-			if (this._data) {
-				editorModel?.notebook.reset(this._data.notebookData.cells.map((cell: ISerializedCell) => deserializeCell(cell)), this._data.notebookData.metadata, this._data.notebookData.transientOptions);
-			}
-
-			return editorModel;
-		});
+		this._inputResolver = this._resolveEditorModel();
 
 		return this._inputResolver;
 	}
 
-	async resolveInput(language: string) {
+	async resolveInput(language?: string) {
 		if (this._inputModelRef) {
 			return this._inputModelRef.object.textEditorModel;
 		}
 
-		this._interactiveDocumentService.willCreateInteractiveDocument(this.resource!, this.inputResource, language);
+		const resolvedLanguage = language ?? this._initLanguage ?? PLAINTEXT_LANGUAGE_ID;
+		this._interactiveDocumentService.willCreateInteractiveDocument(this.resource!, this.inputResource, resolvedLanguage);
 		this._inputModelRef = await this._textModelService.createModelReference(this.inputResource);
 
-		if (this._data && this._data.inputData) {
-			this._inputModelRef.object.textEditorModel.setValue(this._data.inputData.value);
+		return this._inputModelRef.object.textEditorModel;
+	}
+
+	override async save(group: GroupIdentifier, options?: ISaveOptions): Promise<EditorInput | IUntypedEditorInput | undefined> {
+		if (this._editorModelReference) {
+
+			if (this.hasCapability(EditorInputCapabilities.Untitled)) {
+				return this.saveAs(group, options);
+			} else {
+				await this._editorModelReference.save(options);
+			}
+
+			return this;
 		}
 
-		return this._inputModelRef.object.textEditorModel;
+		return undefined;
+	}
+
+	override async saveAs(group: GroupIdentifier, options?: ISaveOptions): Promise<IUntypedEditorInput | undefined> {
+		if (!this._editorModelReference) {
+			return undefined;
+		}
+
+		const provider = this._notebookService.getContributedNotebookType('interactive');
+
+		if (!provider) {
+			return undefined;
+		}
+
+		const filename = this.getName() + '.ipynb';
+		const pathCandidate = joinPath(await this._fileDialogService.defaultFilePath(), filename);
+
+		const target = await this._fileDialogService.pickFileToSave(pathCandidate, options?.availableFileSystems);
+		if (!target) {
+			return undefined; // save cancelled
+		}
+
+		return await this._editorModelReference.saveAs(target);
 	}
 
 	override matches(otherInput: EditorInput | IUntypedEditorInput): boolean {
@@ -171,47 +217,13 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 	}
 
 	override getName() {
-		if (this._initTitle) {
-			return this._initTitle;
-		}
-
-		const p = this.primary.resource!.path;
-		const basename = paths.basename(p);
-
-		return basename.substr(0, basename.length - paths.extname(p).length);
+		return this.name;
 	}
 
-	getSerialization(): { notebookData: any | undefined; inputData: any | undefined } {
-		return {
-			notebookData: this._serializeNotebook(this._editorModelReference?.notebook),
-			inputData: this._inputModelRef ? {
-				value: this._inputModelRef.object.textEditorModel.getValue(),
-				language: this._inputModelRef.object.textEditorModel.getLanguageId()
-			} : undefined
-		};
+	override isModified() {
+		return this._editorModelReference?.isModified() ?? false;
 	}
 
-	private _data: { notebookData: any | undefined; inputData: any | undefined } | undefined;
-
-	async restoreSerialization(data: { notebookData: any | undefined; inputData: any | undefined } | undefined) {
-		this._data = data;
-	}
-
-	private _serializeNotebook(notebook?: NotebookTextModel) {
-		if (!notebook) {
-			return undefined;
-		}
-
-		const cells = notebook.cells.map(cell => serializeCell(cell));
-
-		return {
-			cells: cells,
-			metadata: notebook.metadata,
-			transientOptions: notebook.transientOptions
-		};
-	}
-
-
 	override dispose() {
 		// we support closing the interactive window without prompt, so the editor model should not be dirty
 		this._editorModelReference?.revert({ soft: true });
@@ -229,74 +241,3 @@ export class InteractiveEditorInput extends EditorInput implements ICompositeNot
 		return this._historyService;
 	}
 }
-
-/**
- * Serialization of interactive notebook.
- * This is not placed in notebook land as regular notebooks are handled by file service directly.
- */
-
-interface ISerializedOutputItem {
-	readonly mime: string;
-	readonly data: number[];
-}
-
-interface ISerializedCellOutput {
-	outputs: ISerializedOutputItem[];
-	metadata?: Record<string, any>;
-	outputId: string;
-}
-
-export interface ISerializedCell {
-	source: string;
-	language: string;
-	mime: string | undefined;
-	cellKind: CellKind;
-	outputs: ISerializedCellOutput[];
-	metadata?: NotebookCellMetadata;
-	internalMetadata?: NotebookCellInternalMetadata;
-	collapseState?: NotebookCellCollapseState;
-}
-
-function serializeCell(cell: NotebookCellTextModel): ISerializedCell {
-	return {
-		cellKind: cell.cellKind,
-		language: cell.language,
-		metadata: cell.metadata,
-		mime: cell.mime,
-		outputs: cell.outputs.map(output => serializeCellOutput(output)),
-		source: cell.getValue()
-	};
-}
-
-function deserializeCell(cell: ISerializedCell): ICellDto2 {
-	return {
-		cellKind: cell.cellKind,
-		source: cell.source,
-		language: cell.language,
-		metadata: cell.metadata,
-		mime: cell.mime,
-		outputs: cell.outputs.map((output) => deserializeCellOutput(output))
-	};
-}
-
-function serializeCellOutput(output: IOutputDto): ISerializedCellOutput {
-	return {
-		outputId: output.outputId,
-		outputs: output.outputs.map(ot => ({
-			mime: ot.mime,
-			data: ot.data.buffer ? Array.from(ot.data.buffer) : []
-		})),
-		metadata: output.metadata
-	};
-}
-
-function deserializeCellOutput(output: ISerializedCellOutput): IOutputDto {
-	return {
-		outputId: output.outputId,
-		outputs: output.outputs.map(ot => ({
-			mime: ot.mime,
-			data: VSBuffer.fromByteArray(ot.data)
-		})),
-		metadata: output.metadata
-	};
-}
