@@ -27,9 +27,9 @@ import { ServicesAccessor } from 'vs/platform/instantiation/common/instantiation
 import { RedoCommand, UndoCommand } from 'vs/editor/browser/editorExtensions';
 import { IWebview } from 'vs/workbench/contrib/webview/browser/webview';
 import { Categories } from 'vs/platform/action/common/actionCommonCategories';
-import { IOutputService } from 'vs/workbench/services/output/common/output';
-import { rendererLogId } from 'vs/workbench/common/logConstants';
 import { ILogService } from 'vs/platform/log/common/log';
+import { ICommandService } from 'vs/platform/commands/common/commands';
+import { showWindowLogActionId } from 'vs/workbench/services/log/common/logConstants';
 
 let _logging: boolean = false;
 function toggleLogging() {
@@ -558,8 +558,8 @@ registerAction2(class extends Action2 {
 	run(accessor: ServicesAccessor): void {
 		toggleLogging();
 		if (_logging) {
-			const outputService = accessor.get(IOutputService);
-			outputService.showChannel(rendererLogId);
+			const commandService = accessor.get(ICommandService);
+			commandService.executeCommand(showWindowLogActionId);
 		}
 	}
 });
