@@ -9,7 +9,7 @@ import { Disposable, MutableDisposable } from 'vs/base/common/lifecycle';
 import * as platform from 'vs/base/common/platform';
 import { expandCellRangesWithHiddenCells, ICellViewModel, INotebookEditorDelegate } from 'vs/workbench/contrib/notebook/browser/notebookBrowser';
 import { CellViewModelStateChangeEvent } from 'vs/workbench/contrib/notebook/browser/notebookViewEvents';
-import { CellPart } from 'vs/workbench/contrib/notebook/browser/view/cellPart';
+import { CellContentPart } from 'vs/workbench/contrib/notebook/browser/view/cellPart';
 import { BaseCellRenderTemplate, INotebookCellList } from 'vs/workbench/contrib/notebook/browser/view/notebookRenderingCommon';
 import { cloneNotebookCellTextModel } from 'vs/workbench/contrib/notebook/common/model/notebookCellTextModel';
 import { CellEditType, ICellMoveEdit, SelectionStateType } from 'vs/workbench/contrib/notebook/common/notebookCommon';
@@ -30,7 +30,7 @@ interface CellDragEvent {
 	dragPosRatio: number;
 }
 
-export class CellDragAndDropPart extends CellPart {
+export class CellDragAndDropPart extends CellContentPart {
 	constructor(
 		private readonly container: HTMLElement
 	) {
@@ -140,7 +140,7 @@ export class CellDragAndDropController extends Disposable {
 			return undefined;
 		}
 
-		const cellTop = this.list.getAbsoluteTopOfElement(draggedOverCell);
+		const cellTop = this.list.getCellViewScrollTop(draggedOverCell);
 		const cellHeight = this.list.elementHeight(draggedOverCell);
 
 		const dragPosInElement = dragOffset - cellTop;
@@ -228,7 +228,7 @@ export class CellDragAndDropController extends Disposable {
 	}
 
 	private _dropImpl(draggedCell: ICellViewModel, dropDirection: 'above' | 'below', ctx: { ctrlKey: boolean; altKey: boolean }, draggedOverCell: ICellViewModel) {
-		const cellTop = this.list.getAbsoluteTopOfElement(draggedOverCell);
+		const cellTop = this.list.getCellViewScrollTop(draggedOverCell);
 		const cellHeight = this.list.elementHeight(draggedOverCell);
 		const insertionIndicatorAbsolutePos = dropDirection === 'above' ? cellTop : cellTop + cellHeight;
 		const { bottomToolbarGap } = this.notebookEditor.notebookOptions.computeBottomToolbarDimensions(this.notebookEditor.textModel?.viewType);
@@ -358,7 +358,7 @@ export class CellDragAndDropController extends Disposable {
 
 		const target = this.list.elementAt(dragOffsetY);
 		if (target && target !== cell) {
-			const cellTop = this.list.getAbsoluteTopOfElement(target);
+			const cellTop = this.list.getCellViewScrollTop(target);
 			const cellHeight = this.list.elementHeight(target);
 
 			const dropDirection = this.getExplicitDragDropDirection(dragOffsetY, cellTop, cellHeight);
@@ -400,7 +400,7 @@ export class CellDragAndDropController extends Disposable {
 			return;
 		}
 
-		const cellTop = this.list.getAbsoluteTopOfElement(target);
+		const cellTop = this.list.getCellViewScrollTop(target);
 		const cellHeight = this.list.elementHeight(target);
 		const dropDirection = this.getExplicitDragDropDirection(ctx.dragOffsetY, cellTop, cellHeight);
 		this._dropImpl(cell, dropDirection, ctx, target);
