@@ -7,8 +7,8 @@ import * as DOM from 'vs/base/browser/dom';
 import { DisposableStore, dispose, IDisposable } from 'vs/base/common/lifecycle';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { ICellViewModel, INotebookEditorDelegate, KERNEL_EXTENSIONS } from 'vs/workbench/contrib/notebook/browser/notebookBrowser';
-import { NOTEBOOK_CELL_TOOLBAR_LOCATION, NOTEBOOK_HAS_OUTPUTS, NOTEBOOK_HAS_RUNNING_CELL, NOTEBOOK_INTERRUPTIBLE_KERNEL, NOTEBOOK_KERNEL, NOTEBOOK_KERNEL_COUNT, NOTEBOOK_KERNEL_SELECTED, NOTEBOOK_KERNEL_SOURCE_COUNT, NOTEBOOK_LAST_CELL_FAILED, NOTEBOOK_MISSING_KERNEL_EXTENSION, NOTEBOOK_USE_CONSOLIDATED_OUTPUT_BUTTON, NOTEBOOK_VIEW_TYPE } from 'vs/workbench/contrib/notebook/common/notebookContextKeys';
-import { INotebookExecutionStateService, INotebookFailStateChangedEvent } from 'vs/workbench/contrib/notebook/common/notebookExecutionStateService';
+import { NOTEBOOK_CELL_TOOLBAR_LOCATION, NOTEBOOK_HAS_OUTPUTS, NOTEBOOK_HAS_RUNNING_CELL, NOTEBOOK_HAS_SOMETHING_RUNNING, NOTEBOOK_INTERRUPTIBLE_KERNEL, NOTEBOOK_KERNEL, NOTEBOOK_KERNEL_COUNT, NOTEBOOK_KERNEL_SELECTED, NOTEBOOK_KERNEL_SOURCE_COUNT, NOTEBOOK_LAST_CELL_FAILED, NOTEBOOK_MISSING_KERNEL_EXTENSION, NOTEBOOK_USE_CONSOLIDATED_OUTPUT_BUTTON, NOTEBOOK_VIEW_TYPE } from 'vs/workbench/contrib/notebook/common/notebookContextKeys';
+import { ICellExecutionStateChangedEvent, IExecutionStateChangedEvent, INotebookExecutionStateService, INotebookFailStateChangedEvent, NotebookExecutionType } from 'vs/workbench/contrib/notebook/common/notebookExecutionStateService';
 import { INotebookKernelService } from 'vs/workbench/contrib/notebook/common/notebookKernelService';
 import { IExtensionService } from 'vs/workbench/services/extensions/common/extensions';
 
@@ -20,6 +20,7 @@ export class NotebookEditorContextKeys {
 	private readonly _notebookKernelSelected: IContextKey<boolean>;
 	private readonly _interruptibleKernel: IContextKey<boolean>;
 	private readonly _someCellRunning: IContextKey<boolean>;
+	private readonly _kernelRunning: IContextKey<boolean>;
 	private readonly _hasOutputs: IContextKey<boolean>;
 	private readonly _useConsolidatedOutputButton: IContextKey<boolean>;
 	private readonly _viewType!: IContextKey<string>;
@@ -30,6 +31,7 @@ export class NotebookEditorContextKeys {
 	private readonly _disposables = new DisposableStore();
 	private readonly _viewModelDisposables = new DisposableStore();
 	private readonly _cellOutputsListeners: IDisposable[] = [];
+	private readonly _selectedKernelDisposables = new DisposableStore();
 
 	constructor(
 		private readonly _editor: INotebookEditorDelegate,
@@ -43,6 +45,7 @@ export class NotebookEditorContextKeys {
 		this._notebookKernelSelected = NOTEBOOK_KERNEL_SELECTED.bindTo(contextKeyService);
 		this._interruptibleKernel = NOTEBOOK_INTERRUPTIBLE_KERNEL.bindTo(contextKeyService);
 		this._someCellRunning = NOTEBOOK_HAS_RUNNING_CELL.bindTo(contextKeyService);
+		this._kernelRunning = NOTEBOOK_HAS_SOMETHING_RUNNING.bindTo(contextKeyService);
 		this._useConsolidatedOutputButton = NOTEBOOK_USE_CONSOLIDATED_OUTPUT_BUTTON.bindTo(contextKeyService);
 		this._hasOutputs = NOTEBOOK_HAS_OUTPUTS.bindTo(contextKeyService);
 		this._viewType = NOTEBOOK_VIEW_TYPE.bindTo(contextKeyService);
@@ -60,7 +63,7 @@ export class NotebookEditorContextKeys {
 		this._disposables.add(_notebookKernelService.onDidChangeSourceActions(this._updateKernelContext, this));
 		this._disposables.add(_editor.notebookOptions.onDidChangeOptions(this._updateForNotebookOptions, this));
 		this._disposables.add(_extensionService.onDidChangeExtensions(this._updateForInstalledExtension, this));
-		this._disposables.add(_notebookExecutionStateService.onDidChangeCellExecution(this._updateForCellExecution, this));
+		this._disposables.add(_notebookExecutionStateService.onDidChangeExecution(this._updateForExecution, this));
 		this._disposables.add(_notebookExecutionStateService.onDidChangeLastRunFailState(this._updateForLastRunFailState, this));
 	}
 
@@ -71,6 +74,7 @@ export class NotebookEditorContextKeys {
 		this._notebookKernelSourceCount.reset();
 		this._interruptibleKernel.reset();
 		this._someCellRunning.reset();
+		this._kernelRunning.reset();
 		this._viewType.reset();
 		dispose(this._cellOutputsListeners);
 		this._cellOutputsListeners.length = 0;
@@ -124,7 +128,7 @@ export class NotebookEditorContextKeys {
 		this._updateForInstalledExtension();
 
 		this._viewModelDisposables.add(this._editor.onDidChangeViewCells(e => {
-			e.splices.reverse().forEach(splice => {
+			[...e.splices].reverse().forEach(splice => {
 				const [start, deleted, newCells] = splice;
 				const deletedCellOutputStates = this._cellOutputsListeners.splice(start, deleted, ...newCells.map(addCellOutputsListener));
 				dispose(deletedCellOutputStates);
@@ -132,13 +136,19 @@ export class NotebookEditorContextKeys {
 		}));
 		this._viewType.set(this._editor.textModel.viewType);
 	}
-
-	private _updateForCellExecution(): void {
+	private _updateForExecution(e: ICellExecutionStateChangedEvent | IExecutionStateChangedEvent): void {
 		if (this._editor.textModel) {
-			const notebookExe = this._notebookExecutionStateService.getCellExecutionStatesForNotebook(this._editor.textModel.uri);
-			this._someCellRunning.set(notebookExe.length > 0);
+			const notebookExe = this._notebookExecutionStateService.getExecution(this._editor.textModel.uri);
+			const notebookCellExe = this._notebookExecutionStateService.getCellExecutionsForNotebook(this._editor.textModel.uri);
+			this._kernelRunning.set(notebookCellExe.length > 0 || !!notebookExe);
+			if (e.type === NotebookExecutionType.cell) {
+				this._someCellRunning.set(notebookCellExe.length > 0);
+			}
 		} else {
-			this._someCellRunning.set(false);
+			this._kernelRunning.set(false);
+			if (e.type === NotebookExecutionType.cell) {
+				this._someCellRunning.set(false);
+			}
 		}
 	}
 
@@ -168,12 +178,19 @@ export class NotebookEditorContextKeys {
 		}
 
 		const { selected, all } = this._notebookKernelService.getMatchingKernel(this._editor.textModel);
-		const sourceActions = this._notebookKernelService.getSourceActions();
+		const sourceActions = this._notebookKernelService.getSourceActions(this._editor.textModel, this._editor.scopedContextKeyService);
 		this._notebookKernelCount.set(all.length);
 		this._notebookKernelSourceCount.set(sourceActions.length);
 		this._interruptibleKernel.set(selected?.implementsInterrupt ?? false);
 		this._notebookKernelSelected.set(Boolean(selected));
 		this._notebookKernel.set(selected?.id ?? '');
+
+		this._selectedKernelDisposables.clear();
+		if (selected) {
+			this._selectedKernelDisposables.add(selected.onDidChange(() => {
+				this._interruptibleKernel.set(selected?.implementsInterrupt ?? false);
+			}));
+		}
 	}
 
 	private _updateForNotebookOptions(): void {
