@@ -10,6 +10,7 @@ import { DisposableStore } from 'vs/base/common/lifecycle';
 import { Mimes } from 'vs/base/common/mime';
 import { URI } from 'vs/base/common/uri';
 import { mock } from 'vs/base/test/common/mock';
+import { TestConfigurationService } from 'vs/platform/configuration/test/common/testConfigurationService';
 import { ExtensionIdentifier } from 'vs/platform/extensions/common/extensions';
 import { TestInstantiationService } from 'vs/platform/instantiation/test/common/instantiationServiceMock';
 import { NotebookTextModel } from 'vs/workbench/contrib/notebook/common/model/notebookTextModel';
@@ -22,6 +23,7 @@ suite('NotebookFileWorkingCopyModel', function () {
 
 	let disposables: DisposableStore;
 	let instantiationService: TestInstantiationService;
+	const configurationService = new TestConfigurationService();
 
 	suiteSetup(() => {
 		disposables = new DisposableStore();
@@ -54,7 +56,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 
 			await model.snapshot(CancellationToken.None);
@@ -75,7 +78,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 			await model.snapshot(CancellationToken.None);
 			assert.strictEqual(callCount, 1);
@@ -106,7 +110,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 
 			await model.snapshot(CancellationToken.None);
@@ -127,7 +132,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 			await model.snapshot(CancellationToken.None);
 			assert.strictEqual(callCount, 1);
@@ -158,7 +164,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 
 			await model.snapshot(CancellationToken.None);
@@ -179,7 +186,8 @@ suite('NotebookFileWorkingCopyModel', function () {
 							return VSBuffer.fromString('');
 						}
 					}
-				)
+				),
+				configurationService
 			);
 			await model.snapshot(CancellationToken.None);
 			assert.strictEqual(callCount, 1);
