@@ -31,7 +31,7 @@ import { NotebookEditorWidgetService } from 'vs/workbench/contrib/notebook/brows
 import { ICellMatch, IFileMatchWithCells } from 'vs/workbench/contrib/search/browser/searchNotebookHelpers';
 import { ICellViewModel } from 'vs/workbench/contrib/notebook/browser/notebookBrowser';
 import { CellKind } from 'vs/workbench/contrib/notebook/common/notebookCommon';
-import { createFileUriFromPathFromRoot, getRootName } from 'vs/workbench/contrib/search/test/browser/searchTestCommon';
+import { addToSearchResult, createFileUriFromPathFromRoot, getRootName } from 'vs/workbench/contrib/search/test/browser/searchTestCommon';
 
 const lineOneRange = new OneLineRange(1, 0, 1);
 
@@ -51,6 +51,10 @@ suite('SearchResult', () => {
 		instantiationService.stub(ILogService, new NullLogService());
 	});
 
+	teardown(() => {
+		instantiationService.dispose();
+	});
+
 	test('Line Match', function () {
 		const fileMatch = aFileMatch('folder/file.txt', null!);
 		const lineMatch = new Match(fileMatch, ['0 foo bar'], new OneLineRange(0, 2, 5), new OneLineRange(1, 0, 5));
@@ -172,7 +176,7 @@ suite('SearchResult', () => {
 			new TextSearchMatch('preview 1', new OneLineRange(1, 4, 11)),
 			new TextSearchMatch('preview 2', lineOneRange))];
 
-		testObject.add(target);
+		addToSearchResult(testObject, target);
 
 		assert.strictEqual(3, testObject.count());
 
@@ -202,7 +206,7 @@ suite('SearchResult', () => {
 			aRawMatch('/2',
 				new TextSearchMatch('preview 2', lineOneRange))];
 
-		testObject.add(target);
+		addToSearchResult(testObject, target);
 
 		assert.strictEqual(3, testObject.count());
 
@@ -228,7 +232,7 @@ suite('SearchResult', () => {
 		const cell1 = { cellKind: CellKind.Code } as ICellViewModel;
 		const cell2 = { cellKind: CellKind.Code } as ICellViewModel;
 
-		const addContext = sinon.stub(CellMatch.prototype, 'addContext');
+		sinon.stub(CellMatch.prototype, 'addContext');
 
 		const addFileMatch = sinon.spy(FolderMatch.prototype, "addFileMatch");
 		const fileMatch1 = aRawFileMatchWithCells('/1',
@@ -257,13 +261,12 @@ suite('SearchResult', () => {
 			});
 		const target = [fileMatch1, fileMatch2];
 
-		testObject.add(target);
+		addToSearchResult(testObject, target);
 		assert.strictEqual(6, testObject.count());
 		assert.deepStrictEqual(fileMatch1.cellResults[0].contentResults, (addFileMatch.getCall(0).args[0][0] as IFileMatchWithCells).cellResults[0].contentResults);
 		assert.deepStrictEqual(fileMatch1.cellResults[0].webviewResults, (addFileMatch.getCall(0).args[0][0] as IFileMatchWithCells).cellResults[0].webviewResults);
 		assert.deepStrictEqual(fileMatch2.cellResults[0].contentResults, (addFileMatch.getCall(0).args[0][1] as IFileMatchWithCells).cellResults[0].contentResults);
 		assert.deepStrictEqual(fileMatch2.cellResults[0].webviewResults, (addFileMatch.getCall(0).args[0][1] as IFileMatchWithCells).cellResults[0].webviewResults);
-		addContext.restore();
 	});
 
 	test('Dispose disposes matches', function () {
@@ -271,7 +274,7 @@ suite('SearchResult', () => {
 		const target2 = sinon.spy();
 
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange)),
 			aRawMatch('/2',
@@ -290,7 +293,7 @@ suite('SearchResult', () => {
 	test('remove triggers change event', function () {
 		const target = sinon.spy();
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange))]);
 		const objectToRemove = testObject.matches()[0];
@@ -305,7 +308,7 @@ suite('SearchResult', () => {
 	test('remove array triggers change event', function () {
 		const target = sinon.spy();
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange)),
 			aRawMatch('/2',
@@ -321,7 +324,7 @@ suite('SearchResult', () => {
 
 	test('Removing all line matches and adding back will add file back to result', function () {
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange))]);
 		const target = testObject.matches()[0];
@@ -339,7 +342,7 @@ suite('SearchResult', () => {
 		const voidPromise = Promise.resolve(null);
 		instantiationService.stub(IReplaceService, 'replace', voidPromise);
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange))]);
 
@@ -353,7 +356,7 @@ suite('SearchResult', () => {
 		const voidPromise = Promise.resolve(null);
 		instantiationService.stub(IReplaceService, 'replace', voidPromise);
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange))]);
 		testObject.onChange(target);
@@ -371,7 +374,7 @@ suite('SearchResult', () => {
 		const voidPromise = Promise.resolve(null);
 		instantiationService.stubPromise(IReplaceService, 'replace', voidPromise);
 		const testObject = aSearchResult();
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/1',
 				new TextSearchMatch('preview 1', lineOneRange)),
 			aRawMatch('/2',
@@ -516,7 +519,7 @@ suite('SearchResult', () => {
 		const root = searchResult?.folderMatches()[0];
 		return instantiationService.createInstance(FileMatch, {
 			pattern: ''
-		}, undefined, undefined, root, rawMatch, null);
+		}, undefined, undefined, root, rawMatch, null, '');
 	}
 
 	function aSearchResult(): SearchResult {
@@ -566,7 +569,7 @@ suite('SearchResult', () => {
 			]
 		};
 
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/voo/foo.a',
 				new TextSearchMatch('preview 1', lineOneRange), new TextSearchMatch('preview 2', lineOneRange)),
 			aRawMatch('/with/path/bar.b',
@@ -620,7 +623,7 @@ suite('SearchResult', () => {
 		 *    |- eyy.y
 		 */
 
-		testObject.add([
+		addToSearchResult(testObject, [
 			aRawMatch('/voo/foo.a',
 				new TextSearchMatch('preview 1', lineOneRange), new TextSearchMatch('preview 2', lineOneRange)),
 			aRawMatch('/voo/beep/foo.c',
