@@ -4,11 +4,10 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { onDidChangeFullscreen, isFullscreen } from 'vs/base/browser/browser';
-import { getTotalHeight, getTotalWidth } from 'vs/base/browser/dom';
+import * as dom from 'vs/base/browser/dom';
 import { Color } from 'vs/base/common/color';
 import { Event } from 'vs/base/common/event';
-import { DisposableStore } from 'vs/base/common/lifecycle';
-import { ILifecycleService, LifecyclePhase } from 'vs/workbench/services/lifecycle/common/lifecycle';
+import { DisposableStore, IDisposable } from 'vs/base/common/lifecycle';
 import { editorBackground, foreground } from 'vs/platform/theme/common/colorRegistry';
 import { getThemeTypeSelector, IThemeService } from 'vs/platform/theme/common/themeService';
 import { DEFAULT_EDITOR_MIN_DIMENSIONS } from 'vs/workbench/browser/parts/editor/editor';
@@ -19,7 +18,7 @@ import { IEditorGroupsService } from 'vs/workbench/services/editor/common/editor
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import * as perf from 'vs/base/common/performance';
 import { assertIsDefined } from 'vs/base/common/types';
-import { RunOnceScheduler } from 'vs/base/common/async';
+import { runWhenIdle } from 'vs/base/common/async';
 import { ISplashStorageService } from 'vs/workbench/contrib/splash/browser/splash';
 
 export class PartsSplash {
@@ -34,19 +33,19 @@ export class PartsSplash {
 		@IThemeService private readonly _themeService: IThemeService,
 		@IWorkbenchLayoutService private readonly _layoutService: IWorkbenchLayoutService,
 		@IWorkbenchEnvironmentService private readonly _environmentService: IWorkbenchEnvironmentService,
-		@ILifecycleService lifecycleService: ILifecycleService,
 		@IEditorGroupsService editorGroupsService: IEditorGroupsService,
 		@IConfigurationService private readonly _configService: IConfigurationService,
 		@ISplashStorageService private readonly _partSplashService: ISplashStorageService
 	) {
-		lifecycleService.when(LifecyclePhase.Restored).then(_ => {
+		Event.once(_layoutService.onDidLayout)(() => {
 			this._removePartsSplash();
 			perf.mark('code/didRemovePartsSplash');
-		});
+		}, undefined, this._disposables);
 
-		const savePartsSplashSoon = new RunOnceScheduler(() => this._savePartsSplash(), 800);
-		Event.any(onDidChangeFullscreen, editorGroupsService.onDidLayout)(() => {
-			savePartsSplashSoon.schedule();
+		let lastIdleSchedule: IDisposable | undefined;
+		Event.any(onDidChangeFullscreen, editorGroupsService.onDidLayout, _themeService.onDidColorThemeChange)(() => {
+			lastIdleSchedule?.dispose();
+			lastIdleSchedule = runWhenIdle(() => this._savePartsSplash(), 800);
 		}, undefined, this._disposables);
 
 		_configService.onDidChangeConfiguration(e => {
@@ -55,10 +54,6 @@ export class PartsSplash {
 				this._savePartsSplash();
 			}
 		}, this, this._disposables);
-
-		_themeService.onDidColorThemeChange(_ => {
-			this._savePartsSplash();
-		}, this, this._disposables);
 	}
 
 	dispose(): void {
@@ -85,10 +80,10 @@ export class PartsSplash {
 			layoutInfo: !this._shouldSaveLayoutInfo() ? undefined : {
 				sideBarSide: this._layoutService.getSideBarPosition() === Position.RIGHT ? 'right' : 'left',
 				editorPartMinWidth: DEFAULT_EDITOR_MIN_DIMENSIONS.width,
-				titleBarHeight: this._layoutService.isVisible(Parts.TITLEBAR_PART) ? getTotalHeight(assertIsDefined(this._layoutService.getContainer(Parts.TITLEBAR_PART))) : 0,
-				activityBarWidth: this._layoutService.isVisible(Parts.ACTIVITYBAR_PART) ? getTotalWidth(assertIsDefined(this._layoutService.getContainer(Parts.ACTIVITYBAR_PART))) : 0,
-				sideBarWidth: this._layoutService.isVisible(Parts.SIDEBAR_PART) ? getTotalWidth(assertIsDefined(this._layoutService.getContainer(Parts.SIDEBAR_PART))) : 0,
-				statusBarHeight: this._layoutService.isVisible(Parts.STATUSBAR_PART) ? getTotalHeight(assertIsDefined(this._layoutService.getContainer(Parts.STATUSBAR_PART))) : 0,
+				titleBarHeight: this._layoutService.isVisible(Parts.TITLEBAR_PART) ? dom.getTotalHeight(assertIsDefined(this._layoutService.getContainer(Parts.TITLEBAR_PART))) : 0,
+				activityBarWidth: this._layoutService.isVisible(Parts.ACTIVITYBAR_PART) ? dom.getTotalWidth(assertIsDefined(this._layoutService.getContainer(Parts.ACTIVITYBAR_PART))) : 0,
+				sideBarWidth: this._layoutService.isVisible(Parts.SIDEBAR_PART) ? dom.getTotalWidth(assertIsDefined(this._layoutService.getContainer(Parts.SIDEBAR_PART))) : 0,
+				statusBarHeight: this._layoutService.isVisible(Parts.STATUSBAR_PART) ? dom.getTotalHeight(assertIsDefined(this._layoutService.getContainer(Parts.STATUSBAR_PART))) : 0,
 				windowBorder: this._layoutService.hasWindowBorder(),
 				windowBorderRadius: this._layoutService.getWindowBorderRadius()
 			}
