@@ -140,6 +140,8 @@ class RemoteTerminalBackend extends BaseTerminalBackend implements ITerminalBack
 				}
 			}
 		}));
+
+		this._onPtyHostConnected.fire();
 	}
 
 	async requestDetachInstance(workspaceId: string, instanceId: number): Promise<IProcessDetails | undefined> {
@@ -335,6 +337,8 @@ class RemoteTerminalBackend extends BaseTerminalBackend implements ITerminalBack
 			throw new Error(`Cannot call getActiveInstanceId when there is no remote`);
 		}
 
+		const workspaceId = this._getWorkspaceId();
+
 		// Revive processes if needed
 		const serializedState = this._storageService.get(TerminalStorageKeys.TerminalBufferState, StorageScope.WORKSPACE);
 		const reviveBufferState = this._deserializeTerminalState(serializedState);
@@ -343,7 +347,7 @@ class RemoteTerminalBackend extends BaseTerminalBackend implements ITerminalBack
 				// Note that remote terminals do not get their environment re-resolved unlike in local terminals
 
 				mark('code/terminal/willReviveTerminalProcessesRemote');
-				await this._remoteTerminalChannel.reviveTerminalProcesses(reviveBufferState, Intl.DateTimeFormat().resolvedOptions().locale);
+				await this._remoteTerminalChannel.reviveTerminalProcesses(workspaceId, reviveBufferState, Intl.DateTimeFormat().resolvedOptions().locale);
 				mark('code/terminal/didReviveTerminalProcessesRemote');
 				this._storageService.remove(TerminalStorageKeys.TerminalBufferState, StorageScope.WORKSPACE);
 				// If reviving processes, send the terminal layout info back to the pty host as it
