@@ -8,7 +8,8 @@ export const enum TerminalStorageKeys {
 	SuggestedRendererType = 'terminal.integrated.suggestedRendererType',
 	TabsListWidthHorizontal = 'tabs-list-width-horizontal',
 	TabsListWidthVertical = 'tabs-list-width-vertical',
-	EnvironmentVariableCollections = 'terminal.integrated.environmentVariableCollections',
+	DeprecatedEnvironmentVariableCollections = 'terminal.integrated.environmentVariableCollections',
+	EnvironmentVariableCollections = 'terminal.integrated.environmentVariableCollectionsV2',
 	TerminalBufferState = 'terminal.integrated.bufferState',
 	TerminalLayoutInfo = 'terminal.integrated.layoutInfo',
 	PinnedRecentCommandsPrefix = 'terminal.pinnedRecentCommands',
