@@ -5,30 +5,21 @@
 
 import { Schemas } from 'vs/base/common/network';
 import { URI } from 'vs/base/common/uri';
-import { ServicesAccessor } from 'vs/editor/browser/editorExtensions';
 import { localize } from 'vs/nls';
-import { Action2, registerAction2 } from 'vs/platform/actions/common/actions';
 import { INativeEnvironmentService } from 'vs/platform/environment/common/environment';
 import { IRemoteAuthorityResolverService } from 'vs/platform/remote/common/remoteAuthorityResolver';
-import { ITerminalGroupService, ITerminalService } from 'vs/workbench/contrib/terminal/browser/terminal';
+import { registerTerminalAction } from 'vs/workbench/contrib/terminal/browser/terminalActions';
 import { TerminalCommandId } from 'vs/workbench/contrib/terminal/common/terminal';
 import { IHistoryService } from 'vs/workbench/services/history/common/history';
 
 export function registerRemoteContributions() {
-	registerAction2(class extends Action2 {
-		constructor() {
-			super({
-				id: TerminalCommandId.NewLocal,
-				title: { value: localize('workbench.action.terminal.newLocal', "Create New Integrated Terminal (Local)"), original: 'Create New Integrated Terminal (Local)' },
-				f1: true
-			});
-		}
-		async run(accessor: ServicesAccessor) {
+	registerTerminalAction({
+		id: TerminalCommandId.NewLocal,
+		title: { value: localize('workbench.action.terminal.newLocal', "Create New Integrated Terminal (Local)"), original: 'Create New Integrated Terminal (Local)' },
+		run: async (c, accessor) => {
 			const historyService = accessor.get(IHistoryService);
 			const remoteAuthorityResolverService = accessor.get(IRemoteAuthorityResolverService);
 			const nativeEnvironmentService = accessor.get(INativeEnvironmentService);
-			const terminalService = accessor.get(ITerminalService);
-			const terminalGroupService = accessor.get(ITerminalGroupService);
 			let cwd: URI | undefined;
 			try {
 				const activeWorkspaceRootUri = historyService.getLastActiveWorkspaceRoot(Schemas.vscodeRemote);
@@ -42,13 +33,13 @@ export function registerRemoteContributions() {
 			if (!cwd) {
 				cwd = nativeEnvironmentService.userHome;
 			}
-			const instance = await terminalService.createTerminal({ cwd });
+			const instance = await c.service.createTerminal({ cwd });
 			if (!instance) {
 				return Promise.resolve(undefined);
 			}
 
-			terminalService.setActiveInstance(instance);
-			return terminalGroupService.showPanel(true);
+			c.service.setActiveInstance(instance);
+			return c.groupService.showPanel(true);
 		}
 	});
 }
