@@ -71,7 +71,7 @@ suite('DecorationAddon', () => {
 		instantiationService.dispose();
 	});
 
-	suite('registerDecoration', async () => {
+	suite('registerDecoration', () => {
 		test('should throw when command has no marker', async () => {
 			throws(() => decorationAddon.registerCommandDecoration({ command: 'cd src', timestamp: Date.now(), hasOutput: () => false } as ITerminalCommand));
 		});
