@@ -48,18 +48,22 @@ registerActiveInstanceAction({
 
 function describeEnvironmentChanges(collection: IMergedEnvironmentVariableCollection, scope: EnvironmentVariableScope | undefined): string {
 	let content = `# ${localize('envChanges', 'Terminal Environment Changes')}`;
+	const globalDescriptions = collection.getDescriptionMap(undefined);
+	const workspaceDescriptions = collection.getDescriptionMap(scope);
 	for (const [ext, coll] of collection.collections) {
 		content += `\n\n## ${localize('extension', 'Extension: {0}', ext)}`;
 		content += '\n';
-		if (coll.descriptionMap && coll.descriptionMap.size > 0) {
-			for (const desc of coll.descriptionMap.values()) {
-				content += `\n${desc.description}`;
-				if (desc.scope?.workspaceFolder) {
-					content += ` (${localize('ScopedEnvironmentContributionInfo', 'workspace')})`;
-				}
-			}
-			content += '\n';
+		const globalDescription = globalDescriptions.get(ext);
+		if (globalDescription) {
+			content += `\n${globalDescription}\n`;
 		}
+		const workspaceDescription = workspaceDescriptions.get(ext);
+		if (workspaceDescription) {
+			// Only show '(workspace)' suffix if there is already a description for the extension.
+			const workspaceSuffix = globalDescription ? ` (${localize('ScopedEnvironmentContributionInfo', 'workspace')})` : '';
+			content += `\n${workspaceDescription}${workspaceSuffix}\n`;
+		}
+
 		for (const mutator of coll.map.values()) {
 			if (filterScope(mutator, scope) === false) {
 				continue;
