@@ -28,16 +28,16 @@ import { IAnchor } from 'vs/base/browser/ui/contextview/contextview';
 import { ILabelService } from 'vs/platform/label/common/label';
 import { Schemas } from 'vs/base/common/network';
 import { URI } from 'vs/base/common/uri';
-import { ITerminalQuickFixInternalOptions, ITerminalQuickFixResolvedExtensionOptions, ITerminalQuickFix, ITerminalQuickFixCommandAction, ITerminalQuickFixOpenerAction, ITerminalQuickFixOptions, ITerminalQuickFixProviderSelector, ITerminalQuickFixService, ITerminalQuickFixUnresolvedExtensionOptions, TerminalQuickFixType } from 'vs/workbench/contrib/terminalContrib/quickFix/browser/quickFix';
+import { ITerminalQuickFixInternalOptions, ITerminalQuickFixResolvedExtensionOptions, ITerminalQuickFix, ITerminalQuickFixExecuteTerminalCommandAction, ITerminalQuickFixOpenerAction, ITerminalQuickFixOptions, ITerminalQuickFixProviderSelector, ITerminalQuickFixService, ITerminalQuickFixUnresolvedExtensionOptions, TerminalQuickFixType, ITerminalQuickFixCommandAction } from 'vs/workbench/contrib/terminalContrib/quickFix/browser/quickFix';
 import { ITerminalCommandSelector } from 'vs/platform/terminal/common/terminal';
 import { ActionListItemKind, IActionListItem } from 'vs/platform/actionWidget/browser/actionList';
 import { CodeActionKind } from 'vs/editor/contrib/codeAction/common/types';
 import { Codicon } from 'vs/base/common/codicons';
 import { ThemeIcon } from 'vs/base/common/themables';
+import { ICommandService } from 'vs/platform/commands/common/commands';
 
-const quickFixSelectors = [
+const quickFixClasses = [
 	DecorationSelector.QuickFix,
-	DecorationSelector.LightBulb,
 	DecorationSelector.Codicon,
 	DecorationSelector.CommandDecoration,
 	DecorationSelector.XtermDecoration
@@ -75,6 +75,7 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 		private readonly _aliases: string[][] | undefined,
 		private readonly _capabilities: ITerminalCapabilityStore,
 		@ITerminalQuickFixService private readonly _quickFixService: ITerminalQuickFixService,
+		@ICommandService private readonly _commandService: ICommandService,
 		@IConfigurationService private readonly _configurationService: IConfigurationService,
 		@IAudioCueService private readonly _audioCueService: IAudioCueService,
 		@IOpenerService private readonly _openerService: IOpenerService,
@@ -88,7 +89,7 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 		if (commandDetectionCapability) {
 			this._registerCommandHandlers();
 		} else {
-			this._register(this._capabilities.onDidAddCapability(c => {
+			this._register(this._capabilities.onDidAddCapabilityType(c => {
 				if (c === TerminalCapability.CommandDetection) {
 					this._registerCommandHandlers();
 				}
@@ -114,7 +115,7 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 		}
 
 		// TODO: What's documentation do? Need a vscode command?
-		const actions = this._currentRenderContext.quickFixes.map(f => new TerminalQuickFixItem(f, f.type, f.source, f.label));
+		const actions = this._currentRenderContext.quickFixes.map(f => new TerminalQuickFixItem(f, f.type, f.source, f.label, f.kind));
 		const documentation = this._currentRenderContext.quickFixes.map(f => { return { id: f.source, title: f.label, tooltip: f.source }; });
 		const actionSet = {
 			// TODO: Documentation and actions are separate?
@@ -148,7 +149,8 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 			type: 'unresolved',
 			commandLineMatcher: selector.commandLineMatcher,
 			outputMatcher: selector.outputMatcher,
-			commandExitResult: selector.commandExitResult
+			commandExitResult: selector.commandExitResult,
+			kind: selector.kind
 		});
 		this._registeredSelectors.add(selector.id);
 		this._commandListeners.set(matcherKey, currentOptions);
@@ -190,9 +192,16 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 			}
 			const id = selector.id;
 			await this._extensionService.activateByEvent(`onTerminalQuickFixRequest:${id}`);
-			return this._quickFixService.providers.get(id)?.provideTerminalQuickFixes(command, lines, { type: 'resolved', commandLineMatcher: selector.commandLineMatcher, outputMatcher: selector.outputMatcher, commandExitResult: selector.commandExitResult, id: selector.id }, new CancellationTokenSource().token);
+			return this._quickFixService.providers.get(id)?.provideTerminalQuickFixes(command, lines, {
+				type: 'resolved',
+				commandLineMatcher: selector.commandLineMatcher,
+				outputMatcher: selector.outputMatcher,
+				commandExitResult: selector.commandExitResult,
+				kind: selector.kind,
+				id: selector.id
+			}, new CancellationTokenSource().token);
 		};
-		const result = await getQuickFixesForCommand(aliases, terminal, command, this._commandListeners, this._openerService, this._labelService, this._onDidRequestRerunCommand, resolver);
+		const result = await getQuickFixesForCommand(aliases, terminal, command, this._commandListeners, this._commandService, this._openerService, this._labelService, this._onDidRequestRerunCommand, resolver);
 		if (!result) {
 			return;
 		}
@@ -248,12 +257,6 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 			return;
 		}
 		decoration?.onRender((e: HTMLElement) => {
-			if (e.classList.contains(DecorationSelector.QuickFix)) {
-				return;
-			}
-			e.classList.add(...quickFixSelectors);
-			updateLayout(this._configurationService, e);
-			this._audioCueService.playAudioCue(AudioCue.terminalQuickFix);
 			const rect = e.getBoundingClientRect();
 			const anchor = {
 				x: rect.x,
@@ -262,6 +265,24 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 				height: rect.height
 			};
 
+			if (e.classList.contains(DecorationSelector.QuickFix)) {
+				if (this._currentRenderContext) {
+					this._currentRenderContext.anchor = anchor;
+				}
+
+				return;
+			}
+
+			e.classList.add(...quickFixClasses);
+			const isExplainOnly = fixes.every(e => e.kind === 'explain');
+			if (isExplainOnly) {
+				e.classList.add('explainOnly');
+			}
+			e.classList.add(...ThemeIcon.asClassNameArray(isExplainOnly ? Codicon.sparkle : Codicon.lightBulb));
+
+			updateLayout(this._configurationService, e);
+			this._audioCueService.playAudioCue(AudioCue.terminalQuickFix);
+
 			const parentElement = e.parentElement?.parentElement?.parentElement?.parentElement;
 			if (!parentElement) {
 				return;
@@ -277,6 +298,7 @@ export class TerminalQuickFixAddon extends Disposable implements ITerminalAddon,
 
 export interface ITerminalAction extends IAction {
 	type: TerminalQuickFixType;
+	kind?: 'fix' | 'explain';
 	source: string;
 	uri?: URI;
 	command?: string;
@@ -287,6 +309,7 @@ export async function getQuickFixesForCommand(
 	terminal: Terminal,
 	terminalCommand: ITerminalCommand,
 	quickFixOptions: Map<string, ITerminalQuickFixOptions[]>,
+	commandService: ICommandService,
 	openerService: IOpenerService,
 	labelService: ILabelService,
 	onDidRequestRerunCommand?: Emitter<{ command: string; addNewLine?: boolean }>,
@@ -333,15 +356,16 @@ export async function getQuickFixesForCommand(
 					let action: ITerminalAction | undefined;
 					if ('type' in quickFix) {
 						switch (quickFix.type) {
-							case TerminalQuickFixType.Command: {
-								const fix = quickFix as ITerminalQuickFixCommandAction;
+							case TerminalQuickFixType.TerminalCommand: {
+								const fix = quickFix as ITerminalQuickFixExecuteTerminalCommandAction;
 								if (commandQuickFixSet.has(fix.terminalCommand)) {
 									continue;
 								}
 								commandQuickFixSet.add(fix.terminalCommand);
 								const label = localize('quickFix.command', 'Run: {0}', fix.terminalCommand);
 								action = {
-									type: TerminalQuickFixType.Command,
+									type: TerminalQuickFixType.TerminalCommand,
+									kind: option.kind,
 									class: undefined,
 									source: quickFix.source,
 									id: quickFix.id,
@@ -375,6 +399,7 @@ export async function getQuickFixesForCommand(
 									id: quickFix.id,
 									label,
 									type: TerminalQuickFixType.Opener,
+									kind: option.kind,
 									class: undefined,
 									enabled: true,
 									run: () => openerService.open(fix.uri),
@@ -388,6 +413,7 @@ export async function getQuickFixesForCommand(
 								action = {
 									source: 'builtin',
 									type: fix.type,
+									kind: option.kind,
 									id: fix.id,
 									label: fix.label,
 									class: fix.class,
@@ -399,6 +425,21 @@ export async function getQuickFixesForCommand(
 								};
 								break;
 							}
+							case TerminalQuickFixType.VscodeCommand: {
+								const fix = quickFix as ITerminalQuickFixCommandAction;
+								action = {
+									source: quickFix.source,
+									type: fix.type,
+									kind: option.kind,
+									id: fix.id,
+									label: fix.title,
+									class: undefined,
+									enabled: true,
+									run: () => commandService.executeCommand(fix.id),
+									tooltip: fix.title
+								};
+								break;
+							}
 						}
 						if (action) {
 							fixes.push(action);
@@ -418,22 +459,20 @@ function convertToQuickFixOptions(selectorProvider: ITerminalQuickFixProviderSel
 		commandLineMatcher: selectorProvider.selector.commandLineMatcher,
 		outputMatcher: selectorProvider.selector.outputMatcher,
 		commandExitResult: selectorProvider.selector.commandExitResult,
+		kind: selectorProvider.selector.kind,
 		getQuickFixes: selectorProvider.provider.provideTerminalQuickFixes
 	};
 }
 
 class TerminalQuickFixItem {
-	action: ITerminalAction;
-	type: TerminalQuickFixType;
-	disabled?: boolean;
-	title?: string;
-	source: string;
-	constructor(action: ITerminalAction, type: TerminalQuickFixType, source: string, title?: string, disabled?: boolean) {
-		this.action = action;
-		this.disabled = disabled;
-		this.title = title;
-		this.source = source;
-		this.type = type;
+	readonly disabled = false;
+	constructor(
+		readonly action: ITerminalAction,
+		readonly type: TerminalQuickFixType,
+		readonly source: string,
+		readonly title: string | undefined,
+		readonly kind: 'fix' | 'explain' = 'fix'
+	) {
 	}
 }
 
@@ -465,15 +504,20 @@ function toActionWidgetItems(inputQuickFixes: readonly TerminalQuickFixItem[], s
 }
 
 function getQuickFixIcon(quickFix: TerminalQuickFixItem): ThemeIcon {
+	if (quickFix.kind === 'explain') {
+		return Codicon.sparkle;
+	}
 	switch (quickFix.type) {
 		case TerminalQuickFixType.Opener:
 			if ('uri' in quickFix.action && quickFix.action.uri) {
 				const isUrl = (quickFix.action.uri.scheme === Schemas.http || quickFix.action.uri.scheme === Schemas.https);
 				return isUrl ? Codicon.linkExternal : Codicon.goToFile;
 			}
-		case TerminalQuickFixType.Command:
+		case TerminalQuickFixType.TerminalCommand:
 			return Codicon.run;
 		case TerminalQuickFixType.Port:
 			return Codicon.debugDisconnect;
+		case TerminalQuickFixType.VscodeCommand:
+			return Codicon.lightbulb;
 	}
 }
