@@ -4,7 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { CancellationTokenSource } from 'vs/base/common/cancellation';
-import { Disposable } from 'vs/base/common/lifecycle';
+import { Disposable, toDisposable } from 'vs/base/common/lifecycle';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { createDecorator } from 'vs/platform/instantiation/common/instantiation';
 import { IStorageService, StorageScope, StorageTarget } from 'vs/platform/storage/common/storage';
@@ -15,6 +15,7 @@ import { TestService } from 'vs/workbench/contrib/testing/common/testServiceImpl
 import { ITestRunProfile } from 'vs/workbench/contrib/testing/common/testTypes';
 import { Emitter, Event } from 'vs/base/common/event';
 import { TestId } from 'vs/workbench/contrib/testing/common/testId';
+import { WellDefinedPrefixTree } from 'vs/base/common/prefixTree';
 
 export const ITestingContinuousRunService = createDecorator<ITestingContinuousRunService>('testingContinuousRunService');
 
@@ -43,6 +44,17 @@ export interface ITestingContinuousRunService {
 	 */
 	isEnabledForAParentOf(testId: string): boolean;
 
+	/**
+	 * Gets whether continous run is specifically enabled for
+	 * the given test ID, or any of its parents.
+	 */
+	isEnabledForAChildOf(testId: string): boolean;
+
+	/**
+	 * Gets whether it's enabled at all.
+	 */
+	isEnabled(): boolean;
+
 	/**
 	 * Starts a continuous auto run with a specific profile or set of profiles.
 	 * Globally if no test is given, for a specific test otherwise.
@@ -60,7 +72,8 @@ export class TestingContinuousRunService extends Disposable implements ITestingC
 	declare readonly _serviceBrand: undefined;
 
 	private readonly changeEmitter = new Emitter<string | undefined>();
-	private readonly running = new Map<string | undefined, CancellationTokenSource>();
+	private globallyRunning?: CancellationTokenSource;
+	private readonly running = new WellDefinedPrefixTree<CancellationTokenSource>();
 	private readonly lastRun: StoredValue<Set<number>>;
 	private readonly isGloballyOn: IContextKey<boolean>;
 
@@ -77,7 +90,7 @@ export class TestingContinuousRunService extends Disposable implements ITestingC
 	) {
 		super();
 		this.isGloballyOn = TestingContextKeys.isContinuousModeOn.bindTo(contextKeyService);
-		this.lastRun = new StoredValue<Set<number>>({
+		this.lastRun = this._register(new StoredValue<Set<number>>({
 			key: 'lastContinuousRunProfileIds',
 			scope: StorageScope.WORKSPACE,
 			target: StorageTarget.MACHINE,
@@ -85,31 +98,38 @@ export class TestingContinuousRunService extends Disposable implements ITestingC
 				deserialize: v => new Set(JSON.parse(v)),
 				serialize: v => JSON.stringify([...v])
 			},
-		}, storageService);
+		}, storageService));
+
+		this._register(toDisposable(() => {
+			this.globallyRunning?.dispose();
+			for (const cts of this.running.values()) {
+				cts.dispose();
+			}
+		}));
 	}
 
 	/** @inheritdoc */
 	public isSpecificallyEnabledFor(testId: string): boolean {
-		return this.running.has(testId);
+		return this.running.size > 0 && this.running.hasKey(TestId.fromString(testId).path);
 	}
 
 	/** @inheritdoc */
 	public isEnabledForAParentOf(testId: string): boolean {
-		if (!this.running.size) {
-			return false;
-		}
-
-		if (this.running.has(undefined)) {
+		if (this.globallyRunning) {
 			return true;
 		}
 
-		for (const part of TestId.fromString(testId).idsFromRoot()) {
-			if (this.running.has(part.toString())) {
-				return true;
-			}
-		}
+		return this.running.size > 0 && this.running.hasKeyOrParent(TestId.fromString(testId).path);
+	}
 
-		return false;
+	/** @inheritdoc */
+	public isEnabledForAChildOf(testId: string): boolean {
+		return this.running.size > 0 && this.running.hasKeyOrChildren(TestId.fromString(testId).path);
+	}
+
+	/** @inheritdoc */
+	public isEnabled(): boolean {
+		return !!this.globallyRunning || this.running.size > 0;
 	}
 
 	/** @inheritdoc */
@@ -120,8 +140,16 @@ export class TestingContinuousRunService extends Disposable implements ITestingC
 			this.isGloballyOn.set(true);
 		}
 
-		this.running.get(testId)?.dispose(true);
-		this.running.set(testId, cts);
+		if (!testId) {
+			this.globallyRunning?.dispose(true);
+			this.globallyRunning = cts;
+		} else {
+			this.running.mutate(TestId.fromString(testId).path, c => {
+				c?.dispose(true);
+				return cts;
+			});
+		}
+
 		this.lastRun.store(new Set(profile.map(p => p.profileId)));
 
 		this.testService.startContinuousRun({
@@ -139,8 +167,12 @@ export class TestingContinuousRunService extends Disposable implements ITestingC
 
 	/** @inheritdoc */
 	public stop(testId?: string): void {
-		this.running.get(testId)?.dispose(true);
-		this.running.delete(testId);
+		if (!testId) {
+			this.globallyRunning?.dispose(true);
+			this.globallyRunning = undefined;
+		} else {
+			this.running.delete(TestId.fromString(testId).path)?.dispose(true);
+		}
 
 		if (testId === undefined) {
 			this.isGloballyOn.set(false);
