@@ -6,16 +6,18 @@
 import * as assert from 'assert';
 import { timeout } from 'vs/base/common/async';
 import { VSBuffer } from 'vs/base/common/buffer';
+import { CancellationTokenSource } from 'vs/base/common/cancellation';
+import { ensureNoDisposablesAreLeakedInTestSuite } from 'vs/base/test/common/utils';
 import { MockContextKeyService } from 'vs/platform/keybinding/test/common/mockKeybindingService';
 import { NullLogService } from 'vs/platform/log/common/log';
 import { TestId } from 'vs/workbench/contrib/testing/common/testId';
 import { TestProfileService } from 'vs/workbench/contrib/testing/common/testProfileService';
-import { HydratedTestResult, LiveTestResult, resultItemParents, TaskRawOutput, TestResultItemChange, TestResultItemChangeReason } from 'vs/workbench/contrib/testing/common/testResult';
+import { HydratedTestResult, LiveTestResult, TaskRawOutput, TestResultItemChange, TestResultItemChangeReason, resultItemParents } from 'vs/workbench/contrib/testing/common/testResult';
 import { TestResultService } from 'vs/workbench/contrib/testing/common/testResultService';
-import { InMemoryResultStorage, ITestResultStorage } from 'vs/workbench/contrib/testing/common/testResultStorage';
+import { ITestResultStorage, InMemoryResultStorage } from 'vs/workbench/contrib/testing/common/testResultStorage';
 import { ITestTaskState, ResolvedTestRunRequest, TestResultItem, TestResultState, TestRunProfileBitset } from 'vs/workbench/contrib/testing/common/testTypes';
 import { makeEmptyCounts } from 'vs/workbench/contrib/testing/common/testingStates';
-import { getInitializedMainTestCollection, testStubs, TestTestCollection } from 'vs/workbench/contrib/testing/test/common/testStubs';
+import { TestTestCollection, getInitializedMainTestCollection, testStubs } from 'vs/workbench/contrib/testing/test/common/testStubs';
 import { TestStorageService } from 'vs/workbench/test/common/workbenchTestServices';
 
 suite('Workbench - Test Results Service', () => {
@@ -37,27 +39,40 @@ suite('Workbench - Test Results Service', () => {
 	});
 
 	class TestLiveTestResult extends LiveTestResult {
+		constructor(
+			id: string,
+			persist: boolean,
+			request: ResolvedTestRunRequest,
+		) {
+			super(id, persist, request);
+			ds.add(this);
+		}
+
 		public setAllToStatePublic(state: TestResultState, taskId: string, when: (task: ITestTaskState, item: TestResultItem) => boolean) {
 			this.setAllToState(state, taskId, when);
 		}
 	}
 
+	const ds = ensureNoDisposablesAreLeakedInTestSuite();
+
 	setup(async () => {
 		changed = new Set();
-		r = new TestLiveTestResult(
+		r = ds.add(new TestLiveTestResult(
 			'foo',
 			true,
 			defaultOpts(['id-a']),
-		);
+		));
 
-		r.onChange(e => changed.add(e));
+		ds.add(r.onChange(e => changed.add(e)));
 		r.addTask({ id: 't', name: undefined, running: true });
 
-		tests = testStubs.nested();
+		tests = ds.add(testStubs.nested());
+		const cts = ds.add(new CancellationTokenSource());
 		const ok = await Promise.race([
 			Promise.resolve(tests.expand(tests.root.id, Infinity)).then(() => true),
-			timeout(1000).then(() => false),
+			timeout(1000, cts.token).then(() => false),
 		]);
+		cts.cancel();
 
 		// todo@connor4312: debug for tests #137853:
 		if (!ok) {
@@ -76,6 +91,8 @@ suite('Workbench - Test Results Service', () => {
 		]);
 	});
 
+	// ensureNoDisposablesAreLeakedInTestSuite(); todo@connor4312
+
 	suite('LiveTestResult', () => {
 		test('is empty if no tests are yet present', async () => {
 			assert.deepStrictEqual(getLabelsIn(new TestLiveTestResult(
@@ -190,8 +207,8 @@ suite('Workbench - Test Results Service', () => {
 		}
 
 		setup(() => {
-			storage = new InMemoryResultStorage(new TestStorageService(), new NullLogService());
-			results = new TestTestResultService(new MockContextKeyService(), storage, new TestProfileService(new MockContextKeyService(), new TestStorageService()));
+			storage = ds.add(new InMemoryResultStorage(ds.add(new TestStorageService()), new NullLogService()));
+			results = ds.add(new TestTestResultService(new MockContextKeyService(), storage, ds.add(new TestProfileService(new MockContextKeyService(), ds.add(new TestStorageService())))));
 		});
 
 		test('pushes new result', () => {
@@ -205,11 +222,11 @@ suite('Workbench - Test Results Service', () => {
 			r.markComplete();
 			await timeout(10); // allow persistImmediately async to happen
 
-			results = new TestResultService(
+			results = ds.add(new TestResultService(
 				new MockContextKeyService(),
 				storage,
-				new TestProfileService(new MockContextKeyService(), new TestStorageService()),
-			);
+				ds.add(new TestProfileService(new MockContextKeyService(), ds.add(new TestStorageService()))),
+			));
 
 			assert.strictEqual(0, results.results.length);
 			await timeout(10); // allow load promise to resolve
@@ -326,9 +343,11 @@ suite('Workbench - Test Results Service', () => {
 
 			const a1 = ctrl.append(VSBuffer.fromString('12345'), 1);
 			const a2 = ctrl.append(VSBuffer.fromString('67890'), 1234);
+			const a3 = ctrl.append(VSBuffer.fromString('with new line\r\n'), 4);
 
-			assert.deepStrictEqual(ctrl.getRange(a1, 5), VSBuffer.fromString('12345'));
-			assert.deepStrictEqual(ctrl.getRange(a2, 5), VSBuffer.fromString('67890'));
+			assert.deepStrictEqual(ctrl.getRange(a1.offset, a1.length), VSBuffer.fromString('\x1b]633;SetMark;Id=s1;Hidden\x0712345\x1b]633;SetMark;Id=e1;Hidden\x07'));
+			assert.deepStrictEqual(ctrl.getRange(a2.offset, a2.length), VSBuffer.fromString('\x1b]633;SetMark;Id=s1234;Hidden\x0767890\x1b]633;SetMark;Id=e1234;Hidden\x07'));
+			assert.deepStrictEqual(ctrl.getRange(a3.offset, a3.length), VSBuffer.fromString('\x1b]633;SetMark;Id=s4;Hidden\x07with new line\x1b]633;SetMark;Id=e4;Hidden\x07\r\n'));
 		});
 	});
 });
