@@ -15,7 +15,7 @@ import { Codicon } from 'vs/base/common/codicons';
 import { debounce } from 'vs/base/common/decorators';
 import { Emitter, Event } from 'vs/base/common/event';
 import { KeyCode, KeyMod } from 'vs/base/common/keyCodes';
-import { splitName } from 'vs/base/common/labels';
+import { normalizeDriveLetter } from 'vs/base/common/labels';
 import { Disposable, DisposableStore } from 'vs/base/common/lifecycle';
 import { parseLinkedText } from 'vs/base/common/linkedText';
 import { Schemas } from 'vs/base/common/network';
@@ -58,6 +58,7 @@ import { defaultButtonStyles, defaultInputBoxStyles } from 'vs/platform/theme/br
 import { isMacintosh } from 'vs/base/common/platform';
 import { IKeybindingService } from 'vs/platform/keybinding/common/keybinding';
 import { ResolvedKeybinding } from 'vs/base/common/keybindings';
+import { basename, dirname } from 'vs/base/common/resources';
 
 export const shieldIcon = registerIcon('workspace-trust-banner', Codicon.shield, localize('shieldIcon', 'Icon for workspace trust ion the banner.'));
 
@@ -576,7 +577,7 @@ class TrustedUriPathColumnRenderer implements ITableRenderer<ITrustedUriItem, IT
 
 	private formatPath(uri: URI): string {
 		if (uri.scheme === Schemas.file) {
-			return uri.fsPath;
+			return normalizeDriveLetter(uri.fsPath);
 		}
 
 		// If the path is not a file uri, but points to a windows remote, we should create windows fs path
@@ -585,7 +586,7 @@ class TrustedUriPathColumnRenderer implements ITableRenderer<ITrustedUriItem, IT
 			const pathWithoutLeadingSeparator = uri.path.substring(1);
 			const isWindowsPath = hasDriveLetter(pathWithoutLeadingSeparator, true);
 			if (isWindowsPath) {
-				return win32.normalize(pathWithoutLeadingSeparator);
+				return normalizeDriveLetter(win32.normalize(pathWithoutLeadingSeparator), true);
 			}
 		}
 
@@ -1041,7 +1042,7 @@ export class WorkspaceTrustEditor extends EditorPane {
 
 		if (this.workspaceTrustManagementService.canSetParentFolderTrust()) {
 			const workspaceIdentifier = toWorkspaceIdentifier(this.workspaceService.getWorkspace()) as ISingleFolderWorkspaceIdentifier;
-			const { name } = splitName(splitName(workspaceIdentifier.uri.fsPath).parentPath);
+			const name = basename(dirname(workspaceIdentifier.uri));
 
 			const trustMessageElement = append(parent, $('.trust-message-box'));
 			trustMessageElement.innerText = localize('trustMessage', "Trust the authors of all files in the current folder or its parent '{0}'.", name);
