@@ -4,7 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { localize } from 'vs/nls';
-import { INativeHostService } from 'vs/platform/native/electron-sandbox/native';
+import { INativeHostService } from 'vs/platform/native/common/native';
 import { IEditorService } from 'vs/workbench/services/editor/common/editorService';
 import { Action2, MenuId } from 'vs/platform/actions/common/actions';
 import { Categories } from 'vs/platform/action/common/actionCommonCategories';
@@ -68,23 +68,6 @@ export class ConfigureRuntimeArgumentsAction extends Action2 {
 	}
 }
 
-
-export class ToggleSharedProcessAction extends Action2 {
-
-	constructor() {
-		super({
-			id: 'workbench.action.toggleSharedProcess',
-			title: { value: localize('toggleSharedProcess', "Toggle Shared Process"), original: 'Toggle Shared Process' },
-			category: Categories.Developer,
-			f1: true
-		});
-	}
-
-	async run(accessor: ServicesAccessor): Promise<void> {
-		return accessor.get(INativeHostService).toggleSharedProcessWindow();
-	}
-}
-
 export class ReloadWindowWithExtensionsDisabledAction extends Action2 {
 
 	constructor() {
@@ -130,5 +113,3 @@ export class OpenUserDataFolderAction extends Action2 {
 		return nativeHostService.showItemInFolder(itemToShow.fsPath);
 	}
 }
-
-
