@@ -9,10 +9,9 @@ import { IDialogHandler, IDialogResult, IDialogService } from 'vs/platform/dialo
 import { IKeybindingService } from 'vs/platform/keybinding/common/keybinding';
 import { ILayoutService } from 'vs/platform/layout/browser/layoutService';
 import { ILogService } from 'vs/platform/log/common/log';
-import { INativeHostService } from 'vs/platform/native/electron-sandbox/native';
+import { INativeHostService } from 'vs/platform/native/common/native';
 import { IProductService } from 'vs/platform/product/common/productService';
 import { Registry } from 'vs/platform/registry/common/platform';
-import { IThemeService } from 'vs/platform/theme/common/themeService';
 import { IWorkbenchContribution, IWorkbenchContributionsRegistry, Extensions as WorkbenchExtensions } from 'vs/workbench/common/contributions';
 import { IDialogsModel, IDialogViewItem } from 'vs/workbench/common/dialogs';
 import { BrowserDialogHandler } from 'vs/workbench/browser/parts/dialogs/dialogHandler';
@@ -34,7 +33,6 @@ export class DialogHandlerContribution extends Disposable implements IWorkbenchC
 		@IDialogService private dialogService: IDialogService,
 		@ILogService logService: ILogService,
 		@ILayoutService layoutService: ILayoutService,
-		@IThemeService themeService: IThemeService,
 		@IKeybindingService keybindingService: IKeybindingService,
 		@IInstantiationService instantiationService: IInstantiationService,
 		@IProductService productService: IProductService,
@@ -43,7 +41,7 @@ export class DialogHandlerContribution extends Disposable implements IWorkbenchC
 	) {
 		super();
 
-		this.browserImpl = new BrowserDialogHandler(logService, layoutService, themeService, keybindingService, instantiationService, productService, clipboardService);
+		this.browserImpl = new BrowserDialogHandler(logService, layoutService, keybindingService, instantiationService, productService, clipboardService);
 		this.nativeImpl = new NativeDialogHandler(logService, nativeHostService, productService, clipboardService);
 
 		this.model = (this.dialogService as DialogService).model;
@@ -66,26 +64,32 @@ export class DialogHandlerContribution extends Disposable implements IWorkbenchC
 			// Confirm
 			if (this.currentDialog.args.confirmArgs) {
 				const args = this.currentDialog.args.confirmArgs;
-				result = this.useCustomDialog ? await this.browserImpl.confirm(args.confirmation) : await this.nativeImpl.confirm(args.confirmation);
+				result = (this.useCustomDialog || args?.confirmation.custom) ?
+					await this.browserImpl.confirm(args.confirmation) :
+					await this.nativeImpl.confirm(args.confirmation);
 			}
 
 			// Input (custom only)
 			else if (this.currentDialog.args.inputArgs) {
 				const args = this.currentDialog.args.inputArgs;
-				result = await this.browserImpl.input(args.severity, args.message, args.buttons, args.inputs, args.options);
+				result = await this.browserImpl.input(args.input);
 			}
 
-			// Message
-			else if (this.currentDialog.args.showArgs) {
-				const args = this.currentDialog.args.showArgs;
-				result = (this.useCustomDialog || args.options?.custom) ?
-					await this.browserImpl.show(args.severity, args.message, args.buttons, args.options) :
-					await this.nativeImpl.show(args.severity, args.message, args.buttons, args.options);
+			// Prompt
+			else if (this.currentDialog.args.promptArgs) {
+				const args = this.currentDialog.args.promptArgs;
+				result = (this.useCustomDialog || args?.prompt.custom) ?
+					await this.browserImpl.prompt(args.prompt) :
+					await this.nativeImpl.prompt(args.prompt);
 			}
 
 			// About
 			else {
-				await this.nativeImpl.about();
+				if (this.useCustomDialog) {
+					await this.browserImpl.about();
+				} else {
+					await this.nativeImpl.about();
+				}
 			}
 
 			this.currentDialog.close(result);
@@ -99,4 +103,4 @@ export class DialogHandlerContribution extends Disposable implements IWorkbenchC
 }
 
 const workbenchRegistry = Registry.as<IWorkbenchContributionsRegistry>(WorkbenchExtensions.Workbench);
-workbenchRegistry.registerWorkbenchContribution(DialogHandlerContribution, 'DialogHandlerContribution', LifecyclePhase.Starting);
+workbenchRegistry.registerWorkbenchContribution(DialogHandlerContribution, LifecyclePhase.Starting);
