@@ -25,7 +25,7 @@ export const launchSchemaId = 'vscode://schemas/launch';
 export const tasksSchemaId = 'vscode://schemas/tasks';
 
 export const APPLICATION_SCOPES = [ConfigurationScope.APPLICATION];
-export const PROFILE_SCOPES = [ConfigurationScope.MACHINE, ConfigurationScope.WINDOW, ConfigurationScope.RESOURCE, ConfigurationScope.LANGUAGE_OVERRIDABLE];
+export const PROFILE_SCOPES = [ConfigurationScope.MACHINE, ConfigurationScope.WINDOW, ConfigurationScope.RESOURCE, ConfigurationScope.LANGUAGE_OVERRIDABLE, ConfigurationScope.MACHINE_OVERRIDABLE];
 export const LOCAL_MACHINE_PROFILE_SCOPES = [ConfigurationScope.WINDOW, ConfigurationScope.RESOURCE, ConfigurationScope.LANGUAGE_OVERRIDABLE];
 export const LOCAL_MACHINE_SCOPES = [ConfigurationScope.APPLICATION, ...LOCAL_MACHINE_PROFILE_SCOPES];
 export const REMOTE_MACHINE_SCOPES = [ConfigurationScope.MACHINE, ConfigurationScope.WINDOW, ConfigurationScope.RESOURCE, ConfigurationScope.LANGUAGE_OVERRIDABLE, ConfigurationScope.MACHINE_OVERRIDABLE];
@@ -84,6 +84,14 @@ export interface IWorkbenchConfigurationService extends IConfigurationService {
 	 * @param arg workspace Identifier
 	 */
 	initialize(arg: IAnyWorkspaceIdentifier): Promise<void>;
+
+	/**
+	 * Returns true if the setting can be applied for all profiles otherwise false.
+	 * @param setting
+	 */
+	isSettingAppliedForAllProfiles(setting: string): boolean;
 }
 
 export const TASKS_DEFAULT = '{\n\t\"version\": \"2.0.0\",\n\t\"tasks\": []\n}';
+
+export const APPLY_ALL_PROFILES_SETTING = 'workbench.settings.applyToAllProfiles';
