@@ -185,11 +185,11 @@ class ExtensionBisectUi {
 	private _showBisectPrompt(): void {
 
 		const goodPrompt: IPromptChoice = {
-			label: 'Good Now',
+			label: localize('I cannot reproduce', "I can't reproduce"),
 			run: () => this._commandService.executeCommand('extension.bisect.next', false)
 		};
 		const badPrompt: IPromptChoice = {
-			label: 'This is Bad',
+			label: localize('This is Bad', "I can reproduce"),
 			run: () => this._commandService.executeCommand('extension.bisect.next', true)
 		};
 		const stop: IPromptChoice = {
@@ -329,11 +329,11 @@ registerAction2(class extends Action2 {
 			detail: localize('bisect', "Extension Bisect is active and has disabled {0} extensions. Check if you can still reproduce the problem and proceed by selecting from these options.", bisectService.disabledCount),
 			buttons: [
 				{
-					label: localize({ key: 'next.good', comment: ['&& denotes a mnemonic'] }, "&&Good now"),
+					label: localize({ key: 'next.good', comment: ['&& denotes a mnemonic'] }, "I ca&&n't reproduce"),
 					run: () => false // good now
 				},
 				{
-					label: localize({ key: 'next.bad', comment: ['&& denotes a mnemonic'] }, "This is &&bad"),
+					label: localize({ key: 'next.bad', comment: ['&& denotes a mnemonic'] }, "I can &&reproduce"),
 					run: () => true // bad
 				},
 				{
