@@ -4,6 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { Barrier } from 'vs/base/common/async';
+import { toErrorMessage } from 'vs/base/common/errorMessage';
 import { Emitter } from 'vs/base/common/event';
 import { Disposable } from 'vs/base/common/lifecycle';
 import { Schemas } from 'vs/base/common/network';
@@ -623,14 +624,8 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 
 	//#region Stopping / Starting / Restarting
 
-	public stopExtensionHosts(reason: string): Promise<boolean>;
-	public stopExtensionHosts(force: true): void;
-	public stopExtensionHosts(arg0: true | string): void | Promise<boolean> {
-		if (arg0 === true) {
-			return this._doStopExtensionHosts();
-		}
-
-		return this._doStopExtensionHostsWithVeto(arg0);
+	public stopExtensionHosts(reason: string): Promise<boolean> {
+		return this._doStopExtensionHostsWithVeto(reason);
 	}
 
 	protected _doStopExtensionHosts(): void {
@@ -659,7 +654,7 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 
 	private async _doStopExtensionHostsWithVeto(reason: string): Promise<boolean> {
 		const vetos: (boolean | Promise<boolean>)[] = [];
-		const vetoReasons: string[] = [];
+		const vetoReasons = new Set<string>();
 
 		this._onWillStop.fire({
 			reason,
@@ -668,13 +663,15 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 
 				if (typeof value === 'boolean') {
 					if (value === true) {
-						vetoReasons.push(reason);
+						vetoReasons.add(reason);
 					}
 				} else {
 					value.then(value => {
 						if (value) {
-							vetoReasons.push(reason);
+							vetoReasons.add(reason);
 						}
+					}).catch(error => {
+						vetoReasons.add(nls.localize('extensionStopVetoError', "{0} (Error: {1})", reason, toErrorMessage(error)));
 					});
 				}
 			}
@@ -684,13 +681,15 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 		if (!veto) {
 			this._doStopExtensionHosts();
 		} else {
-			this._logService.warn(`Extension host was not stopped because of veto (stop reason: ${reason}, veto reason: ${vetoReasons.join(', ')})`);
+			const vetoReasonsArray = Array.from(vetoReasons);
+
+			this._logService.warn(`Extension host was not stopped because of veto (stop reason: ${reason}, veto reason: ${vetoReasonsArray.join(', ')})`);
 
 			await this._dialogService.warn(
 				nls.localize('extensionStopVetoMessage', "The following operation was blocked: {0}", reason),
-				vetoReasons.length === 1 ?
-					nls.localize('extensionStopVetoDetailsOne', "The reason for blocking the operation: {0}", vetoReasons[0]) :
-					nls.localize('extensionStopVetoDetailsMany', "The reasons for blocking the operation:\n- {0}", vetoReasons.join('\n -')),
+				vetoReasonsArray.length === 1 ?
+					nls.localize('extensionStopVetoDetailsOne', "The reason for blocking the operation: {0}", vetoReasonsArray[0]) :
+					nls.localize('extensionStopVetoDetailsMany', "The reasons for blocking the operation:\n- {0}", vetoReasonsArray.join('\n -')),
 			);
 		}
 
@@ -739,7 +738,7 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 	}
 
 	protected _doCreateExtensionHostManager(extensionHost: IExtensionHost, initialActivationEvents: string[]): IExtensionHostManager {
-		return createExtensionHostManager(this._instantiationService, extensionHost, initialActivationEvents, this._acquireInternalAPI());
+		return createExtensionHostManager(this._instantiationService, extensionHost, initialActivationEvents, this._acquireInternalAPI(extensionHost));
 	}
 
 	private _onExtensionHostCrashOrExit(extensionHost: IExtensionHostManager, code: number, signal: string | null): void {
@@ -1071,13 +1070,13 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 
 	//#region Called by extension host
 
-	private _acquireInternalAPI(): IInternalExtensionService {
+	private _acquireInternalAPI(extensionHost: IExtensionHost): IInternalExtensionService {
 		return {
 			_activateById: (extensionId: ExtensionIdentifier, reason: ExtensionActivationReason): Promise<void> => {
 				return this._activateById(extensionId, reason);
 			},
 			_onWillActivateExtension: (extensionId: ExtensionIdentifier): void => {
-				return this._onWillActivateExtension(extensionId);
+				return this._onWillActivateExtension(extensionId, extensionHost.runningLocation);
 			},
 			_onDidActivateExtension: (extensionId: ExtensionIdentifier, codeLoadingTime: number, activateCallTime: number, activateResolvedTime: number, activationReason: ExtensionActivationReason): void => {
 				return this._onDidActivateExtension(extensionId, codeLoadingTime, activateCallTime, activateResolvedTime, activationReason);
@@ -1101,7 +1100,8 @@ export abstract class AbstractExtensionService extends Disposable implements IEx
 		}
 	}
 
-	private _onWillActivateExtension(extensionId: ExtensionIdentifier): void {
+	private _onWillActivateExtension(extensionId: ExtensionIdentifier, runningLocation: ExtensionRunningLocation): void {
+		this._runningLocations.set(extensionId, runningLocation);
 		const extensionStatus = this._getOrCreateExtensionStatus(extensionId);
 		extensionStatus.onWillActivate();
 	}
