@@ -228,7 +228,7 @@ class ExtensionHostManager extends Disposable implements IExtensionHostManager {
 
 		let sum = 0;
 		for (let i = 0; i < COUNT; i++) {
-			const sw = StopWatch.create(true);
+			const sw = StopWatch.create();
 			await proxy.test_latency(i);
 			sw.stop();
 			sum += sw.elapsed();
@@ -248,7 +248,7 @@ class ExtensionHostManager extends Disposable implements IExtensionHostManager {
 		for (let i = 0; i < buff.byteLength; i++) {
 			buff.writeUInt8(i, value);
 		}
-		const sw = StopWatch.create(true);
+		const sw = StopWatch.create();
 		await proxy.test_up(buff);
 		sw.stop();
 		return ExtensionHostManager._convert(SIZE, sw.elapsed());
@@ -257,7 +257,7 @@ class ExtensionHostManager extends Disposable implements IExtensionHostManager {
 	private async _measureDown(proxy: IExtensionHostProxy): Promise<number> {
 		const SIZE = 10 * 1024 * 1024; // 10MB
 
-		const sw = StopWatch.create(true);
+		const sw = StopWatch.create();
 		await proxy.test_down(SIZE);
 		sw.stop();
 		return ExtensionHostManager._convert(SIZE, sw.elapsed());
