@@ -460,11 +460,6 @@ export interface IExtensionService {
 	 */
 	stopExtensionHosts(reason: string): Promise<boolean>;
 
-	/**
-	 * @deprecated Use `stopExtensionHosts()` instead.
-	 */
-	stopExtensionHosts(force: true): void;
-
 	/**
 	 * Starts the extension hosts.
 	 */
