@@ -13,7 +13,7 @@ import { URI } from 'vs/base/common/uri';
 import { IFileMatch, IFileSearchProviderStats, IFolderQuery, ISearchCompleteStats, IFileQuery, QueryGlobTester, resolvePatternsForProvider, hasSiblingFn } from 'vs/workbench/services/search/common/search';
 import { FileSearchProvider, FileSearchOptions } from 'vs/workbench/services/search/common/searchExtTypes';
 
-export interface IInternalFileMatch {
+interface IInternalFileMatch {
 	base: URI;
 	original?: URI;
 	relativePath?: string; // Not present for extraFiles or absolute path matches
@@ -21,13 +21,13 @@ export interface IInternalFileMatch {
 	size?: number;
 }
 
-export interface IDirectoryEntry {
+interface IDirectoryEntry {
 	base: URI;
 	relativePath: string;
 	basename: string;
 }
 
-export interface IDirectoryTree {
+interface IDirectoryTree {
 	rootEntries: IDirectoryEntry[];
 	pathToEntries: { [relativePath: string]: IDirectoryEntry[] };
 }
@@ -329,7 +329,7 @@ export class FileSearchManager {
 	}
 
 	private doSearch(engine: FileSearchEngine, batchSize: number, onResultBatch: (matches: IInternalFileMatch[]) => void, token: CancellationToken): Promise<IInternalSearchComplete> {
-		token.onCancellationRequested(() => {
+		const listener = token.onCancellationRequested(() => {
 			engine.cancel();
 		});
 
@@ -349,12 +349,14 @@ export class FileSearchManager {
 				onResultBatch(batch);
 			}
 
+			listener.dispose();
 			return result;
 		}, error => {
 			if (batch.length) {
 				onResultBatch(batch);
 			}
 
+			listener.dispose();
 			return Promise.reject(error);
 		});
 	}
