@@ -203,6 +203,10 @@ export class TestWorkingCopy extends Disposable implements IWorkingCopy {
 		return this.dirty;
 	}
 
+	isModified(): boolean {
+		return this.isDirty();
+	}
+
 	async save(options?: ISaveOptions, stat?: IFileStatWithMetadata): Promise<boolean> {
 		this._onDidSave.fire({ reason: options?.reason ?? SaveReason.EXPLICIT, stat: stat ?? createFileStat(this.resource), source: options?.source });
 
