@@ -26,7 +26,7 @@ const optimist = require('optimist')
 	.describe('runGlob', 'only run tests matching <file_pattern>').alias('runGlob', 'glob').alias('runGlob', 'runGrep').string('runGlob')
 	.describe('build', 'run with build output (out-build)').boolean('build')
 	.describe('coverage', 'generate coverage report').boolean('coverage')
-	.describe('debug', 'open dev tools, keep window open, reuse app data').string('debug')
+	.describe('dev', 'open dev tools, keep window open, reuse app data').alias('dev', ['dev-tools', 'devTools']).string('dev')
 	.describe('reporter', 'the mocha reporter').string('reporter').default('reporter', 'spec')
 	.describe('reporter-options', 'the mocha reporter options').string('reporter-options').default('reporter-options', '')
 	.describe('wait-server', 'port to connect to and wait before running tests')
@@ -73,7 +73,7 @@ if (crashReporterDirectory) {
 	});
 }
 
-if (!argv.debug) {
+if (!argv.dev) {
 	app.setPath('userData', path.join(tmpdir(), `vscode-tests-${Date.now()}`));
 }
 
@@ -152,7 +152,7 @@ class IPCRunner extends events.EventEmitter {
 app.on('ready', () => {
 
 	ipcMain.on('error', (_, err) => {
-		if (!argv.debug) {
+		if (!argv.dev) {
 			console.error(err);
 			app.exit(1);
 		}
@@ -182,7 +182,7 @@ app.on('ready', () => {
 		width: 800,
 		show: false,
 		webPreferences: {
-			preload: path.join(__dirname, '..', '..', '..', 'src', 'vs', 'base', 'parts', 'sandbox', 'electron-browser', 'preload.js'), // ensure similar environment as VSCode as tests may depend on this
+			preload: path.join(__dirname, '..', '..', '..', 'src', 'vs', 'base', 'parts', 'sandbox', 'electron-sandbox', 'preload.js'), // ensure similar environment as VSCode as tests may depend on this
 			additionalArguments: [`--vscode-window-config=vscode:test-vscode-window-config`],
 			nodeIntegration: true,
 			contextIsolation: false,
@@ -192,7 +192,7 @@ app.on('ready', () => {
 	});
 
 	win.webContents.on('did-finish-load', () => {
-		if (argv.debug) {
+		if (argv.dev) {
 			win.show();
 			win.webContents.openDevTools();
 		}
@@ -270,7 +270,7 @@ app.on('ready', () => {
 		applyReporter(runner, argv);
 	}
 
-	if (!argv.debug) {
+	if (!argv.dev) {
 		ipcMain.on('all done', () => app.exit(runner.didFail ? 1 : 0));
 	}
 });
